@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -82,7 +82,11 @@ void ConnectedComponents::process(ImageComponent * comp) {
     vtkSmartPointer<vtkImageData> outputImage = implementProcess (inputImage);
     QString newName;
     QTextStream(&newName) << comp->getName() << "_cc";
-    new ImageComponent(outputImage, newName);
+    ImageComponent* outputComp = new ImageComponent(outputImage, newName);
+
+    // consider frame policy on new image created
+    Action::applyTargetPosition(comp, outputComp);
+
     Application::refresh();
 
 }
@@ -149,7 +153,6 @@ vtkSmartPointer<vtkImageData> ConnectedComponents::itkProcess(vtkSmartPointer<vt
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observer->Reset();
     observerRelabel->Reset();
