@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -113,7 +113,12 @@ void MorphologicalOperators::process(ImageComponent * comp) {
     vtkSmartPointer<vtkImageData> outputImage = implementProcess (inputImage);
     QString newName;
     QTextStream(&newName) << comp->getName() << suffix;
-    new ImageComponent(outputImage, newName);
+
+    ImageComponent* outputComp = new ImageComponent(outputImage, newName);
+
+    // consider frame policy on new image created
+    Action::applyTargetPosition(comp, outputComp);
+
     Application::refresh();
 
 }
@@ -123,7 +128,7 @@ void MorphologicalOperators::process(ImageComponent * comp) {
 // ITK filter implementation
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::itkProcess(vtkSmartPointer<vtkImageData> img) {
-    vtkSmartPointer<vtkImageData> result;
+    vtkSmartPointer<vtkImageData> result = NULL;
 
     switch (this->getMorphoType()) {
 
@@ -187,7 +192,7 @@ template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryErosionFilter(vtkSmartPointer<vtkImageData> img) {
 
 
-    vtkSmartPointer<vtkImageData> filteredImage;
+
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -198,16 +203,16 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryErosionFilter(vtkSma
     typedef itk::VTKImageToImageFilter<InputImageType> vtkToItkFilterType;
     typename vtkToItkFilterType::Pointer vtkToItkFilter = vtkToItkFilterType::New();
 
-    // In the same way, once the image is filtered, we need to convert it again to
-    //    VTK format to give it to CamiTK.
-    typedef itk::ImageToVTKImageFilter<OutputImageType> itkToVtkFilterType;
-    typename itkToVtkFilterType::Pointer itkToVtkFilter = itkToVtkFilterType::New();
-
     // Declare and create your own private ITK filter here...
     typedef itk::BinaryBallStructuringElement<InputPixelType, dim> StructuringElementType;
     typedef itk::BinaryErodeImageFilter <InputImageType, OutputImageType, StructuringElementType> FilterType;
     typename FilterType::Pointer filter = FilterType::New();
 
+    // In the same way, once the image is filtered, we need to convert it again to
+    //    VTK format to give it to CamiTK.
+    typedef itk::ImageToVTKImageFilter<OutputImageType> itkToVtkFilterType;
+    typename itkToVtkFilterType::Pointer itkToVtkFilter = itkToVtkFilterType::New();
+
     // To update CamiTK progress bar while filtering, add an ITK observer to the filters.
     ItkProgressObserver::Pointer observer = ItkProgressObserver::New();
     // ITK observers generally give values between 0 and 1, and CamiTK progress bar
@@ -226,6 +231,8 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryErosionFilter(vtkSma
     structuringElement.CreateStructuringElement();
     filter->SetKernel(structuringElement);
 
+    filter->Update();
+
     // From ITK to VTK
     itkToVtkFilter->SetInput(filter->GetOutput());
 
@@ -235,14 +242,14 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryErosionFilter(vtkSma
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observer->Reset();
+    observer = NULL;
 
     return filteredImage;
 
@@ -251,7 +258,6 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryErosionFilter(vtkSma
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryDilationFilter(vtkSmartPointer<vtkImageData> img) {
 
-    vtkSmartPointer<vtkImageData> filteredImage;
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -290,6 +296,8 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryDilationFilter(vtkSm
     structuringElement.CreateStructuringElement();
     filter->SetKernel(structuringElement);
 
+    filter->Update();
+
     // From ITK to VTK
     itkToVtkFilter->SetInput(filter->GetOutput());
 
@@ -299,14 +307,14 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryDilationFilter(vtkSm
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observer->Reset();
+    observer = NULL;
 
     return filteredImage;
 
@@ -315,7 +323,6 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryDilationFilter(vtkSm
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryClosureFilter(vtkSmartPointer<vtkImageData> img) {
 
-    vtkSmartPointer<vtkImageData> filteredImage = NULL;
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -360,10 +367,12 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryClosureFilter(vtkSma
     dilationFilter->SetInput(vtkToItkFilter->GetOutput());
     dilationFilter->AddObserver ( itk::ProgressEvent(), observerDilation );
     dilationFilter->SetKernel(structuringElement);
+    dilationFilter->Update();
 
     erosionFilter->SetInput(dilationFilter->GetOutput());
     erosionFilter->AddObserver( itk::ProgressEvent(), observerErosion );
     erosionFilter->SetKernel(structuringElement);
+    erosionFilter->Update();
 
     // From ITK to VTK
     itkToVtkFilter->SetInput(erosionFilter->GetOutput());
@@ -374,16 +383,18 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryClosureFilter(vtkSma
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observerErosion->Reset();
     observerDilation->Reset();
 
+    observerDilation = NULL;
+    observerErosion = NULL;
+
     return filteredImage;
 
 }
@@ -391,7 +402,7 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryClosureFilter(vtkSma
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryOpeningFilter(vtkSmartPointer<vtkImageData> img) {
 
-    vtkSmartPointer<vtkImageData> filteredImage;
+
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -436,10 +447,12 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryOpeningFilter(vtkSma
     erosionFilter->SetInput(vtkToItkFilter->GetOutput());
     erosionFilter->AddObserver( itk::ProgressEvent(), observerErosion );
     erosionFilter->SetKernel(structuringElement);
+    erosionFilter->Update();
 
     dilationFilter->SetInput(erosionFilter->GetOutput());
     dilationFilter->AddObserver ( itk::ProgressEvent(), observerDilation );
     dilationFilter->SetKernel(structuringElement);
+    dilationFilter->Update();
 
     // From ITK to VTK
     itkToVtkFilter->SetInput(dilationFilter->GetOutput());
@@ -450,16 +463,18 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryOpeningFilter(vtkSma
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observerErosion->Reset();
     observerDilation->Reset();
 
+    observerErosion = NULL;
+    observerDilation = NULL;
+
     return filteredImage;
 
 }
@@ -468,7 +483,7 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::binaryOpeningFilter(vtkSma
 
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelErosionFilter(vtkSmartPointer<vtkImageData> img) {
-    vtkSmartPointer<vtkImageData> filteredImage;
+
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -506,6 +521,7 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelErosionFilter(vtk
     structuringElement.SetRadius( structuringElementSize );
     structuringElement.CreateStructuringElement();
     filter->SetKernel(structuringElement);
+    filter->Update();
 
     // From ITK to VTK
     itkToVtkFilter->SetInput(filter->GetOutput());
@@ -516,14 +532,14 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelErosionFilter(vtk
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observer->Reset();
+    observer = NULL;
 
     return filteredImage;
 
@@ -533,7 +549,7 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelErosionFilter(vtk
 
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelDilationFilter(vtkSmartPointer<vtkImageData> img) {
-    vtkSmartPointer<vtkImageData> filteredImage;
+
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -571,6 +587,7 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelDilationFilter(vt
     structuringElement.SetRadius( structuringElementSize );
     structuringElement.CreateStructuringElement();
     filter->SetKernel(structuringElement);
+    filter->Update();
 
     // From ITK to VTK
     itkToVtkFilter->SetInput(filter->GetOutput());
@@ -581,14 +598,14 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelDilationFilter(vt
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observer->Reset();
+    observer = NULL;
 
     return filteredImage;
 
@@ -596,7 +613,6 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelDilationFilter(vt
 
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelClosureFilter(vtkSmartPointer<vtkImageData> img) {
-    vtkSmartPointer<vtkImageData> filteredImage = NULL;
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -641,10 +657,12 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelClosureFilter(vtk
     dilationFilter->SetInput(vtkToItkFilter->GetOutput());
     dilationFilter->AddObserver ( itk::ProgressEvent(), observerDilation );
     dilationFilter->SetKernel(structuringElement);
+    dilationFilter->Update();
 
     erosionFilter->SetInput(dilationFilter->GetOutput());
     erosionFilter->AddObserver( itk::ProgressEvent(), observerErosion );
     erosionFilter->SetKernel(structuringElement);
+    erosionFilter->Update();
 
     // From ITK to VTK
     itkToVtkFilter->SetInput(erosionFilter->GetOutput());
@@ -655,15 +673,16 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelClosureFilter(vtk
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observerErosion->Reset();
     observerDilation->Reset();
+    observerDilation = NULL;
+    observerErosion = NULL;
 
     return filteredImage;
 
@@ -672,7 +691,6 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelClosureFilter(vtk
 template <class InputPixelType, class OutputPixelType, const int dim>
 vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelOpeningFilter(vtkSmartPointer<vtkImageData> img) {
 
-    vtkSmartPointer<vtkImageData> filteredImage = NULL;
     // --------------------- Filters declaration and creation ----------------------
     // Define ITK input and output image types with respect to the instanciation
     //    types of the tamplate.
@@ -717,10 +735,12 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelOpeningFilter(vtk
     erosionFilter->SetInput(vtkToItkFilter->GetOutput());
     erosionFilter->AddObserver( itk::ProgressEvent(), observerErosion );
     erosionFilter->SetKernel(structuringElement);
+    erosionFilter->Update();
 
     dilationFilter->SetInput(erosionFilter->GetOutput());
     dilationFilter->AddObserver ( itk::ProgressEvent(), observerDilation );
     dilationFilter->SetKernel(structuringElement);
+    dilationFilter->Update();
 
     // From ITK to VTK
     itkToVtkFilter->SetInput(dilationFilter->GetOutput());
@@ -731,15 +751,16 @@ vtkSmartPointer<vtkImageData> MorphologicalOperators::greyLevelOpeningFilter(vtk
 
     // --------------------- Create and return a copy (the filters will be deleted)--
     vtkSmartPointer<vtkImageData> resultImage = itkToVtkFilter->GetOutput();
-    filteredImage = vtkImageData::New();
+    vtkSmartPointer<vtkImageData> filteredImage = vtkSmartPointer<vtkImageData>::New();
     int extent[6];
     resultImage->GetExtent(extent);
     filteredImage->SetExtent(extent);
     filteredImage->DeepCopy(resultImage);
-    filteredImage->Update();
 
     observerErosion->Reset();
     observerDilation->Reset();
+    observerDilation = NULL;
+    observerErosion = NULL;
 
     return filteredImage;
 
