@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -24,14 +24,12 @@
  ****************************************************************************/
 #include "MMLActionExtension.h"
 
-#include "CreateSC.h"
 #include "GenerateModel.h"
+#include "SimulationDialog.h"
 
-// --------------- declare the extension -------------------
-Q_EXPORT_PLUGIN2(mmlactionextension, MMLActionExtension)
 
 // -------------------- init --------------------
 void MMLActionExtension::init() {
     registerNewAction(GenerateModel);
-    registerNewAction(CreateSC);
+    registerNewAction(SimulationDialog);
 }
