@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -24,19 +24,22 @@
  ****************************************************************************/
 
 
-// PML/LML
+// PML
 #include <pml/PhysicalModel.h>
 #include <pml/MultiComponent.h>
 
+// LML
+#include <lml/Loads.h>
+#include <lml/Load.h>
+
+// Physical Model Component
 #include "LoadsManager.h"
 #include "LoadsSimulation.h"
 #include "LoadsMovie.h"
 #include "LoadsEditor.h"
 #include "AtomDecoration.h"
 #include "PMManagerDC.h"
-
 #include "AtomDC.h"
-#include <lml/XMLLoads.h>
 
 // camiTK
 #include <Application.h>
