@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,9 +30,10 @@
 
 #include <sofa/simulation/common/xml/initXml.h>
 #include <sofa/component/init.h>
+#include <sofa/helper/Utils.h>
+#include <sofa/helper/system/PluginManager.h>
 
 #ifdef SOFA_1_0_RC1
-// FIXME: check if this is really needed!
 #include <sofa/simulation/common/xml/initXml.h>
 #include <sofa/simulation/common/Node.h>
 #include <sofa/simulation/tree/TreeSimulation.h>
@@ -74,32 +75,25 @@ bool sofaRegistered = SimulatorFactory::getInstance()->registerClass<SofaSimulat
 
 SofaSimulator::SofaSimulator( MonitoringManager* monitoringManager ): InteractiveSimulator( monitoringManager ) {
 
-    string mshFile;
     // check for Sofa scn
-    scnFile = monitoringManager->getPmlFileName();
-    string::size_type pLast = scnFile.rfind( "." );
-
-    if( pLast != string::npos ) {
-        scnFile.erase( pLast );
-        mshFile = string( scnFile );
-        mshFile += ".msh";
-        scnFile += ".scn";
-    }
-
+    QFileInfo mmlFileInfo = QFileInfo(monitoringManager->getMmlFileName().c_str());
+    QString scnFileName = mmlFileInfo.absolutePath() + "/" + mmlFileInfo.baseName() + ".scn";
+    scnFile = scnFileName.toStdString();
 
     // if scn file already exist, use this file
     ifstream iscn( scnFile.c_str() );
 
     if( !iscn ) {
+        // scn file do not exist in the same directory, create one in temp directory
+        scnFileName = QDir::tempPath() + "/" + mmlFileInfo.baseName() + ".scn";
+        scnFile = scnFileName.toStdString();
 
-        //scn file do not exist in pml directory, create one
-        //TODO? add simulator file path to mml? do not create if specified?
-
-        //create msh from pmlFile
+        // create msh from pmlFile in temporary directory as well
+        QString mshFileName = QDir::tempPath() + "/" + QFileInfo(monitoringManager->getPmlFileName().c_str()).baseName() + ".msh";
         int type = 0;
         PhysicalModel* pml = monitoringManager->getPml();
         ofstream msh;
-        msh.open( mshFile.c_str(), ios::out );
+        msh.open( mshFileName.toStdString().c_str(), ios::out );
 
         //create nodes
         msh << "$NOD" << endl;
@@ -115,7 +109,6 @@ SofaSimulator::SofaSimulator( MonitoringManager* monitoringManager ): Interactiv
 
         msh << "$ENDNOD" << endl;
 
-
         //create elements if an "Elements" components exists
         Component *elements = pml->getComponentByName( "Elements" );
 
@@ -181,7 +174,7 @@ SofaSimulator::SofaSimulator( MonitoringManager* monitoringManager ): Interactiv
         // to choose a possible modeling techniques we assume that only one type of elements is used
         ofstream scn;
         scn.open( scnFile.c_str(), ios::out );
-#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN)
+#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN) || defined(SOFA_STABLE)
         scn << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
         scn << "<!-- Created from " << monitoringManager->getPmlFileName() << " by CamiTK/mml -->" << endl;
         scn << "<Node name=\"Root\" gravity=\"0 0 0\" dt=\"" << monitoringManager->getDt() << "\" >" << endl;
@@ -197,7 +190,7 @@ SofaSimulator::SofaSimulator( MonitoringManager* monitoringManager ): Interactiv
         scn << "        <EulerImplicit name=\"cg_odesolver\"  printLog=\"false\" />" << endl;
         scn << "        <CGLinearSolver iterations=\"25\" name=\"linear solver\" tolerance=\"1.0e-9\" threshold=\"1.0e-9\" />" << endl;
         scn << "        <!-- mesh -->" << endl;
-        scn << "        <MeshGmshLoader name=\"meshLoader\" filename=\"" << mshFile << "\" />" << endl;
+        scn << "        <MeshGmshLoader name=\"meshLoader\" filename=\"" << mshFileName.toStdString() << "\" />" << endl;
         scn << "        <Mesh src=\"@meshLoader\" />" << endl;
         scn << "        <!-- mechanical object -->" << endl;
         scn << "        <MechanicalObject src=\"@meshLoader\" />" << endl;
@@ -298,13 +291,51 @@ SofaSimulator::~SofaSimulator() {
 // -------------------- build --------------------
 void SofaSimulator::build() {
 
-#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN)
-    sofa::helper::system::DataRepository.addFirstPath( string( SOFA_PATH ) + "/share" );
-    sofa::helper::system::DataRepository.addFirstPath( string( SOFA_PATH ) + "/examples" );
+#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN) || defined(SOFA_STABLE)
+    // retrieve plugins
+    sofa::component::init();
+    sofa::simulation::xml::initXml();
+
+    // mimicking sofa set/get path methods using local variable names
+    const std::string sofaPathPrefix = string( SOFA_BUILD_DIR );
+#ifdef WIN32
+    const std::string pluginDir = sofaPathPrefix;
+#else
+    const std::string pluginDir = sofaPathPrefix + "/lib";
+#endif
+    sofa::helper::system::PluginRepository.addFirstPath( pluginDir );
+
+    // Initialise paths
+    const std::string configDirectoryPath = sofaPathPrefix + "/config";
+    const std::string  screenshotDirectoryPath = sofaPathPrefix + "/screenshots";
+
+    // manage plugins from plugin file loadedPlugins.ini
+    // This file can be found in the build path.
+    // Beware that this file can only be setup/initialized/populated by runSofa application (in Edit -> Plugin Manager menu)
+    // or sofa modeler.
+    // Simulate the initialization of m_pluginMap by a Sofa GUI application
+    // Next line is extracted from SofaPluginManager::loadPluginsFromIniFile()
+    std::string path = configDirectoryPath + "/loadedPlugins.ini";
+    sofa::helper::system::PluginManager::getInstance().readFromIniFile( path);
+
+    sofa::helper::system::PluginManager::getInstance().init();
+
+    // -- from GUIManager::Init
+    // double init!
+    sofa::component::init();
+    sofa::simulation::xml::initXml();
+    // from SOFA_SOURCE_DIR find the directory to share and examples files (do not use the etc/sofa.ini file
+    sofa::helper::system::DataRepository.addFirstPath( string( SOFA_SOURCE_DIR ) + "/share" );
+    sofa::helper::system::DataRepository.addFirstPath( string( SOFA_SOURCE_DIR ) + "/examples" );
+
+    // look for the scn file
     QFileInfo scnFileInfo( scnFile.c_str() );
+    /*TODO CLEANUP
+    std::string fileName = sofa::helper::system::DataRepository.getFile(scnFileInfo.absoluteDir().canonicalPath().toStdString());
+    */
     sofa::helper::system::DataRepository.addFirstPath( scnFileInfo.absoluteDir().canonicalPath().toStdString() );
 
-    /*    std::cout << "DataRepository is now: " << std::endl;
+    /* TODO CLEANUP    std::cout << "DataRepository is now: " << std::endl;
         const std::vector< std::string > paths = sofa::helper::system::DataRepository.getPaths();
         std::copy( &paths[0], &paths[paths.size()], ostream_iterator<string>(cout, " "));
     */
@@ -320,10 +351,10 @@ void SofaSimulator::build() {
 #endif
 
     //-- load the SOFA scn
-#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN)
-    //preRC1 (svn)
-    groot = sofa::core::objectmodel::SPtr_dynamic_cast<sofa::simulation::Node>( sofa::simulation::tree::getSimulation()->load( scnFile.c_str() ) );
-    //RC1 groot = sofa::core::objectmodel::SPtr_dynamic_cast<sofa::simulation::Node>(sofa::simulation::getSimulation()->load(scnFile.c_str()));
+#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN) || defined(SOFA_STABLE)
+    // strong hypothesis: we don't use SOFA DAG, but sofa tree architecture
+    //groot = sofa::core::objectmodel::SPtr_dynamic_cast<sofa::simulation::Node>( sofa::simulation::tree::getSimulation()->load( fileName.c_str() ) );
+    groot = sofa::core::objectmodel::SPtr_dynamic_cast<sofa::simulation::Node>( sofa::simulation::tree::getSimulation()->load( scnFile.c_str()  ) );
 #endif
 
 #ifdef MML_SOFA_1_0_BETA4
@@ -331,7 +362,7 @@ void SofaSimulator::build() {
 #endif
 
     if( getGNode() == NULL ) {
-#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN)
+#if defined(SOFA_1_0_RC1) || defined(SOFA_SVN) || defined(SOFA_STABLE)
         groot = sofa::simulation::tree::getSimulation()->createNewGraph( "" );
 #endif
 
@@ -344,6 +375,11 @@ void SofaSimulator::build() {
     // init root
     sofa::simulation::tree::getSimulation()->init( getGNode() );
 
+    // calling sofa::simulation::tree::getSimulation()->reset ( getGNode() ) is not needed as
+    // it is done in runSofa main (sse RealGUI::setScene -> RealGUI::resetScene )
+    // as it will be done automatically when the sofa simulator will be initialized
+    // (see SofaSimulator::init)
+
     // sofa scn dt prevails
     monitoringManager->setDt( getGNode()->getDt() );
 
@@ -410,7 +446,12 @@ void SofaSimulator::doMove( double dt ) {
     getGNode()->getContext()->setDt( dt );
 
     //-- animate one step
+#ifdef SOFA_STABLE
+    // Warning animate method does not need any dt. 0.0 is always at least used in Sofa v15_03
+    sofa::simulation::tree::getSimulation()->animate( getGNode(), /*dt*/0.0 );
+#else
     sofa::simulation::tree::getSimulation()->animate( getGNode(), dt );
+#endif
 }
 
 // --------------- getPosition -------------------
@@ -460,7 +501,7 @@ void SofaSimulator::buildConstraints() {
                 }
             }
 
-#if !defined(SOFA_1_0_RC1) && !defined(SOFA_SVN)
+#if !defined(SOFA_1_0_RC1) && !defined(SOFA_SVN) && !defined(SOFA_STABLE)
             delete translations[i];
 #endif
         }
