@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -45,18 +45,15 @@ OpenFile::OpenFile (ActionExtension * extension) : Action (extension) {
     setDescription(tr("Open data (component) from a given file"));
     setComponent("");
 
-    if (qApp->type() != QApplication::Tty)
-        setIcon (QPixmap (":/fileOpen"));
+    setIcon (QPixmap (":/fileOpen"));
 
     // Setting classification family and tags
     setFamily("Application");
     addTag(tr("Open"));
 
     // add a shortcut
-    if (qApp->type() != QApplication::Tty) {
-        getQAction()->setShortcut( QKeySequence::Open );
-        getQAction()->setShortcutContext(Qt::ApplicationShortcut);
-    }
+    getQAction()->setShortcut( QKeySequence::Open );
+    getQAction()->setShortcutContext(Qt::ApplicationShortcut);
 
     // the unique property is the filename
     Property* fileNameProperty = new Property(tr("File name"), "", tr("The name of the file to open."), "");
