@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -332,7 +332,7 @@ void ImageLutWidget::draw () {
     pen.setStyle(Qt::DashLine);
 
     // pen width depends on numbers of bars in the histogram
-    int penWidth = (int)(sceneRectangle.width() / 100.0);
+    int penWidth = 3.0; // (int)(sceneRectangle.width() / 100.0);
     pen.setWidth(penWidth);
 
     ui.histogramGraphicsView->scene()->addLine(level, sceneRectangle.y(), level, sceneRectangle.height(), pen);
@@ -489,7 +489,15 @@ void ImageLutWidget::invertButtonClicked() {
 void ImageLutWidget::updateGradient() {
     QColor maxColor = ui.maxColor->palette().button().color();
     QColor minColor = ui.minColor->palette().button().color();
-    QString style = "background-color: qlineargradient(x1:0 y1:0, x2:1 y2:0, stop:0 rgba("+ QString::number(minColor.red()) + ", " + QString::number(minColor.green()) + ", " + QString::number(minColor.blue()) + ", " + QString::number(minColor.alpha()) + " ), stop:1 rgba( " + QString::number(maxColor.red()) + ", " + QString::number(maxColor.green()) + ", " + QString::number(maxColor.blue()) + ", " + QString::number(maxColor.alpha()) + " ) )";
+    QString style = "background-color: qlineargradient(x1:0 y1:0, x2:1 y2:0, stop:0 rgba("+
+                    QString::number(minColor.red()) + ", " +
+                    QString::number(minColor.green()) + ", " +
+                    QString::number(minColor.blue()) + ", " +
+                    QString::number(minColor.alpha()) + " ), stop:1 rgba( " +
+                    QString::number(maxColor.red()) + ", " +
+                    QString::number(maxColor.green()) + ", " +
+                    QString::number(maxColor.blue()) + ", " +
+                    QString::number(maxColor.alpha()) + " ) )";
     ui.colorScale->setStyleSheet(style);
 }
 
