@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -32,14 +32,15 @@
 
 class PixelColorChangerExtension : public camitk::ActionExtension {
     Q_OBJECT
-    Q_INTERFACES(camitk::ActionExtension);
+    Q_INTERFACES(camitk::ActionExtension)
+    Q_PLUGIN_METADATA(IID "fr.imag.camitk.sdk.action.pixelcolorchanger")
 
 public:
     /// the constructor
-    PixelColorChangerExtension() : ActionExtension() {};
+    PixelColorChangerExtension() : ActionExtension() {}
 
     /// the destructor
-    virtual ~PixelColorChangerExtension() {};
+    virtual ~PixelColorChangerExtension() {}
 
     /// initialize all the actions
     virtual void init();
@@ -57,4 +58,4 @@ public:
 };
 
 
-#endif // PIXELCOLORCHANGEREXTENSION_H
\ No newline at end of file
+#endif // PIXELCOLORCHANGEREXTENSION_H
