@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,9 +26,6 @@
 #include "VolumeRenderingExtension.h"
 #include "VolumeRenderingAction.h"
 
-// --------------- declare the extension -------------------
-Q_EXPORT_PLUGIN2(volumerenderingextension, VolumeRenderingExtension)
-
 // --------------- getActions -------------------
 void VolumeRenderingExtension::init() {
     registerNewAction(VolumeRenderingAction);
