@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -222,7 +222,6 @@ void MeshQuality::updateMeshColor(vtkSmartPointer< vtkDoubleArray > qualityArray
             double scalar = getQualityColor(val,minAR,maxAR,minNR,maxNR);
             cellData->InsertValue(indices[id],scalar);
         }
-        meshComponent->getPointSet()->Update();
         meshComponent->getPointSet()->GetCellData()->SetScalars(cellData);
         Application::refresh();
     }
@@ -309,7 +308,7 @@ void MeshQuality::updateTableWidget(vtkSmartPointer< vtkDoubleArray > qualityArr
 
     //-- keep lines below at the end to have a correct final layout
     QHeaderView *horizontalHeader = qualityInfo->horizontalHeader();
-    horizontalHeader->setResizeMode(QHeaderView::Stretch);
+    horizontalHeader->setSectionResizeMode(QHeaderView::Stretch);
 
     QStringList headerTitles;
     headerTitles << "Cell Id" << "Quality";
