@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,7 +35,7 @@
 
 // description of the application. Please update the manpage-prologue.1.in also if you modify this string.
 const char* description="Please visit http://camitk.imag.fr for more information.\n"
-                        "(c) UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525\n\n"
+                        "(c) Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525\n\n"
                         "camitk-cepgenerator aims at creating CamiTK Extension Project skeleton from\n"
                         "a description given in a XML file (valid CamiTK cepcoreschema language).";
 
@@ -87,7 +87,9 @@ int main(int argc, char * argv[]) {
                 } else {
                     // now we can work!
                     // for the translation from argument to QString, see http://qt-project.org/doc/qt-4.8/qcoreapplication.html#accessing-command-line-arguments
-                    CepGenerator::generateCEP(QString::fromLocal8Bit(o.file().c_str()), QString::fromLocal8Bit(o.directory().c_str()));
+                    CepGenerator* generator = new CepGenerator(QString::fromLocal8Bit(o.file().c_str()), QString::fromLocal8Bit(o.directory().c_str()));
+                    generator->process();
+                    delete generator;
                 }
             }
         }
