@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -63,9 +63,9 @@ int main(int argc, char *argv[]) {
                 if (compiledFromPackageSource())
                     std::cout << "Compiled using package source." << std::endl;
                 else {
-                    std::cout << "Compiled using svn";
-                    if (hasMoreSvnInformation()) {
-                        std::cout << " Rev: " << svnRevision() << ", Date: " << svnDate() << std::endl;
+                    std::cout << "Compiled using git";
+                    if (hasMoreGitInformation()) { // Check if CAMITK_GIT_FOUND can be set to "1" otherwise we never get into this 'if'
+                        std::cout << " Hash: " << gitHash() << ", Date: " << gitDate() << std::endl;
                     }
                     std::cout << "." << std::endl;
                 }
@@ -99,6 +99,15 @@ int main(int argc, char *argv[]) {
                 // print the configuration on the std::cout
                 std::cout << Core::getConfig().toStdString() << std::endl;
                 return EXIT_SUCCESS;
+            } else if (o.bug_report_info()) {
+                // init the camitk application context without auto-loading all extensions
+                Application a("camitk-config", argc, argv);
+                // avoid all redirection to console
+                MainWindow *defaultMainWindow = dynamic_cast<MainWindow*>(a.getMainWindow());
+                defaultMainWindow->redirectToConsole(false);
+                // print the configuration on the std::cout
+                std::cout << Core::getBugReport().toStdString() << std::endl;
+                return EXIT_SUCCESS;
             } else {
                 usage(argv[0]);
                 //TODO: Show some GUI (for e.g. with "copy to clipboard" and "email" buttons)
