@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,6 +30,7 @@
 #include <Application.h>
 #include <ExtensionManager.h>
 #include <MedicalImageViewer.h>
+#include <ActionViewer.h>
 #include <SettingsDialog.h>
 #include <Component.h>
 #include <Action.h>
@@ -38,6 +39,8 @@
 #include <Explorer.h>
 #include <FrameExplorer.h>
 #include <PropertyExplorer.h>
+#include <Property.h>
+#include <PropertyObject.h>
 
 using namespace camitk;
 
@@ -503,11 +506,8 @@ void ImpMainWindow::editSettings() {
     // create the dialog
     SettingsDialog settingsDialog;
 
-    // construct a dynamic property object
-    QObject *myProperties = new QObject;
-    myProperties->setObjectName(Application::getName());
-    myProperties->setProperty ( "autoLoadLastOpened", autoLoadLastOpened );
-    settingsDialog.editSettings ( myProperties );
+    // show the properties of the CamiTK application
+    settingsDialog.editSettings(dynamic_cast<Application*>(qApp)->getPropertyObject());
 
     // edit all viewers that have properties
     foreach ( Viewer *v, viewers ) {
@@ -523,18 +523,23 @@ void ImpMainWindow::editSettings() {
         updateRecentDocumentsMenu();
     }
 
-    // update the property
-    autoLoadLastOpened = myProperties->property ( "autoLoadLastOpened" ).toBool();
-    // save it in the settings
+    // update the CamiTK IMP properties
+    autoLoadLastOpened = dynamic_cast<Application*>(qApp)->getPropertyObject()->property ( dynamic_cast<Application*>(qApp)->getAutoloadLastOpenedComponentsProperty()->getName().toStdString().c_str()).toBool();
+
+    // save application properties as settings
     QSettings & settings = Application::getSettings();
     settings.beginGroup ( Application::getName() + ".Application" );
-    settings.setValue ( "autoLoadLastOpened", autoLoadLastOpened );
+    // auto load last opened components
+    // Note: prefer simple key names: http://doc.qt.io/qt-4.8/qsettings.html#section-and-key-syntax
+    settings.setValue ( "autoLoadLastOpened",
+                        dynamic_cast<Application*>(qApp)->getPropertyObject()->property(dynamic_cast<Application*>(qApp)->getAutoloadLastOpenedComponentsProperty()->getName().toStdString().c_str()));
+    // default target component
+    settings.setValue ( "targetedPositionningPolicy",
+                        dynamic_cast<Application*>(qApp)->getPropertyObject()->property(dynamic_cast<Application*>(qApp)->getDefaultTargetedComponentProperty()->getName().toStdString().c_str()));
     settings.endGroup();
 
     // check if there are anything to change in the data directory menu (for data directory manager)
     updateOpenDirectoryMenu();
-
-    delete myProperties;
 }
 
 // ------------------------------ initSettings -------------------------------
@@ -546,7 +551,17 @@ void ImpMainWindow::initSettings() {
 
     settings.beginGroup (Application::getName() + ".Application");
     // the autoload option
-    autoLoadLastOpened = settings.value ( "autoLoadLastOpened", false ).toBool(); // default false
+    // Note: prefer simple key names: http://doc.qt.io/qt-4.8/qsettings.html#section-and-key-syntax
+    autoLoadLastOpened = settings.value ( "autoLoadLastOpened",
+                                          false).toBool(); // default false
+    dynamic_cast<Application*>(qApp)->getPropertyObject()->setProperty(
+        dynamic_cast<Application*>(qApp)->getAutoloadLastOpenedComponentsProperty()->getName().toStdString().c_str(), autoLoadLastOpened);
+
+    // the frame policy option
+    Application::TargetPositionningMethods framePolicy = (Application::TargetPositionningMethods) settings.value ( "targetedPositionningPolicy", 0).toInt();
+    dynamic_cast<Application*>(qApp)->getPropertyObject()->setProperty(
+        dynamic_cast<Application*>(qApp)->getDefaultTargetedComponentProperty()->getName().toStdString().c_str(), framePolicy);
+
     settings.endGroup();
 }
 
