@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,6 +30,8 @@
 
 // -- Core stuff
 #include <MainWindow.h>
+#include <Application.h>
+
 /**
  * @ingroup group_sdk_application_imp
  *
@@ -225,6 +227,12 @@ private:
 
     ///@}
 
+    /** @name Frame management attributes */
+    ///@{
+    /// How to handle the new target (i.e. component created by an action) frame?
+    //camitk::Application::TargetPositionningMethods defaultTargetPositionningMethod;
+
+    ///@}
 
 private slots:
 
