@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,7 +26,7 @@
 // Include .h file
 #include "ActionAddParameterState.h"
 #include "ActionAddParameterWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ActionCreationState.h"
 #include "ActionParameterWidget.h"
 
@@ -36,12 +36,12 @@
 #include <Parameter.hxx>
 
 
-/**  Constructor */
-ActionAddParameterState::ActionAddParameterState(QString name, ActionAddParameterWidget * widget, DorothyMainWindow * mainWindow, ActionCreationState * parent)
+
+ActionAddParameterState::ActionAddParameterState(QString name, ActionAddParameterWidget * widget, WizardMainWindow * mainWindow, ActionCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domAction = NULL;
 }
-/**  Destructor */
+
 ActionAddParameterState::~ActionAddParameterState() {}
 
 void ActionAddParameterState::resetDomAction(cepcoreschema::Action * domAction) {
