@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -43,7 +43,7 @@ class Action;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to add parameters in the action
  *
  */
 class ActionAddParameterState : public WizardState  {
@@ -51,8 +51,10 @@ class ActionAddParameterState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ActionAddParameterState(QString name, ActionAddParameterWidget * widget, DorothyMainWindow * mainWindow, ActionCreationState * parent);
+    /**  Constructor */
+    ActionAddParameterState(QString name, ActionAddParameterWidget * widget, WizardMainWindow * mainWindow, ActionCreationState * parent);
 
+    /**  Destructor */
     ~ActionAddParameterState();
 
     void resetDomAction(cepcoreschema::Action * domAction);
