@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,7 +27,7 @@
 #include "ActionClassificationState.h"
 #include "ActionClassificationWidget.h"
 #include "ActionTagWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ActionCreationState.h"
 
 // includes from coreschema
@@ -35,12 +35,12 @@
 #include <Classification.hxx>
 
 
-/**  Constructor */
-ActionClassificationState::ActionClassificationState(QString name, ActionClassificationWidget * widget, DorothyMainWindow * mainWindow, ActionCreationState * parent)
+
+ActionClassificationState::ActionClassificationState(QString name, ActionClassificationWidget * widget, WizardMainWindow * mainWindow, ActionCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domAction = NULL;
 }
-/**  Destructor */
+
 ActionClassificationState::~ActionClassificationState() {}
 
 void ActionClassificationState::resetDomAction(cepcoreschema::Action *domAction) {
