@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -40,7 +40,7 @@ class Action;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to class the action and to attribute a tag to it.
  *
  */
 class ActionClassificationState : public WizardState  {
@@ -48,8 +48,10 @@ class ActionClassificationState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ActionClassificationState(QString name, ActionClassificationWidget * widget, DorothyMainWindow * mainWindow, ActionCreationState * parent);
+    /**  Constructor */
+    ActionClassificationState(QString name, ActionClassificationWidget * widget, WizardMainWindow * mainWindow, ActionCreationState * parent);
 
+    /**  Destructor */
     ~ActionClassificationState();
 
     void resetDomAction(cepcoreschema::Action * domAction);
