@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -32,12 +32,11 @@
 // Qt files
 #include <QMessageBox>
 
-/**  Constructor */
 ActionClassificationWidget::ActionClassificationWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
     setToDefault();
 }
-/**  Destructor */
+
 ActionClassificationWidget::~ActionClassificationWidget() {}
 
 void ActionClassificationWidget::setToDefault() {
@@ -57,7 +56,8 @@ void ActionClassificationWidget::setToDefault() {
 
 void ActionClassificationWidget::nextButtonClicked() {
     QString family = ui.actionFamilyItself->text();
-    if (family.toUtf8() != family.toAscii()) {
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
+    if (family.toUtf8() != family.toLatin1()) {
         ui.actionFamilyStar->setStyleSheet(enhancedStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultAscii);
@@ -74,6 +74,9 @@ void ActionClassificationWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(normalStyle);
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void ActionClassificationWidget::previousButtonClicked() {
@@ -91,7 +94,7 @@ bool ActionClassificationWidget::isOneNonAsciiTag() {
 
     while ((it != list.end()) && (! oneNonAscii)) {
         QString tag = (*it)->getTag();
-        if (tag.toUtf8() != tag.toAscii()) {
+        if (tag.toUtf8() != tag.toLatin1()) {
             oneNonAscii = true;
         }
         it++;
