@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,7 +25,7 @@
 
 // Include .h file
 #include "ActionCreationState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ActionExtensionCreationState.h"
 
 #include "ActionDescriptionWidget.h"
@@ -44,8 +44,8 @@
 #include <QMessageBox>
 #include <iostream>
 
-/**  Constructor */
-ActionCreationState::ActionCreationState(QString name, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent) : QState(parent) {
+
+ActionCreationState::ActionCreationState(QString name, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent) : QState(parent) {
     this->name = name;
     this->cancelled = false;
     this->domAction = NULL;
@@ -57,7 +57,7 @@ ActionCreationState::ActionCreationState(QString name, DorothyMainWindow * mainW
 }
 
 
-/**  Destructor */
+
 ActionCreationState::~ActionCreationState() {}
 
 void ActionCreationState::resetDomActionExtension(cepcoreschema::ActionExtension *domActionExtension) {
@@ -102,7 +102,7 @@ void ActionCreationState::actionCancelled() {
     emit nextACS();
 }
 
-void ActionCreationState::createSubStates(DorothyMainWindow * mainWindow) {
+void ActionCreationState::createSubStates(WizardMainWindow * mainWindow) {
     actionDescriptionWidget = new ActionDescriptionWidget(NULL);
     actionDescriptionState = new ActionDescriptionState("Action Description",  actionDescriptionWidget, mainWindow, domCep, this);
 
