@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,7 +28,7 @@
 #include <QState>
 #include <QWidget>
 
-class DorothyMainWindow;
+class WizardMainWindow;
 class ActionExtensionCreationState;
 
 // Sub-states
@@ -53,7 +53,9 @@ class Cep;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to create one action.
+ *
+ * This state manages sub-state to create one action.
  *
  */
 class  ActionCreationState : public QState  {
@@ -61,7 +63,9 @@ class  ActionCreationState : public QState  {
     Q_OBJECT;
 
 public:
-    ActionCreationState(QString name, DorothyMainWindow * mainWidnow, cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent);
+    /**  Constructor */
+    ActionCreationState(QString name, WizardMainWindow * mainWidnow, cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent);
+    /**  Destructor */
     ~ActionCreationState();
 
     void resetDomActionExtension(cepcoreschema::ActionExtension * domActionExtension);
@@ -93,7 +97,7 @@ protected:
 
 
 private:
-    void createSubStates(DorothyMainWindow * mainWindow);
+    void createSubStates(WizardMainWindow * mainWindow);
 
     bool cancelled;
     QString name;
