@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,7 +26,7 @@
 // Include .h file
 #include "ActionDescriptionState.h"
 #include "ActionDescriptionWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ActionCreationState.h"
 
 // includes from coreschema
@@ -42,14 +42,14 @@
 // temporary
 #include <iostream>
 
-/**  Constructor */
-ActionDescriptionState::ActionDescriptionState(QString name, ActionDescriptionWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, ActionCreationState * parent)
+
+ActionDescriptionState::ActionDescriptionState(QString name, ActionDescriptionWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, ActionCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domAction = NULL;
     this->domActionExtension = NULL;
     this->domCep = domCep;
 }
-/**  Destructor */
+
 ActionDescriptionState::~ActionDescriptionState() {}
 
 void ActionDescriptionState::resetDomAction(cepcoreschema::Action * domAction, cepcoreschema::ActionExtension * domActionExtension) {
@@ -74,13 +74,20 @@ void ActionDescriptionState::onEntry(QEvent *event) {
         }
 
         // Check existing CEP components
+        // CS: problem to get components name.
+        // The loop was under component extension, the corresction is to loop under components for each componentExtension.
         if (domCep->componentExtensions().present()) {
-            cepcoreschema::ComponentExtensions::componentExtension_sequence cepComponents = domCep->componentExtensions().get().componentExtension();
-            cepcoreschema::ComponentExtensions::componentExtension_iterator it;
-            for (it = cepComponents.begin(); it != cepComponents.end(); it++) {
-                QString componentName = (*it).name().c_str();
-                componentName = ClassNameHandler::getClassName(componentName);
-                actionDescriptionWidget->addPossibleComponent(componentName);
+            cepcoreschema::ComponentExtensions::componentExtension_sequence cepComponentExtensions = domCep->componentExtensions().get().componentExtension();
+            cepcoreschema::ComponentExtensions::componentExtension_iterator itCompExt;
+            // Loop on ComponentExtensions
+            for (itCompExt = cepComponentExtensions.begin(); itCompExt != cepComponentExtensions.end(); itCompExt++) {
+                cepcoreschema::Components::component_iterator itComp;
+                // Loop on components for each componentExtension.
+                for (itComp = itCompExt->components().component().begin(); itComp != itCompExt->components().component().end(); itComp++) {
+                    QString componentName = (*itComp).name().c_str();
+                    componentName = ClassNameHandler::getClassName(componentName);
+                    actionDescriptionWidget->addPossibleComponent(componentName);
+                }
             }
         }
     }
