@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ class Cep;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to describe action
  *
  */
 class ActionDescriptionState : public WizardState  {
@@ -50,8 +50,10 @@ class ActionDescriptionState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ActionDescriptionState(QString name, ActionDescriptionWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep,ActionCreationState * parent);
+    /**  Constructor */
+    ActionDescriptionState(QString name, ActionDescriptionWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep,ActionCreationState * parent);
 
+    /**  Destructor */
     ~ActionDescriptionState();
 
     void resetDomAction(cepcoreschema::Action * domAction, cepcoreschema::ActionExtension * domActionExtension);
