@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -32,17 +32,18 @@
 #include <QMessageBox>
 #include <QStringList>
 
-/**  Constructor */
+
 ActionDescriptionWidget::ActionDescriptionWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
     setToDefault(defaultActionExtensionName);
 }
-/**  Destructor */
+
 ActionDescriptionWidget::~ActionDescriptionWidget() {}
 
 void ActionDescriptionWidget::nextButtonClicked() {
     QString actionName = ui.actionNameItself->text();
     QString actionDescription = ui.actionGoalItself->toPlainText();
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
     if (actionName == actionExtensionName) {
         ui.actionNameStar->setStyleSheet(enhancedStyle);
         ui.actionGoalStar->setStyleSheet(normalStyle);
@@ -50,7 +51,7 @@ void ActionDescriptionWidget::nextButtonClicked() {
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultActionNameAndExtension);
 
-    } else if (actionName.toUtf8() != actionName.toAscii()) {
+    } else if (actionName.toUtf8() != actionName.toLatin1()) {
         ui.actionNameStar->setStyleSheet(enhancedStyle);
         ui.actionGoalStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -62,7 +63,7 @@ void ActionDescriptionWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealActionName);
-    } else if (actionDescription.toUtf8() != actionDescription.toAscii()) {
+    } else if (actionDescription.toUtf8() != actionDescription.toLatin1()) {
         ui.actionNameStar->setStyleSheet(normalStyle);
         ui.actionGoalStar->setStyleSheet(enhancedStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -77,6 +78,9 @@ void ActionDescriptionWidget::nextButtonClicked() {
     } else {
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void ActionDescriptionWidget::cancelButtonClicked() {
