@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,7 +25,7 @@
 
 // Include .h file
 #include "ActionExtensionCreationState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 #include "ActionExtensionDescriptionWidget.h"
 #include "ActionExtensionDescriptionState.h"
@@ -44,8 +44,8 @@
 #include <QMessageBox>
 #include <iostream>
 
-/**  Constructor */
-ActionExtensionCreationState::ActionExtensionCreationState(QString name, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep) : QState() {
+
+ActionExtensionCreationState::ActionExtensionCreationState(QString name, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep) : QState() {
     this->cancelled = false;
     this->name = name;
     this->domCep = domCep;
@@ -55,7 +55,7 @@ ActionExtensionCreationState::ActionExtensionCreationState(QString name, Dorothy
 }
 
 
-/**  Destructor */
+
 ActionExtensionCreationState::~ActionExtensionCreationState() {}
 
 
@@ -106,7 +106,7 @@ void ActionExtensionCreationState::extensionCancelled() {
     emit next();
 }
 
-void ActionExtensionCreationState::createSubStates(DorothyMainWindow * mainWindow) {
+void ActionExtensionCreationState::createSubStates(WizardMainWindow * mainWindow) {
     actionExtensionDescriptionWidget = new ActionExtensionDescriptionWidget(NULL);
     actionExtensionDescriptionState = new ActionExtensionDescriptionState("Action Extension",  actionExtensionDescriptionWidget, mainWindow, this);
 
