@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,7 +28,7 @@
 #include <QState>
 #include <QWidget>
 
-class DorothyMainWindow;
+class WizardMainWindow;
 // Sub states
 class ActionExtensionDescriptionWidget;
 class ActionExtensionDescriptionState;
@@ -51,7 +51,10 @@ class ActionExtension;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to create an action extension. \n
+ *
+ * This state enables to create all states to generate one or more actions. \n
+ * It manages a sub-states dedicated to the creation of actions.
  *
  */
 class  ActionExtensionCreationState : public QState  {
@@ -59,7 +62,9 @@ class  ActionExtensionCreationState : public QState  {
     Q_OBJECT;
 
 public:
-    ActionExtensionCreationState(QString name, DorothyMainWindow * mainWidnow, cepcoreschema::Cep * domCep);
+    /**  Constructor */
+    ActionExtensionCreationState(QString name, WizardMainWindow * mainWidnow, cepcoreschema::Cep * domCep);
+    /**  Destructor */
     ~ActionExtensionCreationState();
 
 signals:
@@ -92,7 +97,7 @@ private:
     ExtensionSummaryWidget            * actionExtensionSummaryWidget;
     ExtensionSummaryState             * actionExtensionSummaryState;
 
-    void createSubStates(DorothyMainWindow * mainWindow);
+    void createSubStates(WizardMainWindow * mainWindow);
 
     QString name;
     cepcoreschema::Cep * domCep;
