@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,7 +25,7 @@
 
 // Include .h file
 #include "ActionExtensionDependenciesState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ActionExtensionCreationState.h"
 #include "DependenciesWidget.h"
 
@@ -34,14 +34,14 @@
 #include <Actions.hxx>
 #include <Action.hxx>
 
-/**  Constructor */
-ActionExtensionDependenciesState::ActionExtensionDependenciesState(QString name, DependenciesWidget * widget, DorothyMainWindow * mainWindow,  cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent)
+
+ActionExtensionDependenciesState::ActionExtensionDependenciesState(QString name, DependenciesWidget * widget, WizardMainWindow * mainWindow,  cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent)
     : DependenciesState(name, widget, mainWindow, domCep, parent) {
     this->domActionExtension = NULL;
     widget->setElement("Action Extension");
 }
 
-/**  Destructor */
+
 ActionExtensionDependenciesState::~ActionExtensionDependenciesState() {}
 
 void ActionExtensionDependenciesState::resetDomActionExtension(cepcoreschema::ActionExtension * domActionExtension) {
