@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ class ActionExtension;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to define action extension dependencies
  *
  */
 class ActionExtensionDependenciesState : public DependenciesState  {
@@ -47,8 +47,10 @@ class ActionExtensionDependenciesState : public DependenciesState  {
     Q_OBJECT;
 
 public:
-    ActionExtensionDependenciesState(QString name, DependenciesWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent);
+    /**  Constructor */
+    ActionExtensionDependenciesState(QString name, DependenciesWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, ActionExtensionCreationState * parent);
 
+    /**  Destructor */
     ~ActionExtensionDependenciesState();
 
     void resetDomActionExtension(cepcoreschema::ActionExtension * domActionExtension);
