@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,11 +31,11 @@
 // Qt files
 #include <QMessageBox>
 
-/**  Constructor */
+
 ActionExtensionDescriptionWidget::ActionExtensionDescriptionWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
 }
-/**  Destructor */
+
 ActionExtensionDescriptionWidget::~ActionExtensionDescriptionWidget() {}
 
 void ActionExtensionDescriptionWidget::cancelButtonClicked() {
@@ -46,7 +46,8 @@ void ActionExtensionDescriptionWidget::nextButtonClicked() {
     QString actionExtensionName = ui.actionExtensionNameItself->text();
     QString actionExtensionDescription = ui.actionExtensionDescriptionItself->toPlainText();
 
-    if (actionExtensionName.toUtf8() != actionExtensionName.toAscii()) {
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
+    if (actionExtensionName.toUtf8() != actionExtensionName.toLatin1()) {
         ui.actionExtensionNameStar->setStyleSheet(enhancedStyle);
         ui.actionExtensionDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -56,7 +57,7 @@ void ActionExtensionDescriptionWidget::nextButtonClicked() {
         ui.actionExtensionDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealExtensionName);
-    } else if (actionExtensionDescription.toUtf8() != actionExtensionDescription.toAscii()) {
+    } else if (actionExtensionDescription.toUtf8() != actionExtensionDescription.toLatin1()) {
         ui.actionExtensionNameStar->setStyleSheet(normalStyle);
         ui.actionExtensionDescriptionStar->setStyleSheet(enhancedStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -72,6 +73,9 @@ void ActionExtensionDescriptionWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(normalStyle);
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void ActionExtensionDescriptionWidget::setToDefault() {
