@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,7 +27,7 @@
 #include "ActionSummaryState.h"
 #include "ActionSummaryWidget.h"
 
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 // includes from coreschema
 #include <Action.hxx>
@@ -35,7 +35,7 @@
 #include <iostream>
 
 ActionSummaryState::ActionSummaryState(QString name, ActionSummaryWidget * widget,
-                                       DorothyMainWindow * mainWindow, QState * parent)
+                                       WizardMainWindow * mainWindow, QState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domAction = NULL;
 }
