@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ class Action;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to summarize the created action
  *
  */
 class ActionSummaryState : public WizardState  {
@@ -47,8 +47,10 @@ class ActionSummaryState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ActionSummaryState(QString name, ActionSummaryWidget * widget, DorothyMainWindow * mainWindow, QState * parent);
+    /** Constructor*/
+    ActionSummaryState(QString name, ActionSummaryWidget * widget, WizardMainWindow * mainWindow, QState * parent);
 
+    /** Destructor*/
     ~ActionSummaryState();
 
     void resetAction(cepcoreschema::Action * domAction);
