@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,20 +26,20 @@
 // Include .h file
 #include "ActionsCreationState.h"
 #include "ActionsCreationWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ActionExtensionCreationState.h"
 
 // includes from coreschema
 #include <ActionExtension.hxx>
 #include <Actions.hxx>
 
-/**  Constructor */
-ActionsCreationState::ActionsCreationState(QString name, ActionsCreationWidget * widget, DorothyMainWindow * mainWindow, ActionExtensionCreationState * parent)
+
+ActionsCreationState::ActionsCreationState(QString name, ActionsCreationWidget * widget, WizardMainWindow * mainWindow, ActionExtensionCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domActionExtension = NULL;
 }
 
-/**  Destructor */
+
 ActionsCreationState::~ActionsCreationState() {}
 
 void ActionsCreationState::resetDomActionExtension(cepcoreschema::ActionExtension * domActionExtension) {
