@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -40,7 +40,7 @@ class ActionExtension;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to create actions
  *
  */
 class ActionsCreationState : public WizardState  {
@@ -48,8 +48,10 @@ class ActionsCreationState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ActionsCreationState(QString name, ActionsCreationWidget * widget, DorothyMainWindow * mainWindow, ActionExtensionCreationState * parent);
+    /**  Constructor */
+    ActionsCreationState(QString name, ActionsCreationWidget * widget, WizardMainWindow * mainWindow, ActionExtensionCreationState * parent);
 
+    /**  Destructor */
     ~ActionsCreationState();
 
     void resetDomActionExtension(cepcoreschema::ActionExtension * domActionExtension);
