@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,11 +31,11 @@
 #include <QMessageBox>
 
 
-/**  Constructor */
+
 ActionsCreationWidget::ActionsCreationWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
 }
-/**  Destructor */
+
 ActionsCreationWidget::~ActionsCreationWidget() {}
 
 void ActionsCreationWidget::setToDefault() {
@@ -46,6 +46,7 @@ void ActionsCreationWidget::setToDefault() {
 
 void ActionsCreationWidget::nextButtonClicked() {
     // check if at least an action has been created
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
     if (createdActions.isEmpty()) {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         ui.label_Star->setStyleSheet(enhancedStyle);
@@ -55,6 +56,9 @@ void ActionsCreationWidget::nextButtonClicked() {
         ui.label_Star->setStyleSheet(normalStyle);
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void ActionsCreationWidget::addActionClicked() {
