@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -38,7 +38,7 @@ class Cep;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State of the contact of the creator of the CEP
  *
  */
 class CepContactState  : public WizardState  {
@@ -46,7 +46,9 @@ class CepContactState  : public WizardState  {
     Q_OBJECT;
 
 public:
-    CepContactState(QString name, CepContactWidget * widget, DorothyMainWindow * mainWidnow, cepcoreschema::Cep * domCep);
+    /**  Constructor */
+    CepContactState(QString name, CepContactWidget * widget, WizardMainWindow * mainWidnow, cepcoreschema::Cep * domCep);
+    /**  Destructor */
     ~CepContactState();
 
 protected:
