@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -33,7 +33,7 @@
 
 #include <iostream>
 
-/**  Constructor */
+
 CepContactWidget::CepContactWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
     ui.cepContactLineEdit->setText(defaultContact);
@@ -42,16 +42,17 @@ CepContactWidget::CepContactWidget(QWidget * parent) : QWidget(parent) {
 
     ui.userDefTextEdit->setVisible(false);
 }
-/**  Destructor */
+
 CepContactWidget::~CepContactWidget() {}
 
 void CepContactWidget::nextButtonClicked() {
     QString contact = ui.cepContactLineEdit->text();
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
     if (contact.isEmpty() || contact == defaultContact || !contact.contains("@")) {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         ui.cepContactStar->setStyleSheet(enhancedStyle);
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealContact);
-    } else if (contact.toUtf8() != contact.toAscii()) {
+    } else if (contact.toUtf8() != contact.toLatin1()) {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         ui.cepContactStar->setStyleSheet(enhancedStyle);
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultAscii);
@@ -60,6 +61,9 @@ void CepContactWidget::nextButtonClicked() {
         ui.cepContactStar->setStyleSheet(normalStyle);
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void CepContactWidget::previousButtonClicked() {
@@ -86,7 +90,6 @@ bool CepContactWidget::hasUserLicence() {
 
 QString CepContactWidget::getUserLicence() {
     QString userLicence = ui.userDefTextEdit->toPlainText();
-    userLicence = " <![CDATA[ " + userLicence + " ]]> ";
     std::cout << "licence: \n" << userLicence.toStdString() << std::endl;
     return userLicence;
 }
