@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,7 +26,7 @@
 // Include .h file
 #include "CepCreateRecapState.h"
 #include "CepCreateRecapWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 // includes from coreschema
 #include <Cep.hxx>
@@ -37,12 +37,12 @@
 // temporary include
 #include <iostream>
 
-/**  Constructor */
-CepCreateRecapState::CepCreateRecapState(QString name, CepCreateRecapWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep)
+
+CepCreateRecapState::CepCreateRecapState(QString name, CepCreateRecapWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep)
     : WizardState(name, widget, mainWindow) {
     this->domCep = domCep;
 }
-/**  Destructor */
+
 CepCreateRecapState::~CepCreateRecapState() {}
 
 
