@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -29,12 +29,12 @@
 
 #include <iostream>
 
-/**  Constructor */
-CepCreationDirectoryState::CepCreationDirectoryState(QString name, CepCreationDirectoryWidget * widget, DorothyMainWindow * mainWindow, QString * devDirName) :
+
+CepCreationDirectoryState::CepCreationDirectoryState(QString name, CepCreationDirectoryWidget * widget, WizardMainWindow * mainWindow, QString * devDirName) :
     WizardState(name, widget, mainWindow) {
     this->devDirName = devDirName;
 }
-/**  Destructor */
+
 CepCreationDirectoryState::~CepCreationDirectoryState() {}
 
 
