@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -33,7 +33,7 @@ class CepCreationDirectoryWidget;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to define the directory of the CEP.
  *
  */
 class  CepCreationDirectoryState : public WizardState  {
@@ -41,7 +41,9 @@ class  CepCreationDirectoryState : public WizardState  {
     Q_OBJECT;
 
 public:
-    CepCreationDirectoryState(QString name, CepCreationDirectoryWidget * widget, DorothyMainWindow * mainWidnow, QString * devDirName);
+    /**  Constructor */
+    CepCreationDirectoryState(QString name, CepCreationDirectoryWidget * widget, WizardMainWindow * mainWidnow, QString * devDirName);
+    /**  Destructor */
     ~CepCreationDirectoryState();
 
 protected:
