@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,11 +30,11 @@
 #include <QMessageBox>
 #include <QFileDialog>
 
-/**  Constructor */
+
 CepCreationDirectoryWidget::CepCreationDirectoryWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
 }
-/**  Destructor */
+
 CepCreationDirectoryWidget::~CepCreationDirectoryWidget() {}
 
 void CepCreationDirectoryWidget::nextButtonClicked() {
@@ -42,16 +42,23 @@ void CepCreationDirectoryWidget::nextButtonClicked() {
     QString enteredDir = ui.inputDirectoryLineEdit->text();
     QFileInfo devDir(enteredDir);
     // Message if the field is empty (no development directory)
+
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
     if ((enteredDir == "") || (!devDir.isDir())) {
+
         ui.selectLabel->setStyleSheet("QLabel { background-color : red; color : yellow; }");
         ui.requiredLabel->setStyleSheet("QLabel { background-color : red; color : yellow; }");
         int ret = QMessageBox::warning(this, tr("Before going further..."), tr("Please select a valid development directory\n"));
+
     } else {
         ui.selectLabel->setStyleSheet("QLabel { background-color : none; color : black; }");
         ui.requiredLabel->setStyleSheet("QLabel { background-color : none; color : black; }");
         emit next();
 
     }
+#else
+    emit next();
+#endif
 
 }
 
