@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,17 +26,17 @@
 // Include .h file
 #include "CepDescriptionState.h"
 #include "CepDescriptionWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 // includes from coreschema
 #include <Cep.hxx>
 
-/**  Constructor */
-CepDescriptionState::CepDescriptionState(QString name, CepDescriptionWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep)
+
+CepDescriptionState::CepDescriptionState(QString name, CepDescriptionWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep)
     : WizardState(name, widget, mainWindow) {
     this->domCep = domCep;
 }
-/**  Destructor */
+
 CepDescriptionState::~CepDescriptionState() {}
 
 void CepDescriptionState::onExit( QEvent * event ) {
