@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -33,27 +33,27 @@
 
 
 
-/**  Constructor */
+
 CepDescriptionWidget::CepDescriptionWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
     ui.cepNameLineEdit->setText(defaultCepName);
     ui.cepDescriptionTextEdit->setHtml(defaultCepDescription);
 }
 
-/**  Destructor */
 CepDescriptionWidget::~CepDescriptionWidget() {}
 
 void CepDescriptionWidget::nextButtonClicked() {
     QString cepName = ui.cepNameLineEdit->text();
 
     QString cepDescription = ui.cepDescriptionTextEdit->toPlainText();
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
     if (cepName.isEmpty() ||cepName == defaultCepName) {
         ui.cepDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         ui.cepNameStar->setStyleSheet(enhancedStyle);
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealCepName);
-    } else if (cepName.toUtf8() != cepName.toAscii()) {
+    } else if (cepName.toUtf8() != cepName.toLatin1()) {
         ui.cepDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         ui.cepNameStar->setStyleSheet(enhancedStyle);
@@ -65,7 +65,7 @@ void CepDescriptionWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealCepDescription);
-    } else if (cepDescription.toUtf8() != cepDescription.toAscii()) {
+    } else if (cepDescription.toUtf8() != cepDescription.toLatin1()) {
         ui.cepNameStar->setStyleSheet(normalStyle);
         ui.cepDescriptionStar->setStyleSheet(enhancedStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -77,6 +77,9 @@ void CepDescriptionWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(normalStyle);
         emit next();
     }
+#else
+    emit next();
+#endif
 
 }
 
