@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,7 +27,7 @@
 #include "ComponentAddPropertyState.h"
 #include "ComponentAddPropertyWidget.h"
 #include "ComponentPropertyWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ComponentCreationState.h"
 
 // includes from coreschema
@@ -36,12 +36,12 @@
 #include <Parameter.hxx>
 
 
-/**  Constructor */
-ComponentAddPropertyState::ComponentAddPropertyState(QString name, ComponentAddPropertyWidget * widget, DorothyMainWindow * mainWindow, ComponentCreationState * parent)
+
+ComponentAddPropertyState::ComponentAddPropertyState(QString name, ComponentAddPropertyWidget * widget, WizardMainWindow * mainWindow, ComponentCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domComponent = NULL;
 }
-/**  Destructor */
+
 ComponentAddPropertyState::~ComponentAddPropertyState() {}
 
 void ComponentAddPropertyState::resetDomComponent(cepcoreschema::Component * domComponent) {
