@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -43,7 +43,7 @@ class Component;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to add a property to a component
  *
  */
 class ComponentAddPropertyState : public WizardState  {
@@ -51,7 +51,9 @@ class ComponentAddPropertyState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ComponentAddPropertyState(QString name, ComponentAddPropertyWidget * widget, DorothyMainWindow * mainWindow, ComponentCreationState * parent);
+    /**  Constructor */
+    ComponentAddPropertyState(QString name, ComponentAddPropertyWidget * widget, WizardMainWindow * mainWindow, ComponentCreationState * parent);
+    /**  Destructor */
     ~ComponentAddPropertyState();
 
     void resetDomComponent(cepcoreschema::Component * domComponent);
