@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,17 +39,18 @@
 #include <sstream>
 
 
-/**  Constructor */
+
 ComponentAddPropertyWidget::ComponentAddPropertyWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
     setToDefault();
 }
-/**  Destructor */
+
 ComponentAddPropertyWidget::~ComponentAddPropertyWidget() {
 
 }
 
 void ComponentAddPropertyWidget::nextButtonClicked() {
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
     if (isOneNonAsciiParameter()) {
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultAscii);
     } else if (isOneNoName()) {
@@ -57,6 +58,9 @@ void ComponentAddPropertyWidget::nextButtonClicked() {
     } else {
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void ComponentAddPropertyWidget::previousButtonClicked() {
@@ -93,10 +97,10 @@ bool ComponentAddPropertyWidget::isOneNonAsciiParameter() {
         QString paramDescription = (*it)->getDescription();
         QString paramDefaultValue = (*it)->getDefaultValue();
 
-        if ((paramName.toUtf8() != paramName.toAscii()) ||
-                (paramType.toUtf8() != paramType.toAscii()) ||
-                (paramDescription.toUtf8() != paramDescription.toAscii()) ||
-                (paramDefaultValue.toUtf8() != paramDefaultValue.toAscii())) {
+        if ((paramName.toUtf8() != paramName.toLatin1()) ||
+                (paramType.toUtf8() != paramType.toLatin1()) ||
+                (paramDescription.toUtf8() != paramDescription.toLatin1()) ||
+                (paramDefaultValue.toUtf8() != paramDefaultValue.toLatin1())) {
             oneNonAscii = true;
         }
         it++;
