@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,7 +25,7 @@
 
 // Include .h file
 #include "ComponentCreationState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ComponentExtensionCreationState.h"
 
 #include "ComponentDescriptionWidget.h"
@@ -42,7 +42,7 @@
 #include <iostream>
 
 /**  Constructor */
-ComponentCreationState::ComponentCreationState(QString name, DorothyMainWindow * mainWindow, ComponentExtensionCreationState * parent)
+ComponentCreationState::ComponentCreationState(QString name, WizardMainWindow * mainWindow, ComponentExtensionCreationState * parent)
     : QState(parent) {
     this->name = name;
     this->cancelled = false;
@@ -98,7 +98,7 @@ void ComponentCreationState::componentCancelled() {
     emit nextCCS();
 }
 
-void ComponentCreationState::createSubStates(DorothyMainWindow * mainWindow) {
+void ComponentCreationState::createSubStates(WizardMainWindow * mainWindow) {
     componentDescriptionWidget = new ComponentDescriptionWidget(NULL);
     componentDescriptionState = new ComponentDescriptionState("Component Description",componentDescriptionWidget, mainWindow, this);
 
