@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,7 +26,7 @@
 // Include .h file
 #include "ComponentDescriptionState.h"
 #include "ComponentDescriptionWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ComponentCreationState.h"
 
 // includes from coreschema
@@ -36,14 +36,13 @@
 // temporary
 #include <iostream>
 
-/**  Constructor */
-ComponentDescriptionState::ComponentDescriptionState(QString name, ComponentDescriptionWidget * widget, DorothyMainWindow * mainWindow,  ComponentCreationState * parent)
+ComponentDescriptionState::ComponentDescriptionState(QString name, ComponentDescriptionWidget * widget, WizardMainWindow * mainWindow,  ComponentCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domComponent = NULL;
     this->domComponentExtension = NULL;
 }
 
-/**  Destructor */
+
 ComponentDescriptionState::~ComponentDescriptionState() {}
 
 void ComponentDescriptionState::resetDomComponent(cepcoreschema::Component *domComponent, cepcoreschema::ComponentExtension *domComponentExtension) {
