@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -41,7 +41,7 @@ class ComponentExtension;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to describe component
  *
  */
 class ComponentDescriptionState : public WizardState  {
@@ -49,8 +49,11 @@ class ComponentDescriptionState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ComponentDescriptionState(QString name, ComponentDescriptionWidget * widget, DorothyMainWindow * mainWindow, ComponentCreationState * parent);
 
+    /**  Constructor */
+    ComponentDescriptionState(QString name, ComponentDescriptionWidget * widget, WizardMainWindow * mainWindow, ComponentCreationState * parent);
+
+    /**  Destructor */
     ~ComponentDescriptionState();
 
     void resetDomComponent(cepcoreschema::Component * domComponent, cepcoreschema::ComponentExtension * domComponentExtension);
