@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,13 +31,12 @@
 // Qt files
 #include <QMessageBox>
 
-/**  Constructor */
 ComponentDescriptionWidget::ComponentDescriptionWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
     setToDefault(defaultComponentExtensionName);
 
 }
-/**  Destructor */
+
 ComponentDescriptionWidget::~ComponentDescriptionWidget() {}
 
 
@@ -46,6 +45,8 @@ void ComponentDescriptionWidget::nextButtonClicked() {
     QString componentDescription = ui.componentDescriptionItself->toPlainText();
     QString fileSuffix = ui.suffixItself->text();
 
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
+
     if (componentName == componentExtensionName) {
         ui.componentNameStar->setStyleSheet(enhancedStyle);
         ui.componentDescriptionStar->setStyleSheet(normalStyle);
@@ -53,7 +54,7 @@ void ComponentDescriptionWidget::nextButtonClicked() {
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultComponentNameAndExtension);
 
-    } else if (componentName.toUtf8() != componentName.toAscii()) {
+    } else if (componentName.toUtf8() != componentName.toLatin1()) {
         ui.componentNameStar->setStyleSheet(enhancedStyle);
         ui.componentDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -65,7 +66,7 @@ void ComponentDescriptionWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealComponentName);
-    } else if (componentDescription.toUtf8() != componentDescription.toAscii()) {
+    } else if (componentDescription.toUtf8() != componentDescription.toLatin1()) {
         ui.componentNameStar->setStyleSheet(normalStyle);
         ui.componentDescriptionStar->setStyleSheet(enhancedStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -77,7 +78,7 @@ void ComponentDescriptionWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealComponentDescription);
-    } else if (fileSuffix.toUtf8() != fileSuffix.toAscii()) {
+    } else if (fileSuffix.toUtf8() != fileSuffix.toLatin1()) {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         ui.componentNameStar->setStyleSheet(normalStyle);
         ui.componentDescriptionStar->setStyleSheet(normalStyle);
@@ -95,6 +96,9 @@ void ComponentDescriptionWidget::nextButtonClicked() {
     else {
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void ComponentDescriptionWidget::cancelButtonClicked() {
