@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,7 +25,7 @@
 
 // Include .h file
 #include "ComponentExtensionCreationState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 #include "ComponentExtensionDescriptionWidget.h"
 #include "ComponentExtensionDescriptionState.h"
@@ -44,8 +44,8 @@
 #include <QMessageBox>
 #include <iostream>
 
-/**  Constructor */
-ComponentExtensionCreationState::ComponentExtensionCreationState(QString name, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep) : QState() {
+
+ComponentExtensionCreationState::ComponentExtensionCreationState(QString name, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep) : QState() {
     this->cancelled = false;
     this->name = name;
     this->domCep = domCep;
@@ -55,7 +55,7 @@ ComponentExtensionCreationState::ComponentExtensionCreationState(QString name, D
 }
 
 
-/**  Destructor */
+
 ComponentExtensionCreationState::~ComponentExtensionCreationState() {}
 
 
@@ -109,7 +109,7 @@ void ComponentExtensionCreationState::extensionCancelled() {
 }
 
 
-void ComponentExtensionCreationState::createSubStates(DorothyMainWindow * mainWindow) {
+void ComponentExtensionCreationState::createSubStates(WizardMainWindow * mainWindow) {
     componentExtensionDescriptionWidget = new ComponentExtensionDescriptionWidget(NULL);
     componentExtensionDescriptionState  = new ComponentExtensionDescriptionState("Component Extension",  componentExtensionDescriptionWidget, mainWindow, this);
 
