@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,7 +28,7 @@
 #include <QState>
 #include <QWidget>
 
-class DorothyMainWindow;
+class WizardMainWindow;
 // Sub States
 class ComponentExtensionDescriptionWidget;
 class ComponentExtensionDescriptionState;
@@ -51,7 +51,7 @@ class ComponentExtension;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to create component extension.
  *
  */
 class  ComponentExtensionCreationState : public QState  {
@@ -59,7 +59,9 @@ class  ComponentExtensionCreationState : public QState  {
     Q_OBJECT;
 
 public:
-    ComponentExtensionCreationState(QString name, DorothyMainWindow * mainWidnow, cepcoreschema::Cep * domCep);
+    /**  Constructor */
+    ComponentExtensionCreationState(QString name, WizardMainWindow * mainWidnow, cepcoreschema::Cep * domCep);
+    /**  Destructor */
     ~ComponentExtensionCreationState();
 
 signals:
@@ -93,7 +95,7 @@ private:
     ExtensionSummaryState                * componentExtensionSummaryState;
 
 
-    void createSubStates(DorothyMainWindow * mainWindow);
+    void createSubStates(WizardMainWindow * mainWindow);
 
     QString name;
     cepcoreschema::Cep * domCep;
