@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,7 +25,7 @@
 
 // Include .h file
 #include "ComponentExtensionDependenciesState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ComponentExtensionCreationState.h"
 #include "DependenciesWidget.h"
 
@@ -34,14 +34,14 @@
 #include <Components.hxx>
 #include <Component.hxx>
 
-/**  Constructor */
-ComponentExtensionDependenciesState::ComponentExtensionDependenciesState(QString name, DependenciesWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, ComponentExtensionCreationState * parent)
+
+ComponentExtensionDependenciesState::ComponentExtensionDependenciesState(QString name, DependenciesWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, ComponentExtensionCreationState * parent)
     : DependenciesState(name, widget, mainWindow, domCep, parent) {
     this->domComponentExtension = NULL;
     widget->setElement("Component Extension");
 }
 
-/**  Destructor */
+
 ComponentExtensionDependenciesState::~ComponentExtensionDependenciesState() {}
 
 void ComponentExtensionDependenciesState::resetDomComponentExtension(cepcoreschema::ComponentExtension *domComponentExtension) {
