@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ class ComponentExtension;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to define dependencies to the component extension
  *
  */
 class ComponentExtensionDependenciesState : public DependenciesState  {
@@ -47,8 +47,10 @@ class ComponentExtensionDependenciesState : public DependenciesState  {
     Q_OBJECT;
 
 public:
-    ComponentExtensionDependenciesState(QString name, DependenciesWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, ComponentExtensionCreationState * parent);
+    /**  Constructor */
+    ComponentExtensionDependenciesState(QString name, DependenciesWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, ComponentExtensionCreationState * parent);
 
+    /**  Destructor */
     ~ComponentExtensionDependenciesState();
 
     void resetDomComponentExtension(cepcoreschema::ComponentExtension * domComponentExtension);
