@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,18 +26,18 @@
 // Include .h file
 #include "ComponentExtensionDescriptionState.h"
 #include "ComponentExtensionDescriptionWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ComponentExtensionCreationState.h"
 
 // includes from coreschema
 #include <ComponentExtension.hxx>
 
-/**  Constructor */
-ComponentExtensionDescriptionState::ComponentExtensionDescriptionState(QString name, ComponentExtensionDescriptionWidget * widget, DorothyMainWindow * mainWindow, ComponentExtensionCreationState * parent)
+
+ComponentExtensionDescriptionState::ComponentExtensionDescriptionState(QString name, ComponentExtensionDescriptionWidget * widget, WizardMainWindow * mainWindow, ComponentExtensionCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domComponentExtension = NULL;
 }
-/**  Destructor */
+
 ComponentExtensionDescriptionState::~ComponentExtensionDescriptionState() {}
 
 void ComponentExtensionDescriptionState::resetDomComponentExtension(cepcoreschema::ComponentExtension * domComponentExtension) {
