@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,11 +31,11 @@
 // Qt files
 #include <QMessageBox>
 
-/**  Constructor */
+
 ComponentExtensionDescriptionWidget::ComponentExtensionDescriptionWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
 }
-/**  Destructor */
+
 ComponentExtensionDescriptionWidget::~ComponentExtensionDescriptionWidget() {}
 
 void ComponentExtensionDescriptionWidget::setToDefault() {
@@ -55,7 +55,8 @@ void ComponentExtensionDescriptionWidget::nextButtonClicked() {
     QString componentExtensionName = ui.componentExtensionNameItself->text();
     QString componentExtensionDescription = ui.componentExtensionDescriptionItself->toPlainText();
 
-    if (componentExtensionName.toUtf8() != componentExtensionName.toAscii()) {
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
+    if (componentExtensionName.toUtf8() != componentExtensionName.toLatin1()) {
         ui.componentExtensionNameStar->setStyleSheet(enhancedStyle);
         ui.componentExtensionDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -65,7 +66,7 @@ void ComponentExtensionDescriptionWidget::nextButtonClicked() {
         ui.componentExtensionDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealExtensionName);
-    } else if (componentExtensionDescription.toUtf8() != componentExtensionDescription.toAscii()) {
+    } else if (componentExtensionDescription.toUtf8() != componentExtensionDescription.toLatin1()) {
         ui.componentExtensionNameStar->setStyleSheet(normalStyle);
         ui.componentExtensionDescriptionStar->setStyleSheet(enhancedStyle);
         ui.requiredLabel->setStyleSheet(normalStyle);
@@ -86,6 +87,9 @@ void ComponentExtensionDescriptionWidget::nextButtonClicked() {
 
         emit next();
     }
+#else
+    emit next();
+#endif
 
 
 }
