@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,13 +27,13 @@
 #include "ComponentSummaryState.h"
 #include "ComponentSummaryWidget.h"
 
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 // includes from coreschema
 #include <Component.hxx>
 
 ComponentSummaryState::ComponentSummaryState(QString name, ComponentSummaryWidget * widget,
-        DorothyMainWindow * mainWindow, QState * parent)
+        WizardMainWindow * mainWindow, QState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domComponent = NULL;
 }
