@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,7 +39,7 @@ class Component;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to summarise component creation
  *
  */
 class ComponentSummaryState : public WizardState  {
@@ -47,8 +47,10 @@ class ComponentSummaryState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ComponentSummaryState(QString name, ComponentSummaryWidget * widget, DorothyMainWindow * mainWindow, QState * parent);
+    /** Constructor */
+    ComponentSummaryState(QString name, ComponentSummaryWidget * widget, WizardMainWindow * mainWindow, QState * parent);
 
+    /** Destructor */
     ~ComponentSummaryState();
 
     void resetComponent(cepcoreschema::Component * domComponent);
