@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,18 +26,18 @@
 // Include .h file
 #include "ComponentsCreationState.h"
 #include "ComponentsCreationWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ComponentExtensionCreationState.h"
 
 // includes from coreschema
 #include <ComponentExtension.hxx>
 
 /**  Constructor */
-ComponentsCreationState::ComponentsCreationState(QString name, ComponentsCreationWidget * widget, DorothyMainWindow * mainWindow, ComponentExtensionCreationState * parent)
+ComponentsCreationState::ComponentsCreationState(QString name, ComponentsCreationWidget * widget, WizardMainWindow * mainWindow, ComponentExtensionCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domComponentExtension = NULL;
 }
-/**  Destructor */
+
 ComponentsCreationState::~ComponentsCreationState() {}
 
 void ComponentsCreationState::resetDomComponentExtension(cepcoreschema::ComponentExtension *domComponentExtension) {
