@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,7 +26,7 @@
 // Include .h file
 #include "DependenciesState.h"
 #include "DependenciesWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "ActionExtensionDependenciesState.h"
 
 // Includes from cepgenerator
@@ -42,13 +42,12 @@
 // temporary include
 #include <iostream>
 
-/**  Constructor */
-DependenciesState::DependenciesState(QString name, DependenciesWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, QState * parent)
+
+DependenciesState::DependenciesState(QString name, DependenciesWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, QState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domCep = domCep;
 }
 
-/**  Destructor */
 DependenciesState::~DependenciesState() {}
 
 
