@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -40,7 +40,7 @@ class Dependencies;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * Basic state to define dependencies
  *
  */
 class DependenciesState : public WizardState  {
@@ -48,8 +48,9 @@ class DependenciesState : public WizardState  {
     Q_OBJECT;
 
 public:
-    DependenciesState(QString name, DependenciesWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, QState * parent);
-
+    /**  Constructor */
+    DependenciesState(QString name, DependenciesWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, QState * parent);
+    /**  Destructor */
     ~DependenciesState();
 
 protected:
