@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,7 +27,7 @@
 #include "ExtensionSummaryState.h"
 #include "ExtensionSummaryWidget.h"
 
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 // includes from coreschema
 #include <ActionExtension.hxx>
@@ -39,7 +39,7 @@
 #include <Component.hxx>
 
 ExtensionSummaryState::ExtensionSummaryState(QString name, ExtensionSummaryWidget * widget,
-        QString type, DorothyMainWindow * mainWindow, QState * parent)
+        QString type, WizardMainWindow * mainWindow, QState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->type = type;
     this->domActionExtension = NULL;
