@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -40,7 +40,7 @@ class ComponentExtension;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to summarize extension
  *
  */
 class ExtensionSummaryState : public WizardState  {
@@ -48,8 +48,10 @@ class ExtensionSummaryState : public WizardState  {
     Q_OBJECT;
 
 public:
-    ExtensionSummaryState(QString name, ExtensionSummaryWidget * widget, QString type, DorothyMainWindow * mainWindow, QState * parent);
+    /** Constructor*/
+    ExtensionSummaryState(QString name, ExtensionSummaryWidget * widget, QString type, WizardMainWindow * mainWindow, QState * parent);
 
+    /** Destructor*/
     ~ExtensionSummaryState();
 
     void setActionExtension(cepcoreschema::ActionExtension * domActionExtension);
