@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,7 +26,7 @@
 // Include .h file
 #include "GeneratingCEPState.h"
 #include "GeneratingCEPWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "DefaultGUIText.h"
 
 #include <CepGenerator.h>
@@ -47,13 +47,13 @@
 static const QString cepSchemaNamespace = "http://camitk.imag.fr/cepcoreschema";
 
 /**  Constructor */
-GeneratingCEPState::GeneratingCEPState(QString name, GeneratingCEPWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, QString * directoryName, QMap<QString, QStringList> * copyFilesMap)
+GeneratingCEPState::GeneratingCEPState(QString name, GeneratingCEPWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, QString * directoryName, QMap<QString, QStringList> * copyFilesMap)
     : WizardState(name, widget, mainWindow) {
     this->domCep = domCep;
     this->directoryName = directoryName;
     this->copyFilesMap = copyFilesMap;
 }
-/**  Destructor */
+
 GeneratingCEPState::~GeneratingCEPState() {}
 
 
@@ -64,7 +64,10 @@ void GeneratingCEPState::onEntry ( QEvent * event ) {
 
     cepcoreschema::Cep aCep(*domCep);
     std::auto_ptr<cepcoreschema::Cep> domCepPtr(domCep);
-    CepGenerator::generateCEP(domCepPtr,  (*directoryName));
+
+    CepGenerator* cepGenerator = new CepGenerator(domCepPtr, (*directoryName));
+    cepGenerator->process();
+    delete cepGenerator;
 
     std::cout << "CEP generated !" << std::endl;
 
