@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -42,7 +42,7 @@ class Cep;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to generate CEP
  *
  */
 class GeneratingCEPState : public WizardState  {
@@ -50,7 +50,9 @@ class GeneratingCEPState : public WizardState  {
     Q_OBJECT;
 
 public:
-    GeneratingCEPState(QString name, GeneratingCEPWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, QString  * directoryName, QMap<QString, QStringList> * copyFilesMap);
+    /**  Constructor */
+    GeneratingCEPState(QString name, GeneratingCEPWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, QString  * directoryName, QMap<QString, QStringList> * copyFilesMap);
+    /**  Destructor */
     ~GeneratingCEPState();
 
 protected:
