@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -40,7 +40,7 @@ class Library;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to copy files in library
  *
  */
 class LibraryCopyFilesState : public WizardState  {
@@ -48,8 +48,10 @@ class LibraryCopyFilesState : public WizardState  {
     Q_OBJECT;
 
 public:
-    LibraryCopyFilesState(QString name, LibraryCopyFilesWidget * widget, DorothyMainWindow * mainWindow, QMap<QString, QStringList> *libraryFilesMap, LibraryCreationState * parent);
+    /**  Constructor */
+    LibraryCopyFilesState(QString name, LibraryCopyFilesWidget * widget, WizardMainWindow * mainWindow, QMap<QString, QStringList> *libraryFilesMap, LibraryCreationState * parent);
 
+    /**  Destructor */
     ~LibraryCopyFilesState();
 
     void resetDomLibrary(cepcoreschema::Library * domLibrary);
