@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,7 +25,7 @@
 
 // Include .h file
 #include "LibraryCreationState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 #include "LibraryDescriptionWidget.h"
 #include "LibraryDescriptionState.h"
@@ -41,8 +41,8 @@
 #include <QMessageBox>
 #include <iostream>
 
-/**  Constructor */
-LibraryCreationState::LibraryCreationState(QString name, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, QMap<QString, QStringList> *libraryFilesMap) : QState() {
+
+LibraryCreationState::LibraryCreationState(QString name, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, QMap<QString, QStringList> *libraryFilesMap) : QState() {
     this->name = name;
     this->domCep = domCep;
     this->libraryFilesMap = libraryFilesMap;
@@ -53,7 +53,7 @@ LibraryCreationState::LibraryCreationState(QString name, DorothyMainWindow * mai
 }
 
 
-/**  Destructor */
+
 LibraryCreationState::~LibraryCreationState() {}
 
 
@@ -100,7 +100,7 @@ void LibraryCreationState::extensionCancelled() {
     emit next();
 }
 
-void LibraryCreationState::createSubStates(DorothyMainWindow * mainWindow) {
+void LibraryCreationState::createSubStates(WizardMainWindow * mainWindow) {
     libraryDescriptionWidget = new LibraryDescriptionWidget(NULL);
     libraryDescriptionState = new LibraryDescriptionState("Library Description",  libraryDescriptionWidget, mainWindow, this);
 
