@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,7 +28,7 @@
 #include <QState>
 #include <QWidget>
 
-class DorothyMainWindow;
+class WizardMainWindow;
 // Sub States
 class LibraryDescriptionWidget;
 class LibraryDescriptionState;
@@ -48,7 +48,9 @@ class Library;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * State to create library
+ *
+ * This state manages sub-state to create one library.
  *
  */
 class  LibraryCreationState : public QState  {
@@ -56,7 +58,9 @@ class  LibraryCreationState : public QState  {
     Q_OBJECT;
 
 public:
-    LibraryCreationState(QString name, DorothyMainWindow * mainWidnow, cepcoreschema::Cep * domCep, QMap<QString, QStringList> *libraryFilesMap);
+    /**  Constructor */
+    LibraryCreationState(QString name, WizardMainWindow * mainWidnow, cepcoreschema::Cep * domCep, QMap<QString, QStringList> *libraryFilesMap);
+    /**  Destructor */
     ~LibraryCreationState();
 
 signals:
@@ -86,7 +90,7 @@ private:
 
     bool cancelled;
 
-    void createSubStates(DorothyMainWindow * mainWindow);
+    void createSubStates(WizardMainWindow * mainWindow);
 
     QString name;
     cepcoreschema::Cep * domCep;
