@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -25,21 +25,21 @@
 
 // Include .h file
 #include "LibraryDependenciesState.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "LibraryCreationState.h"
 #include "DependenciesWidget.h"
 
 // includes from coreschema
 #include <Library.hxx>
 
-/**  Constructor */
-LibraryDependenciesState::LibraryDependenciesState(QString name, DependenciesWidget * widget, DorothyMainWindow * mainWindow, cepcoreschema::Cep * domCep, LibraryCreationState * parent)
+
+LibraryDependenciesState::LibraryDependenciesState(QString name, DependenciesWidget * widget, WizardMainWindow * mainWindow, cepcoreschema::Cep * domCep, LibraryCreationState * parent)
     : DependenciesState(name, widget, mainWindow, domCep, parent) {
     this->domLibrary = NULL;
     widget->setElement("Library");
 }
 
-/**  Destructor */
+
 LibraryDependenciesState::~LibraryDependenciesState() {}
 
 void LibraryDependenciesState::resetDomLibrary(cepcoreschema::Library *domLibrary) {
