@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,18 +26,17 @@
 // Include .h file
 #include "LibraryDescriptionState.h"
 #include "LibraryDescriptionWidget.h"
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 #include "LibraryCreationState.h"
 
 // includes from coreschema
 #include <Library.hxx>
 
-/**  Constructor */
-LibraryDescriptionState::LibraryDescriptionState(QString name, LibraryDescriptionWidget * widget, DorothyMainWindow * mainWindow, LibraryCreationState * parent)
+LibraryDescriptionState::LibraryDescriptionState(QString name, LibraryDescriptionWidget * widget, WizardMainWindow * mainWindow, LibraryCreationState * parent)
     : WizardState(name, widget, mainWindow, parent) {
     this->domLibrary = NULL;
 }
-/**  Destructor */
+
 LibraryDescriptionState::~LibraryDescriptionState() {}
 
 void LibraryDescriptionState::resetDomLibrary(cepcoreschema::Library *domLibrary) {
