@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,12 +30,12 @@
 // Qt files
 #include <QMessageBox>
 
-/**  Constructor */
+
 LibraryDescriptionWidget::LibraryDescriptionWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
     setToDefault();
 }
-/**  Destructor */
+
 LibraryDescriptionWidget::~LibraryDescriptionWidget() {}
 
 void LibraryDescriptionWidget::setToDefault() {
@@ -48,7 +48,8 @@ void LibraryDescriptionWidget::nextButtonClicked() {
     QString libraryName = ui.libraryNameItself->text();
     QString libraryDescription = ui.libraryDescriptionItself->toPlainText();
 
-    if (libraryName.toUtf8() != libraryName.toAscii()) {
+#ifndef _WIZARD_QUESTIONS_SQUEEZE
+    if (libraryName.toUtf8() != libraryName.toLatin1()) {
         ui.libraryNameStar->setStyleSheet(enhancedStyle);
         ui.libraryDescriptionStar->setStyleSheet(normalStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -62,8 +63,7 @@ void LibraryDescriptionWidget::nextButtonClicked() {
         ui.requiredLabel->setStyleSheet(enhancedStyle);
 
         QMessageBox::warning(this, defaultBeforeGoingFurther, defaultRealLibraryName);
-    }
-    if (libraryDescription.toUtf8() != libraryDescription.toAscii()) {
+    } else if (libraryDescription.toUtf8() != libraryDescription.toLatin1()) {
         ui.libraryNameStar->setStyleSheet(normalStyle);
         ui.libraryDescriptionStar->setStyleSheet(enhancedStyle);
         ui.requiredLabel->setStyleSheet(enhancedStyle);
@@ -84,6 +84,9 @@ void LibraryDescriptionWidget::nextButtonClicked() {
 
         emit next();
     }
+#else
+    emit next();
+#endif
 }
 
 void LibraryDescriptionWidget::setLibraryName(QString name) {
@@ -103,6 +106,9 @@ void LibraryDescriptionWidget::setStatic(bool isStatic) {
 }
 
 void LibraryDescriptionWidget::cancelButtonClicked() {
+    ui.libraryNameStar->setStyleSheet(normalStyle);
+    ui.libraryDescriptionStar->setStyleSheet(normalStyle);
+    ui.requiredLabel->setStyleSheet(normalStyle);
     emit cancel();
 }
 
