@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -23,8 +23,6 @@
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
 
-/** CONTROLLER of the model*/
-
 // Import .h file
 #include "WizardController.h"
 
@@ -35,7 +33,7 @@
 #include "WizardState.h"
 
 // Include Widgets
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 #include "WelcomeWidget.h"
 #include "CepCreateOrModifyWidget.h"
@@ -64,9 +62,10 @@
 
 #include <iostream>
 
-/**  Constructor: creation of all the interfaces and the connect */
+
 WizardController::WizardController(void) {
-    this->mainWindow = new DorothyMainWindow();
+
+    this->mainWindow = new WizardMainWindow();
     devDirectoryName = "Hello World";
     cepcoreschema::Contact c;
     this->domCep = new cepcoreschema::Cep("CEP not yet defined...", c, "to be defined");
@@ -75,8 +74,9 @@ WizardController::WizardController(void) {
     WelcomeWidget * welcomeWidget = new WelcomeWidget(NULL);
     WizardState * welcomeState = new WizardState("Welcome",  welcomeWidget, mainWindow);
     // Create a new CEP or work on an existing one ?
-    CepCreateOrModifyWidget * cepCreateOrModifyWidget = new CepCreateOrModifyWidget(NULL);
-    WizardState * cepCreateOrModifyState = new WizardState("Create / Modify a CEP ?", cepCreateOrModifyWidget, mainWindow);
+    // CS: Release 5 Sprint 8 [3.5 Wizard] "modifier un CEP existant"
+    //CepCreateOrModifyWidget * cepCreateOrModifyWidget = new CepCreateOrModifyWidget(NULL);
+    //WizardState * cepCreateOrModifyState = new WizardState("Create / Modify a CEP ?", cepCreateOrModifyWidget, mainWindow);
     // Create the state where to enter the directory for a cep creation
     CepCreationDirectoryWidget * cepCreationDirectoryWidget = new CepCreationDirectoryWidget(NULL);
     CepCreationDirectoryState * cepCreationDirectoryState = new CepCreationDirectoryState("Creation Directory", cepCreationDirectoryWidget, mainWindow, &devDirectoryName);
@@ -108,7 +108,8 @@ WizardController::WizardController(void) {
 
 
     machine.addState(welcomeState);
-    machine.addState(cepCreateOrModifyState);
+    // CS: Release 5 Sprint 8 [3.5 Wizard] "modifier un CEP existant" Remove this state
+    // machine.addState(cepCreateOrModifyState);
     machine.addState(cepCreationDirectoryState);
     machine.addState(cepDescriptionState);
     machine.addState(cepContactState);
@@ -125,13 +126,17 @@ WizardController::WizardController(void) {
     // Adding transitions...
     machine.setInitialState(welcomeState);
 
-    welcomeState->addTransition(welcomeWidget, SIGNAL(next()), cepCreateOrModifyState);
+    // CS: Release 5 Sprint 8 [3.5 Wizard] "modifier un CEP existant" link this state directly with the "choose directory state"
+    // welcomeState->addTransition(welcomeWidget, SIGNAL(next()), cepCreateOrModifyState);
+    welcomeState->addTransition(welcomeWidget, SIGNAL(next()), cepCreationDirectoryState);
 
-    cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(backCep()), welcomeState);
-    cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(newCep()), cepCreationDirectoryState);
+    // CS: Release 5 Sprint 8 [3.5 Wizard] "modifier un CEP existant"
+    //cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(backCep()), welcomeState);
+    //cepCreateOrModifyState->addTransition(cepCreateOrModifyWidget, SIGNAL(newCep()), cepCreationDirectoryState);
 
-
-    cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(previous()), cepCreateOrModifyState);
+    // CS: Release 5 Sprint 8 [3.5 Wizard] "modifier un CEP existant"
+    //cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(previous()), cepCreateOrModifyState);
+    cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(previous()), welcomeState);
     cepCreationDirectoryState->addTransition(cepCreationDirectoryWidget, SIGNAL(next()), cepDescriptionState);
 
     cepDescriptionState->addTransition(cepDescriptionWidget, SIGNAL(previous()), cepCreationDirectoryState);
@@ -157,10 +162,12 @@ WizardController::WizardController(void) {
 }
 
 
-/**  Destructor of the Controller */
-WizardController::~WizardController(void) {}
+WizardController::~WizardController(void) {
+    delete domCep;
+    delete mainWindow;
+}
+
 
-/** Method to start */
 void WizardController::launch() {
     machine.start();
     mainWindow->show();
