@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,7 +28,7 @@
 // Import from Qt
 #include <QStateMachine>
 
-class DorothyMainWindow;
+class WizardMainWindow;
 
 // Dependency from cepcoreschema
 // Declaration here to avoid declaration in dependant projects.
@@ -40,29 +40,33 @@ class Cep;
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * Controller class, based on MVP architecture.
+ *
+ * The wizard is constructed on a state machine. \n
+ * Each state is created in the constructor of this class and is connected with others trought this controller. \n
+ * Moreover, this class creates the XML DOM document to generate the corresponding CEP. \n
  *
  */
 class WizardController   {
-    /*! \class WizardController
-     * Controller class, based on MVP architecture
-     *
-     */
 
 public:
+    /** Constructor: creation of all the interfaces and the connections */
     WizardController(void);
+
+    /** Destructor of the Controller */
     ~WizardController(void);
+
+    /** Method to start */
     void launch();
 
 private:
     QStateMachine machine;
-    DorothyMainWindow * mainWindow;
+    WizardMainWindow * mainWindow;
 
     /**
-        XML DOM Element create by CodeSynthesis
+        XML DOM Element create by CodeSynthesis.
         This cep instance contains all of the informations of the xml file
         */
-
     cepcoreschema::Cep * domCep;
 
     QString  devDirectoryName;
