@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,24 +26,23 @@
 // Include .h file
 #include "WizardState.h"
 
-#include "DorothyMainWindow.h"
+#include "WizardMainWindow.h"
 
 #include <iostream>
 
-/**  Constructor */
-WizardState::WizardState(QString name, QWidget * widget, DorothyMainWindow * mainWindow) : QState() {
+
+WizardState::WizardState(QString name, QWidget * widget, WizardMainWindow * mainWindow) : QState() {
     this->name = name;
     this->widget = widget;
     this->mainWindow = mainWindow;
 }
 
-WizardState::WizardState(QString name, QWidget * widget, DorothyMainWindow * mainWindow, QState * parent) : QState(parent) {
+WizardState::WizardState(QString name, QWidget * widget, WizardMainWindow * mainWindow, QState * parent) : QState(parent) {
     this->name = name;
     this->widget = widget;
     this->mainWindow = mainWindow;
 }
 
-/**  Destructor */
 WizardState::~WizardState() {}
 
 QString WizardState::getName() {
