@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,13 +28,16 @@
 #include <QState>
 #include <QWidget>
 
-class DorothyMainWindow;
+class WizardMainWindow;
 
 /**
  * @ingroup group_sdk_application_wizard
  *
  * @brief
- * TODO Celine please comment here.
+ * Generic state of the wizard.
+ *
+ * Inherited from QState. \n
+ * A state is defined by its name, its widget and its mainWindow. It can be linked too to a state parent.
  *
  */
 class  WizardState : public QState  {
@@ -42,8 +45,11 @@ class  WizardState : public QState  {
     Q_OBJECT;
 
 public:
-    WizardState(QString name, QWidget * widget, DorothyMainWindow * mainWidnow);
-    WizardState(QString name, QWidget * widget, DorothyMainWindow * mainWidnow, QState * parent);
+    /**  Constructor */
+    WizardState(QString name, QWidget * widget, WizardMainWindow * mainWidnow);
+    /**  Constructor */
+    WizardState(QString name, QWidget * widget, WizardMainWindow * mainWidnow, QState * parent);
+    /**  Destructor */
     ~WizardState();
 
     QWidget * getWidget();
@@ -59,6 +65,6 @@ protected:
 
     QString name;
     QWidget * widget;
-    DorothyMainWindow * mainWindow;
+    WizardMainWindow * mainWindow;
 };
 #endif
