@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -156,8 +156,6 @@ void MshComponent::readLegacyFormat ( std::ifstream& fileStream ) {
         nbCells++;
     }
 
-    mesh->Update();
-
     // instanciate the Geometry
     initRepresentation ( mesh );
 
@@ -269,8 +267,6 @@ void MshComponent::readV2Format ( std::ifstream& fileStream ) {
         nbCells++;
     }
 
-    mesh->Update();
-
     // get physical names
     while ( std::getline ( fileStream, line ) ) {
         if ( ( !line.compare ( "$PhysicalNames" ) ) || ( !line.compare ( "$PhysicalNames\r" ) ) )
@@ -297,19 +293,19 @@ void MshComponent::readV2Format ( std::ifstream& fileStream ) {
     }
 
     // add the physical regions
+    /*
+        std::map< int, std::pair< std::string, std::vector< int > > >::iterator it;
 
-    std::map< int, std::pair< std::string, std::vector< int > > >::iterator it;
-
-    for ( it=physicalRegions.begin(); it!=physicalRegions.end(); it++ ) {
-        QString phyName = it->second.first.c_str();
-        phyName.replace(QString("\""), QString(""));
-        addSelection (phyName , vtkSelectionNode::CELL, vtkSelectionNode::INDICES );
-        vtkSmartPointer<vtkIdTypeArray> ids = vtkSmartPointer<vtkIdTypeArray>::New();
-        for ( int i=0; i<it->second.second.size(); i++ )
-            ids->InsertNextValue ( it->second.second[i] );
-        addToSelection(phyName, ids);
-    }
-
+        for ( it=physicalRegions.begin(); it!=physicalRegions.end(); it++ ) {
+            QString phyName = it->second.first.c_str();
+            phyName.replace(QString("\""), QString(""));
+            addSelection (phyName , vtkSelectionNode::CELL, vtkSelectionNode::INDICES );
+            vtkSmartPointer<vtkIdTypeArray> ids = vtkSmartPointer<vtkIdTypeArray>::New();
+            for ( int i=0; i<it->second.second.size(); i++ )
+                ids->InsertNextValue ( it->second.second[i] );
+            addToSelection(phyName, ids);
+        }
+    */
     // instanciate the Geometry
     initRepresentation ( mesh );
 
