@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -39,10 +39,6 @@
 #include <Application.h>
 using namespace camitk;
 
-// declare the plugin
-Q_EXPORT_PLUGIN2 ( MshExtension, MshExtension )
-
-
 QString MshExtension::getName() const {
     return "Msh Component";
 }
@@ -62,21 +58,15 @@ Component * MshExtension::open ( const QString & fileName ) throw ( AbortExcepti
 }
 
 bool MshExtension::save ( Component* component ) const {
-    bool saveOk = true;
-    bool found = true;
-
-    vtkSmartPointer<vtkPointSet> ps =  component->getPointSet();
+    MeshComponent *meshComp = dynamic_cast<MeshComponent*>(component);
+    vtkSmartPointer<vtkPointSet> ps =  meshComp->getPointSet();
 
     if ( ps == NULL || ps->GetNumberOfPoints() ==0 || ps->GetNumberOfCells() == 0 ) {
         QMessageBox::warning ( NULL, "Save As msh", tr("The selected component does not have any points or cells. This is an invalid mesh."), QMessageBox::Abort );
         return false;
     }
 
-    QString baseFilename = QFileInfo ( component->getFileName() ).absolutePath() + "/" + QFileInfo ( component->getFileName() ).completeBaseName();
-
-    QString mshFilename = baseFilename + ".msh";
-
-    ofstream mshFile ( mshFilename.toUtf8() );
+    ofstream mshFile ( meshComp->getFileName().toStdString().c_str() );
     double xyz[3];
     mshFile << "$NOD" << endl;
     mshFile << ps->GetPoints()->GetNumberOfPoints() << endl;
@@ -86,10 +76,18 @@ bool MshExtension::save ( Component* component ) const {
     }
     mshFile << "$ENDNOD" << endl;
     mshFile << "$ELM" << endl;
-    mshFile << ps->GetNumberOfCells() << endl;
 
+    // compute the number of cells, removing the unsupported types
+    unsigned int numberOfExportedCells = 0;
     for ( vtkIdType i = 0; i < ps->GetNumberOfCells() ; i++ ) {
-        found = true;
+        int cellType = ps->GetCell(i)->GetCellType();
+        if (cellType==VTK_LINE || cellType==VTK_TETRA || cellType==VTK_HEXAHEDRON || cellType==VTK_WEDGE || cellType==VTK_PYRAMID || cellType==VTK_TRIANGLE || cellType==VTK_QUAD)
+            numberOfExportedCells++;
+    }
+
+    mshFile << numberOfExportedCells << endl;
+    for ( vtkIdType i = 0; i < ps->GetNumberOfCells() ; i++ ) {
+        bool supportedType = true;
         switch ( ps->GetCell ( i )->GetCellType() ) {
         case VTK_LINE :
             mshFile << i + 1 << " 1 1 1 2";
@@ -113,12 +111,11 @@ bool MshExtension::save ( Component* component ) const {
             mshFile << i + 1 << " 3 1 1 4";
             break;
         default:
-            saveOk = false;
-            found = false;
-            CAMITK_ERROR ( "VolumetricMeshExtension", "save", "unsupported element" );
+            supportedType = false;
+            CAMITK_WARNING ( "MshExtension", "save", "Unsupported element for cell #" << i << ": type = " << ps->GetCell ( i )->GetCellType() << " (this cell was not exported to msh)");
             break;
         }
-        if ( found ) {
+        if (supportedType) {
             for ( vtkIdType j=0; j<ps->GetCell ( i )->GetNumberOfPoints(); j++ )
                 mshFile << " " << ps->GetCell ( i )->GetPointId ( j ) + 1;
             mshFile << endl;
@@ -128,5 +125,5 @@ bool MshExtension::save ( Component* component ) const {
     mshFile << "$ENDELM" << endl;
     mshFile.close();
 
-    return saveOk;
+    return true;
 }
