@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,9 +31,6 @@
 
 using namespace camitk;
 
-// --------------- Extension Declaration -------------------
-Q_EXPORT_PLUGIN2(componentextensionexample, StlExtension)
-
 // --------------- getName -------------------
 QString StlExtension::getName() const {
     return "STL Component";
