@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -65,13 +65,28 @@ ActionGenerator::ActionGenerator( Action & domAction, QString licence) {
     createFromDom(domAction);
 }
 
+// -------------------- getComponentNamespace --------------------
+QString ActionGenerator::getComponentNamespace() {
+    if (componentName == "Component"
+        || componentName == "SimplisticComponent"
+        || componentName == "MeshComponent" 
+        || componentName == "ImageComponent" 
+        || componentName == "ImageAcquisitionComponent") {
+        return "camitk::";
+    }
+    else {
+        return "";
+    }
+}
+
+// -------------------- createFromDom --------------------
 void ActionGenerator::createFromDom(Action & dom) {
     std::cout << "Creating action..." << std::endl;
-    this->name              = QString(dom.name().c_str());
-    this->description    = QString(dom.description().c_str()).simplified();
+    this->name          = QString(dom.name().c_str());
+    this->description   = QString(dom.description().c_str()).simplified();
     this->className     = ClassNameHandler::getClassName(this->name);
     this->componentName = QString(dom.component().c_str());
-
+    
     // classification
     // 1- Family
     this->family           = QString(dom.classification().family().c_str());
@@ -136,6 +151,7 @@ void ActionGenerator::writeHFile(QString directoryName) {
         text.replace(QRegExp("@LICENCE@"), licence);
         text.replace(QRegExp("@HEADDEF@"), className.toUpper());
         text.replace(QRegExp("@COMPONENTNAME@"), componentName);
+        text.replace(QRegExp("@COMPONENTNAMESPACE@"), getComponentNamespace());
         text.replace(QRegExp("@ACTIONCLASSNAME@"), className);
 
         if (text.contains(QRegExp("@IF_NOCOMP@"))) {
