@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -45,7 +45,7 @@ class ParameterGenerator;
  * @ingroup group_sdk_libraries_cepgenerator
  *
  * @brief
- * TODO Celine comment here please
+ * Generate an action
  *
  **/
 class ActionGenerator {
@@ -94,6 +94,9 @@ private:
 
     QVector<ParameterGenerator *> actionParameters;
 
+    /// Check if this action's component is in CamiTK namespace
+    /// @returns "camitk::" if the component is declared in the CamiTK namespace or "" otherwise
+    QString getComponentNamespace();
 };
 
 #endif
