@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -52,26 +52,47 @@ class ExtensionGenerator;
  * @ingroup group_sdk_libraries_cepgenerator
  *
  * @brief
- * TODO Celine comment here please
+ * This class contains the entry points to generate CEP.
+ *
+ * A CEP is generated form an XML file or from a dom xml-schema. \n
+ * See https://forge.imag.fr/plugins/mediawiki/wiki/camitk/index.php/CEP to understand how a CEP is buildt. \n
+ * <b>Release 3.5: Suppose that the CEP does NOT already exist. </b>
  *
  **/
 class CepGenerator {
 public :
-    /// Supposes that the CEP does NOT exist
-    static bool generateCEP(QString xmlFileName, QString devDirectoryName);
-    /// Supposes that the CEP does NOT exist
-    static bool generateCEP(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName);
 
-protected:
+    /**
+    * Create a CEPGenerator from the XML file \c xmlFileName in the directory \c devDirectoryName. \n
+    *
+    * <b>Supposes that the CEP does NOT exist.</b>
+    * Create a domCep from the XML file
+    *
+    **/
     CepGenerator(QString xmlFilename, QString devDirectoryName);
+
+    /**
+    * Create a CEPGenerator from the DOM XML-schema \c domCep in the directory \c devDirectoryName. \n
+    *
+    * <b>Supposes that the CEP does NOT exist.</b>
+    *
+    **/
     CepGenerator(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName);
 
     ~CepGenerator();
 
+    /// call all methods to generate the CEP from the DomTree.
+    void process() throw (QString);
+
+protected:
+
+
     /// Set the input XML CEP manifest (ant check its xml validity)
     virtual void setXmlFileName(QString xmlFileName) throw (QString);
+
     /// Where to generate the CEP directories and files
     virtual void setDevDirectoryName(QString devDirectoryName) throw (QString);
+
     /** Create the general directory tree (the same for every CEP)
             Copies the default files in the right directories:
 
@@ -95,30 +116,51 @@ protected:
     virtual void generateDirectoryTree() throw(QString);
 
     /** @{ Helping Functions  for generateDirectoryTree */
-    ///
+
+    /// Serialize the manifest ie serialize the domCep to a std::string
     virtual void serializeManifest();
-    ///
+
+    /// Generate CMakeLists file
     virtual void generateGlobalCMakeLists();
-    ///
+
+    /// Generate copyright file
     virtual void generateCopyright();
-    ///
+
+    /// Generate Readme File
     virtual void generateReadme();
-    ///
+
+    /// Generate the FindCamiTK file
     virtual void copyFindCamiTK();
-    ///
+
+    /// Generate the Actions directory
     virtual void generateActionsDirectory();
-    ///
+
+    /// Generate the Applications directory
     virtual void generateApplicationsDirectory();
-    ///
+
+    /// Generate the Components directory
     virtual void generateComponentsDirectory();
-    ///
+
+    /// Generate the Libraries directory
     virtual void generateLibrariesDirectory();
-    ///
+
+    /// Set the licence ine the \c licence variable to be included later in the generated files.
     virtual void setLicence();
     /** @} */
 
+    /**
+    Create the ActionExtensionDom if needed and call the appropriate methods to generate the actions Extensions.
+    */
     virtual void createActionExtensionDoms();
+
+    /**
+    Create the ComponentExtensionDom if needed and call the appropriate methods to generate the components Extensions.
+    */
     virtual void createComponentExtensionDoms();
+
+    /**
+    Create the LibrariesDom if needed and call the appropriate methods to generate the libraries.
+    */
     virtual void createLibrarieDoms();
 
     virtual void generateExtensions();
