@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -36,6 +36,10 @@
 #include <QApplication>
 #include <QProcess>
 
+#include <vtkVersion.h>
+// @todo fix itk version matter
+//#include <itkVersion.h>
+
 // MSVC does not have the C++ Standard rint function (it should be included in any C99 implementation)
 #if defined(_WIN32) && !defined(__MINGW32__) && (_MSC_VER < 1800)
 #include <math.h>
@@ -59,9 +63,36 @@ namespace camitk {
 const QString Core::getPaths() {
     QStringList diagnosis;
 
+    QString compileType;
+    if (isDebugBuild()) {
+        compileType = "DEBUG";
+    } else {
+        compileType = "RELEASE";
+    }
+
+    QString stringOS;
+
+#ifdef _WIN32
+    stringOS = "WIN32";
+#endif
+
+#ifdef __APPLE__
+    stringOS = "APPLE";
+#endif
+
+#ifdef __linux__
+    stringOS = "LINUX";
+#endif
+
+    //diagnosis << "- ITK Version : " + QString(itkVersion::GetITKVersion());
+
     diagnosis << "- CamiTK version......................... " + QString(Core::version);
     diagnosis << "- CamiTK Short Version................... " + QString(Core::shortVersion);
     diagnosis << "- CamiTK SO NAME......................... " + QString(Core::soVersion);
+    diagnosis << "- Operating System....................... " + stringOS;
+    diagnosis << "- Build type............................. " + compileType;
+    diagnosis << "- QT Version............................. " + QString(QT_VERSION_STR);
+    diagnosis << "- VTK Version............................ " + QString(vtkVersion::GetVTKVersion());
     diagnosis << "- CamiTK Global Installation Directory... " + Core::getGlobalInstallDir();
     diagnosis << "- User Installation Directory............ " + Core::getUserInstallDir();
     diagnosis << "- Current Working Directory.............. " + Core::getCurrentWorkingDir();
@@ -142,11 +173,11 @@ const QString Core::getConfig() {
 
     foreach(ActionExtension *ae, allActions) {
         QStringList actionNames;
-        for (int i=0; i<ae->getActions().size(); i++) {
+        for (int i = 0; i < ae->getActions().size(); i++) {
             actionNames << ae->getActions().at(i)->getName(); // + ": " + a->getDescription();
         }
         installationDirectory = ExtensionManager::getInstallationString(ExtensionManager::getActionExtensions().key(ae));
-        actions << "  - " + ae->getName() + " " + installationDirectory +": " + QString::number(ae->getActions().size()) + " actions (" + actionNames.join(", ") + ")"; //+ ae->getDescription();
+        actions << "  - " + ae->getName() + " " + installationDirectory + ": " + QString::number(ae->getActions().size()) + " actions (" + actionNames.join(", ") + ")"; //+ ae->getDescription();
         extensionCount++;
         extensionUnitCount += ae->getActions().size();
         if (installationDirectory == "[G]")
@@ -176,7 +207,7 @@ const QString Core::getConfig() {
 const QStringList Core::getInstallDirectories(QString suffix) {
     QStringList dir;
 
-    // current dir actions (build)
+    // find the build directory according to the current directory
     QDir currentWorkingDir(getCurrentWorkingDir());
     if (currentWorkingDir.cd(suffix))
         dir.append(currentWorkingDir.canonicalPath().toUtf8());
@@ -196,19 +227,19 @@ const QStringList Core::getInstallDirectories(QString suffix) {
 
 // ------------- getActionDirectories (static) -----------------
 const QStringList Core::getActionDirectories() {
-    return getInstallDirectories("lib/"+QString(Core::shortVersion)+"/actions");
+    return getInstallDirectories("lib/" + QString(Core::shortVersion) + "/actions");
 }
 
 // ------------- getComponentDirectories (static) -----------------
 const QStringList Core::getComponentDirectories() {
-    return getInstallDirectories("lib/"+QString(Core::shortVersion)+"/components");
+    return getInstallDirectories("lib/" + QString(Core::shortVersion) + "/components");
 }
 
 // ------------- getTestDataDir (static) -----------------
 const QString Core::getTestDataDir() {
     QStringList testDataDirectories = getInstallDirectories("share/" + QString(Core::shortVersion) + "/testdata");
     // just returns the first one if exists
-    if (testDataDirectories.size()>0)
+    if (testDataDirectories.size() > 0)
         return testDataDirectories.at(0);
     else
         // otherwise returns user home directory
@@ -229,7 +260,7 @@ const QString Core::getGlobalInstallDir() {
         process.start("camitk-config", QStringList() << "--camitkDir", QIODevice::ReadWrite | QIODevice::Text);
 
         if (process.waitForStarted(-1)) {
-            while(process.waitForReadyRead(-1)) {
+            while (process.waitForReadyRead(-1)) {
                 camitkDirectory += process.readAllStandardOutput();
             }
             camitkDir = QString(camitkDirectory).trimmed();
@@ -241,7 +272,7 @@ const QString Core::getGlobalInstallDir() {
     // if there was a problem or if this is camitk-config, check CamiTKDir.txt
     if (!processOk) {
         // not found use the last installation path if available
-        QFile file(getUserInstallDir()+"/CamiTKDir.txt");
+        QFile file(getUserInstallDir() + "/CamiTKDir.txt");
         if (file.exists() && file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             camitkDirectory = file.readLine();
             camitkDir = QString(camitkDirectory).trimmed();
@@ -255,7 +286,7 @@ const QString Core::getGlobalInstallDir() {
     return camitkDir.canonicalPath().toUtf8();
 }
 
-// ------------- getUserConfigDir (static) -----------------
+// ------------- getUserInstallDir (static) -----------------
 const QString Core::getUserInstallDir() {
     // obtain (platform specific) application's data/settings directory from settings file
     return QFileInfo(Application::getSettings().fileName()).absolutePath();
@@ -266,6 +297,28 @@ const QString Core::getCurrentWorkingDir() {
     return QDir::currentPath();
 }
 
+// ------------- getBugReport (static) -----------------
+const QString Core::getBugReport() {
+    QStringList BugReport;
+    QString     breakLine("\n\n");
+
+    BugReport <<
+              "About you:                 \n[Present yourself and your project you're working on with CamiTK]" + breakLine;
+    BugReport <<
+              "Overview:                  \n[Rewrite here a larger and more detailed restatement of your summary]" + breakLine;
+    BugReport <<
+              "Steps to Reproduce:        \n[Write here the step - by - step process to reproduce the bug, including file to test(you can attach file on BugZilla / the forum)]" + breakLine;
+    BugReport <<
+              "Actual VS Expected Result: \n[Write here the result of the step - by - step process and explain why it is not what you expected]" + breakLine;
+    BugReport <<
+              "Interpretation:            \n[Write here your interpretation of this bug]" + breakLine;
+    BugReport <<
+              "CamiTK Version:            \n\n" + Core::getConfig() + breakLine;
+
+    return BugReport.join("\n");
+}
+
+
 // ------------- isDebugBuild (static) -----------------
 const bool Core::isDebugBuild() {
 #ifdef QT_DEBUG
@@ -276,20 +329,6 @@ const bool Core::isDebugBuild() {
 }
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 // ----------------------------------------------------------------
 //
 //                     OBSOLETE PUBLIC METHODS
@@ -303,7 +342,7 @@ const bool Core::isDebugBuild() {
 //TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 const QString Core::getComponentDir() {
     QDir appDir(getGlobalInstallDir());
-    appDir.cd("lib/"+QString(Core::shortVersion)+"/components");
+    appDir.cd("lib/" + QString(Core::shortVersion) + "/components");
     return appDir.canonicalPath().toUtf8();
 }
 
@@ -312,7 +351,7 @@ const QString Core::getComponentDir() {
 //TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 const QString Core::getActionDir() {
     QDir appDir(getGlobalInstallDir());
-    appDir.cd("lib/"+QString(Core::shortVersion)+"/actions");
+    appDir.cd("lib/" + QString(Core::shortVersion) + "/actions");
     return appDir.canonicalPath().toUtf8();
 }
 
@@ -321,7 +360,7 @@ const QString Core::getActionDir() {
 //TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 const QString Core::getModuleDir(const QString & subpath) {
     QDir appDir(getGlobalInstallDir());
-    appDir.cd("lib/"+QString(Core::shortVersion)+"/" + subpath);
+    appDir.cd("lib/" + QString(Core::shortVersion) + "/" + subpath);
     return appDir.canonicalPath().toUtf8();
 }
 
@@ -331,10 +370,4 @@ const QString Core::getCoreLibDir() {
     return getGlobalInstallDir();
 }
 
-
 }
-
-
-
-
-
