@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,6 +35,7 @@
 #include <QtGui>
 #include <QSettings>
 #include <QApplication>
+#include <QMessageBox>
 
 namespace camitk {
 
@@ -446,6 +447,8 @@ bool ExtensionManager::unloadActionExtension(QString fileName) {
         }
         //-- unregister extension
         getActionExtensionMap().remove(fileName);
+        // -- unregister actions from application
+        Application::unregisterAllActions(ext);
         //-- delete extensions (and all its actions)
         delete ext;
         return true;
