@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -29,12 +29,12 @@
 // -- Core stuff
 #include "CamiTKAPI.h"
 #include <HistoryItem.h>
+#include <Application.h>
 
 #include <QSet>
 #include <QWidget>
 #include <QString>
 #include <QAction>
-#include <signal.h>
 
 
 namespace camitk {
@@ -142,6 +142,30 @@ class Property;
  * they are updated only when the user click on the apply button of the default widget.
  * Use setAutoUpdateProperties(true) to automatically update the action's properties.
  *
+ * \note if your action needs to react immediately to a change of value in one of its dynamic properties,
+ * you need to override the <tt>virtual bool event(QEvent* e)</tt> method. For instance:
+ * \code
+ * // ---------------------- event ----------------------------
+ * bool MyAction::event(QEvent * e) {
+ *    if (e->type() == QEvent::DynamicPropertyChange) {
+ *        e->accept();
+ *        QDynamicPropertyChangeEvent *changeEvent = dynamic_cast<QDynamicPropertyChangeEvent *>(e);*
+ *
+ *        if (!changeEvent)
+ *            return false;
+ *
+ *        // do something depending of the property that has changed
+ *        QString msg("[" + changeEvent->propertyName() + "] changed to [" + property(changeEvent->propertyName()).toString() + "]");
+ *        std::cout << msg.toStdString() << std::endl;
+ *
+ *        return true;
+ *    }
+ *
+ *    // this is important to continue the process if the event is a different one
+ *    return QObject::event(e);
+ *}
+ * \endcode
+ *
  * \note if you use your own MyVerySpecialActionWidget class, make sure it conforms to this behaviour
  * (you can get the desired behaviour by calling getAutoUpdateProperty()
  *
@@ -340,6 +364,8 @@ public:
     const ComponentList getTargets() const;
     ///@}
 
+    /// @name Property management
+    /// @{
     /// auto update properties
     bool getAutoUpdateProperties() const;
 
@@ -363,6 +389,25 @@ public:
      * @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated)
      */
     virtual bool addParameter(Property*);
+    ///}@
+
+    /// @name Frame management
+    /// @{
+    /**
+     * Change the target frame according to the default frame policy regarding the input's one.
+     * @param input The component refering to for the computation of the frame.
+     * @param target The component on which we apply the frame policy.
+     */
+    void applyTargetPosition(Component* input, Component* target);
+
+    /**
+     * Change the target frame according to a given frame policy regarding the input's one.
+     * @param input The component refering to for the computation of the frame.
+     * @param target The component on which we apply the frame policy.
+     * @param policy The frame policy to use on the target.
+     */
+    void applyTargetPosition(Component* input, Component* target, Application::TargetPositionningMethods policy);
+    /// }@
 
 protected:
     /** @name Generic action attributes setters
