@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -45,6 +45,8 @@ class ActionExtension;
 class Action;
 class HistoryItem;
 class ComponentExtension;
+class Property;
+class PropertyObject;
 
 /**
  * @ingroup group_sdk_libraries_core_application
@@ -62,6 +64,15 @@ class CAMITK_API Application : public QApplication {
 
 public:
 
+    enum TargetPositionningMethods {
+        SAME_TRANSFORMATION, // Child has the same frame as its parent (parent frame = world).
+        NO_TRANSFORMATION, // Child has no frame and parent frame = world.
+        SUBFRAME // Child has no frame but its parent is set as its parent frame.
+    };
+
+    Q_ENUMS(TargetPositionningMethods)
+
+
     /**
      * Initializes the window system and constructs a CamiTK application object with argc command line arguments in argv.
      * The first parameter is the name of the application (used as a identifier in the settings, for example)
@@ -234,6 +245,11 @@ public:
      *  @return the number of actions effectively registered (in case an action's name is already registered it won't be a second time)
      */
     static int registerAllActions(ActionExtension *);
+
+    /** unregister all actions from the given ActionExtension
+    *  @return the number of actions effectively unregistered
+    */
+    static int unregisterAllActions(ActionExtension *);
     ///@}
 
     /** @name Main Window management
@@ -317,16 +333,47 @@ public:
 
     /// @name Application resources management
     ///@{
-
-
     /**
     * Returns for the current CamiTK application, the selected language (stored in its .ini configuration file)
     */
     static QString getSelectedLanguage();
     ///@}
 
+    /// @name Property management
+    ///@{
+    /**
+     * Get the property object of the application.
+     */
+    PropertyObject* getPropertyObject();
+
+    /**
+     * Get the CamiTK property associated with auto loading last opened component when the application starts.
+     */
+    Property* getAutoloadLastOpenedComponentsProperty() {
+        return autoloadLastOpenedComponentsProperty;
+    }
+
+    /**
+     * Get the CamiTK property associated with the new component frame policy.
+     */
+    Property* getDefaultTargetedComponentProperty() {
+        return defaultTargetedComponentProperty;
+    }
+    ///}@
 
 
+    /// @name Frame management
+    ///@{
+    /**
+    * @brief Get the default target positionning method.
+    */
+    static TargetPositionningMethods getDefaultTargetPositionningMethod();
+
+    /**
+     * @brief Set the default target positionning method.
+     */
+    static void setDefaultTargetPositionningMethod(TargetPositionningMethods method);
+    ///@}
 
 private slots:
     void quitting();
@@ -358,8 +405,8 @@ private:
     /// max number of recent document (default 10)
     static int maxRecentDocuments;
 
-	/// Provide internationalization support for text output.
-	QTranslator* translator;
+    /// Provide internationalization support for text output.
+    QTranslator* translator;
     ///@}
 
     /// @name Components management
@@ -457,9 +504,42 @@ private:
     /// Init the application resources by loading the language associated .qm file
     void initResources();
 
+    /// @name Property management
+    ///@{
+    /**
+     * Create all the application properties and add them to the qApp
+     */
+    void createProperties();
+
+    /**
+     * The CamiTK property for selecting the frame policy.
+     */
+    Property *defaultTargetedComponentProperty;
+
+    /**
+     * The CamiTK property to open the last components the application opened during its last session.
+     */
+    Property *autoloadLastOpenedComponentsProperty;
+
+    /**
+     * A simple QObject that holds the CamiTK level properties of the application.
+     *
+     * @note
+     * Use the accessor getPropertyObject() to access this object
+     *
+     * @see
+     * PropertyObject
+     */
+    PropertyObject* propertyObject;
+    ///@}
+
 
 };
 
+
+
 }
 
+Q_DECLARE_METATYPE(camitk::Application::TargetPositionningMethods)
+
 #endif // CAMITKAPPLICATION_H
