@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -63,11 +63,17 @@ Component::Component ( Component *parentComponent, const QString & n, Representa
 
 // -------------------- default destructor --------------------
 Component::~Component() {
+    // delete all reference of this component in the application
     Application::removeComponent(this);
 
-    // delete all children Component
+    // delete all its children Components
     deleteChildren();
 
+    // unregister if I got a parent component
+    if(Component* parent = getParentComponent()) {
+        parent->removeChild(this);
+    }
+
     // erase all the viewers
     myViewers.clear();
 
