@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -333,7 +333,13 @@ public:
      */
     Component(Component *parentComponent, const QString & name, Representation rep = NO_REPRESENTATION) throw(AbortException);
 
-    /// default destructor
+    /** default destructor.
+     *  The Component class destructor is automatically called after the inherited destructor has finished (C++ standard).
+     *  This destructor delete all the children, clear all this component's viewer list, delete all helper class instance
+     *  (Geometry, Slice or Frame), which in turns will delete the VTK pipeline and any additional prop,
+     *  and finally delete and all additional CamiTK Properties.
+     *  @see deleteChildren()
+     */
     virtual ~Component();
 
     /** return the type of representation concretely implemented by this Component in the InteractiveViewer.
@@ -510,7 +516,6 @@ public:
     * version). You are encourage to build Action not getPopupMenu() anymore.
     */
     QMenu * getActionAndPopupMenu();
-    ///@}
     ///@endcond
 
     /** Get a Property given its name
@@ -530,6 +535,7 @@ public:
      * @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated)
      */
     virtual bool addProperty(Property*);
+    ///@}
 
     /**
       * @name InterfaceNode
@@ -808,10 +814,16 @@ public:
 
     delegate3(myFrame, rotate, double, double, double)
 
+    delegate3(myFrame, rotateVTK, double, double, double)
+
     delegate3(myFrame, setTransformTranslation, double, double, double)
 
+    delegate3(myFrame, setTransformTranslationVTK, double, double, double)
+
     delegate3(myFrame, setTransformRotation, double, double, double)
 
+    delegate3(myFrame, setTransformRotationVTK, double, double, double)
+
     vtkSmartPointer<vtkAxesActor> getFrameAxisActor() {
         if(!myFrame)
             CAMITK_ERROR("Component", "getFrameAxisActor", "Delegate myFrame is not instanciated.")
@@ -935,7 +947,7 @@ inline InterfaceFrame * Component::getFrame() {
 
 // -------------------- getPixmap ------------------
 inline QPixmap Component::getIcon() {
-    return NULL;
+    return QPixmap(0, 0); // this is a NULL QPixmap in the Qt sense. QPixmap::isNull will then return true;
 }
 
 // -------------------- inItalic --------------------
