@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -103,12 +103,12 @@ Geometry::Geometry(QString label, vtkSmartPointer<vtkPointSet> pointSetPtr, cons
     pointsColor[1] = 0.0;
     pointsColor[2] = 1.0;
     pointsColor[3] = 1.0;
-
+        
     alphaShaded = 0.2;
 
     //-- init generic filter and dataOutput and customPipelineOuput
     concreteData = vtkSmartPointer<vtkCastToConcrete>::New();
-    concreteData->SetInput(this->pointSet);
+    concreteData->SetInputData(this->pointSet);
 
     worldTransformFilter = vtkSmartPointer<vtkTransformFilter>::New();
     vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
@@ -116,7 +116,6 @@ Geometry::Geometry(QString label, vtkSmartPointer<vtkPointSet> pointSetPtr, cons
     worldTransformFilter->SetTransform(transform);
     worldTransformFilter->SetInputConnection(concreteData->GetOutputPort());
 
-//    dataOutput = concreteData->GetOutputPort();
     dataOutput = worldTransformFilter->GetOutputPort();
     customPipelineOutput = dataOutput;
 
@@ -179,8 +178,6 @@ void Geometry::setPointSet(vtkSmartPointer<vtkPointSet> ps) {
 void Geometry::setMeshWorldTransform(vtkSmartPointer<vtkTransform> transform) {
     // Do not delete vtkSmartTransform previous transform, but set it to NULL to
     // decrement its counter
-//    worldTransformFilter->GetTransform()->Delete();
-
     worldTransformFilter->SetTransform(transform);
     worldTransformFilter->Update();
 }
@@ -428,7 +425,6 @@ bool Geometry::removeProp(const QString& name) {
 void Geometry::setPointPosition(const unsigned int orderNumber, const double x, const double y, const double z) {
     pointSet->GetPoints()->SetPoint(orderNumber, x, y, z);
     pointSet->Modified();
-    pointSet->Update();
 }
 
 //------------------------------- setActorColor ----------------------------------------
@@ -714,7 +710,6 @@ void Geometry::setPointData(vtkSmartPointer<vtkDataArray> da) {
     }
     // make sure the change is taking into account
     pointSet->Modified();
-    pointSet->Update();
     mapper->Update();
 }
 
