@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -40,12 +40,14 @@
 #include <vtkTextActor.h>
 #include <vtkProperty2D.h>
 #include <vtkImageFlip.h>
+#include <vtkImageMapper3D.h>
 
 using namespace std;
 
 
 namespace camitk {
 /* Deprecated constructor  */
+// -------------------- Deprecated constructor --------------------
 Slice::Slice(vtkSmartPointer<vtkImageData> volume, PossibleOrientation orientation, vtkSmartPointer<vtkWindowLevelLookupTable> lookupTable) {
     switch (orientation) {
     default:
@@ -73,7 +75,7 @@ Slice::Slice(vtkSmartPointer<vtkImageData> volume, PossibleOrientation orientati
 
 }
 
-/* Constructor */
+// -------------------- constructor --------------------
 Slice::Slice(vtkSmartPointer<vtkImageData> volume, SliceOrientation orientation, vtkSmartPointer<vtkWindowLevelLookupTable> lookupTable) {
     this->sliceOrientation = orientation;
     this->lut = lookupTable;
@@ -83,9 +85,10 @@ Slice::Slice(vtkSmartPointer<vtkImageData> volume, SliceOrientation orientation,
 }
 
 
-/* Destructor */
+// -------------------- Destructor --------------------
 Slice::~Slice() {
     // Let's unreference vtkSmartPointers
+
     originalVolume = NULL;
     lut = NULL;
     imgToMapFilter = NULL;
@@ -98,6 +101,7 @@ Slice::~Slice() {
 }
 
 
+// -------------------- init --------------------
 void Slice::init() {
     currentSliceIndex = 0;
 
@@ -137,6 +141,7 @@ void Slice::init() {
 
 }
 
+// -------------------- setOriginalVolume --------------------
 void Slice::setOriginalVolume( vtkSmartPointer<vtkImageData> volume ) {
     // If there were already a referenced volume,
     //  de-reference the smart pointer.
@@ -166,9 +171,9 @@ void Slice::setOriginalVolume( vtkSmartPointer<vtkImageData> volume ) {
     initActors();
 }
 
-
+// -------------------- initActors --------------------
 void Slice::initActors() {
-    imgToMapFilter->SetInput(originalVolume);
+    imgToMapFilter->SetInputData(originalVolume);
 
     if (NULL==lut) {
         imgToMapFilter->SetLookupTable(0);
@@ -176,11 +181,11 @@ void Slice::initActors() {
         imgToMapFilter->SetLookupTable(lut);
 
     /* 3D Actor case: directly pluged to the output of imgToMapFilter */
-    image3DActor->SetInput(imgToMapFilter->GetOutput());
+    image3DActor->GetMapper()->SetInputConnection(imgToMapFilter->GetOutputPort());
     image3DActor->InterpolateOn();
 
     // 2D actors
-    image2DActor->SetInput(imgToMapFilter->GetOutput());
+    image2DActor->GetMapper()->SetInputConnection(imgToMapFilter->GetOutputPort());
     image2DActor->InterpolateOn();
 
     // Pick plane
@@ -216,50 +221,48 @@ void Slice::initActors() {
 }
 
 
+// -------------------- setImageWorldTransform --------------------
 void Slice::setImageWorldTransform(vtkSmartPointer<vtkTransform> transform) {
 //    image3DActor->GetUserTransform()->Delete();
     image3DActor->SetUserTransform(transform);
 }
 
 
-/* Return the vtkImageActor (vtkProp) representing a slice to be displayed in 2D. */
+// -------------------- get2DImageActor --------------------
 vtkSmartPointer<vtkImageActor> Slice::get2DImageActor() const {
     return image2DActor;
 }
 
-/* Return the vtkImageActor (vtkProp) representing a slice to be displayed in 2D. */
+// -------------------- get3DImageActor --------------------
 vtkSmartPointer<vtkImageActor> Slice::get3DImageActor() const {
     return image3DActor;
 }
 
-
-/* Return the vtkActor used to pick pixels in the slices. */
+// -------------------- getPickPlaneActor --------------------
 vtkSmartPointer<vtkActor> Slice::getPickPlaneActor() const {
     return pickPlaneActor;
 }
 
-
-
-/* This method is called when the associated plane has been picked in the InteractiveViewer,
- *  the given coordinates is position where the plane was picked.
- */
+// -------------------- pixelPicked --------------------
 void Slice::pixelPicked(double x, double y, double z) {
     return;
 }
 
-
+// -------------------- reslicedToVolumeCoords --------------------
 void Slice::reslicedToVolumeCoords(const double *ijk, double *xyz) {
     xyz[0] = ijk[0] * originalSpacing[0];
     xyz[1] = ijk[1] * originalSpacing[1];
     xyz[2] = ijk[2] * originalSpacing[2];
 }
 
+// -------------------- volumeToReslicedCoords --------------------
 void Slice::volumeToReslicedCoords(const double *xyz, double *ijk) {
     ijk[0] = xyz[0] / originalSpacing[0];
     ijk[1] = xyz[1] / originalSpacing[1];
     ijk[2] = xyz[2] / originalSpacing[2];
 }
 
+// -------------------- updatePickPlane --------------------
 void Slice::updatePickPlane() {
     // Be carefull, The center of the first voxel (0,0,0) is displayed at coordinates (0.0, 0.0, 0.0).
     // Pixels winthin borders are represented (in 2D) only by their half, quarter or eigth depending on their coordinates.
@@ -294,7 +297,7 @@ void Slice::updatePickPlane() {
     pickPlane->UpdateWholeExtent();
 }
 
-/* Return the number of slices in the image data set. */
+// -------------------- getNumberOfSlices --------------------
 int Slice::getNumberOfSlices() const {
     int nbSlices = 0;
 
@@ -315,18 +318,12 @@ int Slice::getNumberOfSlices() const {
     return nbSlices;
 }
 
-
-
-
-/* Return the index of the current displayed slice. */
+// -------------------- getSlice --------------------
 int Slice::getSlice() const {
     return currentSliceIndex;
 }
 
-/* Set the current slice index.
- * If the slice index is less than the first slice index, the first slice is displayed.
- * If the slice index is more than the last slice index, the last slice is displayed.
- * @param s the index of the slice to display (base 0). */
+// -------------------- setSlice --------------------
 void Slice::setSlice(int s) {
     // Check if s is inside the volume bounds
     if ( s < 0 ) {
@@ -379,7 +376,7 @@ void Slice::setSlice(int s) {
 }
 
 
-// Set the slice corresponding to the given world coordinates
+// -------------------- setSlice --------------------
 void Slice::setSlice(double x, double y, double z) {
     // At this point, coordinates are expressed in Image coordinate system
 
@@ -407,21 +404,17 @@ void Slice::setSlice(double x, double y, double z) {
     }
 }
 
-
-
-/* Return the number of colors in the images.
- * If color is coded on 1 byte, the images are on 256 grey level.
- * If color is coded on 2 bytes, the images are on 4096 grey level (not 65536). */
+// -------------------- getNumberOfColors --------------------
 int Slice::getNumberOfColors() const {
     return originalVolume->GetScalarTypeMax() - originalVolume->GetScalarTypeMin();
 }
 
-
-// move the pixel selection green indicator (pixelActor) to the given real position
+// -------------------- setPixelRealPosition --------------------
 void Slice::setPixelRealPosition(double x, double y, double z) {
     updatePixelActorPosition(x, y, z);
 }
 
+// -------------------- initPixelActor --------------------
 void Slice::initPixelActor() {
     double xMin = 0.0;
     double xMax = originalSize[0];
@@ -440,7 +433,7 @@ void Slice::initPixelActor() {
 void Slice::updatePixelActorPosition(double x, double y, double z) {
     // if the interactive viewer is not refreshed/displayed, the pixelActor is null. In this case, no point to update it
     if (pixelActor) {
-        // Create the cloup points used to describe the bounding box around
+        // Create the cloud points used to describe the bounding box around
         vtkSmartPointer<vtkPoints> pixelPoints = vtkSmartPointer<vtkPoints>::New();
         pixelPoints->SetNumberOfPoints(4);
         // Those points describes the (red / blue / green) cross around the picked pixel.
@@ -448,7 +441,7 @@ void Slice::updatePixelActorPosition(double x, double y, double z) {
 
         switch (sliceOrientation) {
         case AXIAL:
-            planeZCoord = z - (originalSpacing[2] / 2);
+            planeZCoord = z - (originalSpacing[2] / 2.0);
             // 0 -> Anterior Point
             pixelPoints->InsertPoint(0, x, 0.0            , planeZCoord);
             // 1 -> Posterior Point
@@ -460,7 +453,7 @@ void Slice::updatePixelActorPosition(double x, double y, double z) {
             break;
 
         case CORONAL:
-            planeYCoord = y - (originalSpacing[1] / 2);
+            planeYCoord = y - (originalSpacing[1] / 2.0);
             // 0 -> Superior Point
             pixelPoints->InsertPoint(0, x              , planeYCoord, originalSize[2]);
             // 1 -> Inferior Point
@@ -472,7 +465,7 @@ void Slice::updatePixelActorPosition(double x, double y, double z) {
             break;
 
         case SAGITTAL:
-            planeXCoord = x + (originalSpacing[0]/2);
+            planeXCoord = x + (originalSpacing[0] / 2.0);
             // 0 -> Superior Point
             pixelPoints->InsertPoint(0, planeXCoord, y, originalSize[2]);
             // 1 -> Inferior Point
@@ -509,7 +502,7 @@ void Slice::updatePixelActorPosition(double x, double y, double z) {
 
         // Create the corresponding mapper
         vtkSmartPointer<vtkDataSetMapper> aPixelMapper = vtkSmartPointer<vtkDataSetMapper>::New();
-        aPixelMapper->SetInput(aPixelGrid);
+        aPixelMapper->SetInputData(aPixelGrid);
 
         pixelActor->SetMapper(aPixelMapper);
         pixelActor->GetProperty()->SetAmbient(1.0);
@@ -533,7 +526,7 @@ void Slice::updatePixelActorPosition(double x, double y, double z) {
         }
 
         pixelActor->GetProperty()->SetLineWidth( 1.0 );
-        pixelActor->SetPosition( 0.0, 0.0, 0.0 );
+//        pixelActor->SetPosition( 0.0, 0.0, 0.0 );
         //-- pixelActor can not be picked
         pixelActor->PickableOff();
     }
@@ -541,14 +534,14 @@ void Slice::updatePixelActorPosition(double x, double y, double z) {
 }
 
 
-/* Create the pixel grid (bounding box) around the pixel picked.
- * Returns the actors that has been calculated */
+// --------------------  --------------------
 vtkSmartPointer<vtkActor> Slice::getPixelActor() {
     if (!pixelActor)
         initPixelActor();
     return pixelActor;
 }
 
+// --------------------  --------------------
 void Slice::init2DAxesActor() {
     axes2DActor = vtkSmartPointer<vtkAxesActor>::New();
     axes2DActor->SetShaftTypeToCylinder();
@@ -589,7 +582,7 @@ void Slice::init2DAxesActor() {
     update2DAxesActorPosition();
 }
 
-
+// --------------------  --------------------
 void Slice::update2DAxesActorPosition() {
     vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
     transform->Identity();
@@ -625,6 +618,7 @@ void Slice::update2DAxesActorPosition() {
     // else no point to update the pixelActor
 }
 
+// --------------------  --------------------
 vtkSmartPointer<vtkAxesActor> Slice::get2DAxesActor() {
     if (! axes2DActor)
         init2DAxesActor();
