@@ -2,7 +2,7 @@
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
-* (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+* (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
@@ -99,6 +99,8 @@ ImageComponent::~ImageComponent() {
     if (selectionView != NULL) {
         delete selectionView;
     }
+
+    originalImageData = NULL;
 }
 
 // -------------------- init --------------------
@@ -119,7 +121,7 @@ void ImageComponent::init() {
     lut = vtkSmartPointer<vtkWindowLevelLookupTable>::New();
 
     // Properties
-    Property * nameProp  = new Property("Image Name", QVariant("None"), tr("Name of the image displaied in the explorer"), "");
+    Property * nameProp  = new Property("Image Name", QVariant(getName()), tr("Name of the image displayed in the explorer"), "");
     addProperty(nameProp);
 
     Property * imageDims = new Property("Image Dimensions", QVariant("(0, 0, 0)"), tr("Dimensions of the image in each direction (x,y,z)"), "voxel number");
@@ -196,7 +198,6 @@ void ImageComponent::updateImageProperties() {
         imageSize += ")";
         setProperty("Image Size", QVariant(imageSize));
 
-
         setProperty("Voxel Data Type", QVariant(getDataType()));
 
         setProperty("Display Image in 3D Viewer", QVariant(true));
@@ -207,10 +208,22 @@ void ImageComponent::updateImageProperties() {
 
 // -------------------- updateProperty --------------------
 void ImageComponent::updateProperty(QString name, QVariant value) {
-    bool viewIn3D = property("Display Image in 3D Viewer").toBool();
-    this->setViewIn3D(viewIn3D);
-
-    Component::updateProperty(name, value);
+    // update the non-read only properties
+    if (name == "Display Image in 3D Viewer") {
+        this->setViewIn3D(value.toBool());
+    } else if (name == "Image Name") {
+        setName(value.toString());
+        refreshInterfaceNode();
+    }
+    // bypass read-only properties
+    // (other specific properties are read only and should not be sent up to Component::updateProperty)
+    else if (name != "Image Dimensions"
+             && name != "Image Size"
+             && name != "Voxel Size"
+             && name != "Voxel Data Type"
+             && name != "Initial Image Orientation") {
+        Component::updateProperty(name, value);
+    }
 }
 
 // -------------------- setImageData --------------------
@@ -222,6 +235,7 @@ void ImageComponent::setImageData(vtkSmartPointer<vtkImageData> anImageData,
     this->initialOrientation = initialOrientation;
 
     originalImageData = NULL;
+    vtkSmartPointer<vtkImageData> inputImage = NULL;
 
     if (copy) {
         // We need to use a shall because of some strange behaviour of mingw
@@ -231,22 +245,22 @@ void ImageComponent::setImageData(vtkSmartPointer<vtkImageData> anImageData,
         // (equivalent of ITK DisconnectPipeline()...)
         // Note : this (i.e disconnect/deepcopy/shallowcopy) should not have to be done
         // in the components...
-        originalImageData = vtkImageData::New();
-        originalImageData->ShallowCopy(anImageData);
+        inputImage = vtkSmartPointer<vtkImageData>::New();
+        inputImage->ShallowCopy(anImageData);
     } else
-        originalImageData = anImageData;
+        inputImage = anImageData;
 
     // 1. Get / compute the initial translation of the image
     double t_x, t_y, t_z;
-    originalImageData->GetOrigin(t_x, t_y, t_z);
-    vtkSmartPointer<vtkTransform> initialTranslation = vtkTransform::New();
+    inputImage->GetOrigin(t_x, t_y, t_z);
+    vtkSmartPointer<vtkTransform> initialTranslation = vtkSmartPointer<vtkTransform>::New();
     initialTranslation->Identity();
     initialTranslation->Translate(t_x, t_y, t_z);
     initialTranslation->Update();
 
     // 2. Get the orientation of the image
-    double* imgSpacing = originalImageData->GetSpacing();
-    int* imgDims    = originalImageData->GetDimensions();
+    double* imgSpacing = inputImage->GetSpacing();
+    int* imgDims    = inputImage->GetDimensions();
     double dims[3];
     dims[0] = imgSpacing[0] * imgDims[0];
     dims[1] = imgSpacing[1] * imgDims[1];
@@ -259,30 +273,30 @@ void ImageComponent::setImageData(vtkSmartPointer<vtkImageData> anImageData,
     addProperty(orientationProperty);
 
     // 4. Store the Translation * orientation -> RAI = initialImageDataTransform
-    initialImageDataTransform = vtkTransform::New();
-    vtkSmartPointer<vtkMatrix4x4> initialImageDataMatrix = vtkMatrix4x4::New();
+    initialImageDataTransform = vtkSmartPointer<vtkTransform>::New();
+    vtkSmartPointer<vtkMatrix4x4> initialImageDataMatrix = vtkSmartPointer<vtkMatrix4x4>::New();
     vtkMatrix4x4::Multiply4x4(initialTranslation->GetMatrix(), orientationToRAIMatrix, initialImageDataMatrix);
     initialImageDataTransform->SetMatrix(initialImageDataMatrix);
 
     // 5. Store the rotation * translation * orientation -> RAI = initialFrameTransform
-    initialFrameTransform = vtkTransform::New();
-    vtkSmartPointer<vtkMatrix4x4> initialFrameMatrix = vtkMatrix4x4::New();
-    if(!initialRotationMatrix){
-        initialRotationMatrix = vtkMatrix4x4::New();
-        initialRotationMatrix->Identity();
-    }
+    initialFrameTransform = vtkSmartPointer<vtkTransform>::New();
+    vtkSmartPointer<vtkMatrix4x4> initialFrameMatrix = vtkSmartPointer<vtkMatrix4x4>::New();
     rotationMatrix = initialRotationMatrix;
-    vtkMatrix4x4::Multiply4x4(initialRotationMatrix, initialTranslation->GetMatrix(), initialFrameMatrix);
+    if(!rotationMatrix) {
+        rotationMatrix = vtkSmartPointer<vtkMatrix4x4>::New();
+        rotationMatrix->Identity();
+    }
+    vtkMatrix4x4::Multiply4x4(rotationMatrix, initialTranslation->GetMatrix(), initialFrameMatrix);
     vtkMatrix4x4::Multiply4x4(initialFrameMatrix, orientationToRAIMatrix, initialFrameMatrix);
     initialFrameTransform->SetMatrix(initialFrameMatrix);
 
     // 6. Apply initialImageDataTransform to the image data
     vtkSmartPointer<vtkImageReslice> imageResliceFilter = vtkSmartPointer<vtkImageReslice>::New();
-    imageResliceFilter->SetInput(anImageData);
+    imageResliceFilter->SetInputData(inputImage);
     imageResliceFilter->SetOutputDimensionality(3);
     imageResliceFilter->SetResliceAxes(initialImageDataTransform->GetMatrix());
+    imageResliceFilter->Update();
     originalImageData = imageResliceFilter->GetOutput();
-    originalImageData->Update();
 
     // 7. Store initialFrameTransform as the current frame
     // note: we need to get another matrix instance for the transformation (else it is deleted)
@@ -293,6 +307,10 @@ void ImageComponent::setImageData(vtkSmartPointer<vtkImageData> anImageData,
     updatedTransform->SetMatrix(updatedMatrix);
     setTransform(updatedTransform);
 
+    // Clean smart pointers
+    inputImage = NULL;
+    imageResliceFilter = NULL;
+
     // Build default lookup table
     initLookupTable();
 
@@ -303,75 +321,70 @@ void ImageComponent::setImageData(vtkSmartPointer<vtkImageData> anImageData,
     updateImageProperties();
 }
 
-// -------------------- prepareForSaving --------------------
-void ImageComponent::prepareForSaving() {
+// -------------------- getImageDataWithFrameTransform --------------------
+vtkSmartPointer<vtkImageData> ImageComponent::getImageDataWithFrameTransform() {
+    vtkSmartPointer<vtkImageData> imageDataFramed = vtkSmartPointer<vtkImageData>::New();
+    imageDataFramed->DeepCopy(originalImageData);
 
     // 1. Put back image data to its original state
-    vtkSmartPointer<vtkMatrix4x4> backToOriginalImageDataMatrix = vtkMatrix4x4::New();
+    vtkSmartPointer<vtkMatrix4x4> backToOriginalImageDataMatrix = vtkSmartPointer<vtkMatrix4x4>::New();
     backToOriginalImageDataMatrix->DeepCopy(initialImageDataTransform->GetMatrix());
     backToOriginalImageDataMatrix->Invert();
     vtkSmartPointer<vtkImageReslice> backToOrigingImageDataFilter = vtkSmartPointer<vtkImageReslice>::New();
-    backToOrigingImageDataFilter->SetInput(originalImageData);
+    backToOrigingImageDataFilter->SetInputData(imageDataFramed);
     backToOrigingImageDataFilter->SetOutputDimensionality(3);
     backToOrigingImageDataFilter->SetResliceAxes(backToOriginalImageDataMatrix);
-    originalImageData = backToOrigingImageDataFilter->GetOutput();
-    originalImageData->Update();
+    imageDataFramed = backToOrigingImageDataFilter->GetOutput();
+    backToOrigingImageDataFilter->Update();
 
     // 2. Retrieve the matrice of the user Muser which has been applied to the initial frame
     // Assuming Mframe = MinitFrame * Muser
-    vtkSmartPointer<vtkMatrix4x4> initialFrameMatrixInverse = vtkMatrix4x4::New();
+    vtkSmartPointer<vtkMatrix4x4> initialFrameMatrixInverse = vtkSmartPointer<vtkMatrix4x4>::New();
     initialFrameMatrixInverse->DeepCopy(initialFrameTransform->GetMatrix());
     initialFrameMatrixInverse->Invert();
     const vtkSmartPointer<vtkTransform> frame = getTransform();
     vtkSmartPointer<vtkMatrix4x4> frameMatrix = frame->GetMatrix();
-    vtkSmartPointer<vtkMatrix4x4> userMatrix = vtkMatrix4x4::New();
+    vtkSmartPointer<vtkMatrix4x4> userMatrix = vtkSmartPointer<vtkMatrix4x4>::New();
     vtkMatrix4x4::Multiply4x4(initialFrameMatrixInverse, frameMatrix , userMatrix);
-    vtkSmartPointer<vtkTransform> userTransform = vtkTransform::New();
+
+    vtkSmartPointer<vtkTransform> userTransform = vtkSmartPointer<vtkTransform>::New();
     userTransform->SetMatrix(userMatrix);
 
     // 3. Retrieve the translation of the user matrix and apply it to the image data
     // This way, the translation will be saved under the Offset tag
     double pos[3];
     userTransform->GetPosition(pos);
-    vtkSmartPointer<vtkTransform> translationTransform = vtkTransform::New();
+    vtkSmartPointer<vtkTransform> translationTransform = vtkSmartPointer<vtkTransform>::New();
     translationTransform->Identity();
     translationTransform->Translate(pos[0], pos[1], pos[2]);
     translationTransform->Update();
     vtkSmartPointer<vtkImageReslice> translationFilter = vtkSmartPointer<vtkImageReslice>::New();
-    translationFilter->SetInput(originalImageData);
+    translationFilter->SetInputData(imageDataFramed);
     translationFilter->SetOutputDimensionality(3);
     translationFilter->SetResliceAxes(translationTransform->GetMatrix());
-    originalImageData = translationFilter->GetOutput();
-    originalImageData->Update();
+    imageDataFramed = translationFilter->GetOutput();
+    translationFilter->Update();
 
     // 4. Retrieve the rotation matrix from the user matrix to manually save it
     // only if user has modify it
     if( (userMatrix->GetElement(0,0) != 1) ||
-        (userMatrix->GetElement(1,1) != 1) ||
-        (userMatrix->GetElement(2,2) != 1) ){
+            (userMatrix->GetElement(1,1) != 1) ||
+            (userMatrix->GetElement(2,2) != 1) ) {
 
-        rotationMatrix = vtkMatrix4x4::New();
+        rotationMatrix = vtkSmartPointer<vtkMatrix4x4>::New();
         rotationMatrix->DeepCopy(userMatrix);
         rotationMatrix->SetElement(0, 3, 0.0);
         rotationMatrix->SetElement(1, 3, 0.0);
         rotationMatrix->SetElement(2, 3, 0.0);
     }
-}
 
-// -------------------- postSaving --------------------
-void ImageComponent::postSaving(){
-    // Revert changes made on image data
-    vtkSmartPointer<vtkImageReslice> revertImageDataFilter = vtkSmartPointer<vtkImageReslice>::New();
-    revertImageDataFilter->SetInput(originalImageData);
-    revertImageDataFilter->SetOutputDimensionality(3);
-    revertImageDataFilter->SetResliceAxes(initialImageDataTransform->GetMatrix());
-    originalImageData = revertImageDataFilter->GetOutput();
-    originalImageData->Update();
+    return imageDataFramed;
 }
 
 // -------------------- initLookupTable --------------------
 void ImageComponent::initLookupTable() {
 
+
     // TODO set in a betterway information about the lut thanks to image data
     if (this->originalImageData->GetNumberOfScalarComponents() == 1) {
         // Default values for grey level lut
@@ -387,10 +400,9 @@ void ImageComponent::initLookupTable() {
 
     } else {
         // For colored image, we need to extract the information from the image
-        // but a classic lut is not really easy to use.
-        // delete default LUT
-        //lut = NULL;
-        lut->ForceBuild();
+        // but a classic lut is useless (if there is one, it displays wrong information)
+        // do not consider a lut for colored images
+        lut = NULL;
     }
 }
 
@@ -427,8 +439,6 @@ void ImageComponent::replaceImageData(vtkSmartPointer<vtkImageData> anImageData,
         volumeRenderingChild = NULL;
     }
 
-    deleteChildren();
-
     this->refreshInterfaceNode();
 
     setImageData(anImageData, copy, initialOrientation);
@@ -456,6 +466,7 @@ SingleImageComponent * ImageComponent::getArbitrarySlices() {
     return this->arbitrarySlices;
 }
 
+// ---------------- getVolumeRenderingChild -------------------
 MeshComponent * ImageComponent::getVolumeRenderingChild() {
     return this->volumeRenderingChild;
 }
