@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,11 +35,11 @@
 #include "qtpropertymanager.h"
 
 // -- QT stuff
-#include <QtCore/QMetaObject>
-#include <QtCore/QMetaProperty>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QScrollArea>
-#include <QtGui/QMessageBox>
+#include <QMetaObject>
+#include <QMetaProperty>
+#include <QVBoxLayout>
+#include <QScrollArea>
+#include <QMessageBox>
 #include <QSize>
 
 // -- stl stuff
@@ -360,6 +360,13 @@ void ObjectControllerPrivate::addDynamicProperties ( QObject *edited ) {
                                 Q_RETURN_ARG(Property*, camitkProp),
                                 Q_ARG(QString, pName));
 
+        // try harder (in case the edited object was not declared in the camitk namespace)
+        if (!getPropertyExist) {
+            getPropertyExist = QMetaObject::invokeMethod(edited, "getProperty", Qt::DirectConnection,
+                               Q_RETURN_ARG(camitk::Property*, camitkProp),
+                               Q_ARG(QString, pName));
+        }
+
         if (!getPropertyExist || camitkProp==NULL) {
             // the old way, build a simple dynamic variant property
             subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ true, false, false, true);
