@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -49,7 +49,7 @@ namespace camitk {
  *
  *  Properties can be grouped in subgroups, see Property::setGroupName().
  *
- *  Basically this is a way to overcomes the Qt Meta Object properties limitations.
+ *  Basically this is a way to overcome the Qt Meta Object properties limitations.
  *  A camitk::Property enriches a Qt Meta Object property (a very simplified
  *  Decorator Design Pattern).
  *
@@ -59,6 +59,71 @@ namespace camitk {
  *  Note that a camitk::Property is represented as a regular Qt Meta Object property
  *  as well (the value of the camitk::Property is in fact stored by the Qt Meta Object property)
  *
+ *  Here are some examples to get started with:
+ *  \code
+    // Demonstrates how rich text can be used in description
+    addParameter(new Property("Bool Prop", false, "This a <i>normal</i> bool property.<br/><b>Note:</b> Rich text description!<br/>See also: <a href=\"http://camitk.imag.fr\">CamiTK web page</a>", ""));
+
+    // beware: the action takes ownership of the Property pointer
+    // This means that the line above does not generate memory leak.
+
+    // Demonstrates how properties can be set as read-only
+    // Demonstrates how properties can be grouped.
+    // Here all read-only properties are assemble in the same eponymic group
+    Property *readOnlyBool = new Property("Read Only Bool", true, "This a read-only boolean", "");
+    readOnlyBool->setReadOnly(true);
+    readOnlyBool->setGroupName("Read Only Properties");
+    addParameter(readOnlyBool);
+
+    // beware: the action takes ownership of the Property pointer
+    // This means that you should NOT delete readOnlyBool in the action desctructor
+
+    // Demonstrates how integer properties can be bounded
+    Property *boundedInt = new Property("Bounded Int", 12, "An integer bounded between 0 and 20", "");
+    boundedInt->setAttribute("minimum", 0);
+    boundedInt->setAttribute("maximum", 20);
+    boundedInt->setGroupName("Numeric Properties");
+    addParameter(boundedInt);
+
+    // Demonstrates how double properties can be half-bounded
+    Property *doubleWithMax = new Property("Double With Max", -10.0, "A double with a max value of -4.2", "");
+    doubleWithMax->setAttribute("maximum", -4.2);
+    doubleWithMax->setGroupName("Numeric Properties");
+    addParameter(doubleWithMax);
+
+    Property *intWithSingleStep = new Property("Int With Single Step", -10, "An integer with a single step of <i>5</i>", "");
+    intWithSingleStep->setAttribute("singleStep", 5);
+    intWithSingleStep->setGroupName("Numeric Properties");
+    addParameter(intWithSingleStep);
+
+    Property *doubleWithStepAndDecimal = new Property("Double With Single Step And Precision", 3.14159, "A double with 5 decimals and a single step of 1.10<sup>-5</sup>", "");
+    doubleWithStepAndDecimal->setAttribute("singleStep", 10e-6);
+    doubleWithStepAndDecimal->setAttribute("decimals", 5);
+    doubleWithStepAndDecimal->setGroupName("Numeric Properties");
+    addParameter(doubleWithStepAndDecimal);
+
+    Property *intWithDecimal = new Property("Int With Precision", 4, "An integer with a precision set to 5 decimals: this should not affect it.", "");
+    intWithDecimal->setAttribute("decimals", 5);
+    intWithDecimal->setGroupName("Numeric Properties");
+    addParameter(intWithDecimal);
+
+    Property *readOnlyQVector3D = new Property("Read Only QVector3D", QVector3D(-4.0, 2.0, 0.1), "A read-only QVector3D", "");
+    readOnlyQVector3D->setReadOnly(true);
+    readOnlyQVector3D->setGroupName("Read Only Properties");
+    addParameter(readOnlyQVector3D);
+
+    Property *stringWithRegExp = new Property("QString Constrained by RegExp", QString("loweronly"), "A QString contrained to lowercase characters only (no separators, numbers...)", "");
+    stringWithRegExp->setAttribute("regExp",QRegExp("[a-z]*"));
+    addParameter(stringWithRegExp);
+
+    Property *constrainedQRect = new Property("Constrained QRect", QRect(10,10,20,20), "A QRect contrained to (0,0,50,50)", "");
+    constrainedQRect->setAttribute("constraint", QRect(0,0,50,50));
+    addParameter(constrainedQRect);
+
+    Property *constrainedQVector3D = new Property("Constrained QVector3D", QVector3D(1.1, 2.2, 3.3), "A constrained QVector3D (not yet implemented)", "");
+    constrainedQVector3D->setAttribute("constraint", QVector3D(10.0, 10.0, 10.0));
+    addParameter(constrainedQVector3D);
+    \endcode
  * @note
  * To create a new Property, prefer using Property.
  * To check if a Property has been added to your Component / Action, use either Component::getProperty() or Action::getProperty() methods.
@@ -188,7 +253,7 @@ namespace camitk {
     \endcode
     \note
     This is not exactly a decorator pattern, as the Property class is not abstract. The Qt
-    Meta Object is still hold by the QtObject inherited class (e.g. Component or Action).
+    Meta Object is still held by the QtObject inherited class (e.g. Component or Action).
     The camitk::Property class adds description, readOnly status and specific attributes to
     a QObject dynamic property.
  */
@@ -205,6 +270,9 @@ public:
      */
     Property(QString name, const QVariant &variant, QString description, QString unit);
 
+    /// Destructor
+    virtual ~Property() {}
+
     /// get the name of the property
     const QString & getName() const;
 
