@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,6 +31,7 @@
 #include "CamiTKAPI.h"
 #include "Component.h"
 #include "Viewer.h"
+#include "RendererWidget.h"
 
 //-- QT stuff
 #include <QFrame>
@@ -52,12 +53,14 @@ class vtkEventQtSlotConnect;
 
 namespace camitk {
 // -- Core stuff classes
-class RendererWidget;
 class SliderSpinBoxWidget;
 class GeometricObject;
 class InterfaceGeometry;
 class InterfaceBitMap;
 class InteractiveViewer;
+class MeshDataFilterModel;
+class PropertyObject;
+class Property;
 
 typedef vtkSmartPointer<vtkCamera> vtkSmartPointerCamera;
 
@@ -65,7 +68,7 @@ typedef vtkSmartPointer<vtkCamera> vtkSmartPointerCamera;
 class InteractiveViewerFrame : public QFrame {
 public:
     /// default constructor
-    InteractiveViewerFrame ( QWidget* parent, InteractiveViewer* s3D ) : QFrame ( parent ), myInteractiveViewer ( s3D ) {};
+    InteractiveViewerFrame ( QWidget* parent, InteractiveViewer* s3D ) : QFrame ( parent ), myInteractiveViewer ( s3D ) {}
 
     /// Handle keyboard events in the scene frame, just send everything to InteractiveViewer!
     void keyPressEvent ( QKeyEvent* );
@@ -78,8 +81,7 @@ protected:
   * @ingroup group_sdk_libraries_core_viewer
   *
   * @brief
-  * InteractiveViewer is used to view 3D objects and slices (anything that provides either a InterfaceBitMap
-  * or a InterfaceGeometry).
+  * InteractiveViewer is used to view 3D objects and slices (anything that provides either a InterfaceBitMap or a InterfaceGeometry).
   *
   * It contains a renderer (class RendererWidget) that combines VTK and QT.
   * The RendererWidget instance manage all the display at the VTK level.
@@ -137,12 +139,6 @@ protected:
 class CAMITK_API InteractiveViewer : public Viewer {
     Q_OBJECT
     Q_ENUMS ( HighlightMode RendererWidget::ControlMode RendererWidget::CameraOrientation ) // so that it can be used in property editor
-    Q_PROPERTY ( HighlightMode highlightMode READ getHighlightMode WRITE setHighlightMode )
-    Q_PROPERTY ( QColor backgroundColor READ getBackgroundColor WRITE setBackgroundColor )
-    Q_PROPERTY ( bool gradientBackground READ getGradientBackground WRITE setGradientBackground )
-    Q_PROPERTY ( bool linesAsTubes READ getLinesAsTubes WRITE setLinesAsTubes )
-    Q_PROPERTY ( bool backfaceCulling READ getBackfaceCulling WRITE setBackfaceCulling )
-    Q_PROPERTY ( double pointSize READ getPointSize WRITE setPointSize )
 
 public:
     /// \enum ViewerType there is two possibilities: this InteractiveViewer is used to display slices or geometry
@@ -184,7 +180,7 @@ public:
     static InteractiveViewer * getNewViewer ( QString , ViewerType type );
 
     /// get a viewer by its name (return NULL if no instance has the given name, use getNewViewer to create one viewer)
-    static InteractiveViewer *getViewer ( QString );
+    static InteractiveViewer * getViewer ( QString );
 
     /// get the 3D viewer default InteractiveViewer (provided for convenience, equivalent to getViewer("3DViewer")
     static InteractiveViewer * get3DViewer();
@@ -256,30 +252,23 @@ public slots:
     void screenshot();
     /// @}
 
-    /** @name Viewing/Interaction Property
-     */
-    ///@{
-
 public:
     /// set gradient background on/off
     virtual void setGradientBackground ( bool );
 
-    /// get the current background gradient mode.
-    bool getGradientBackground() const;
-
     /// set background color
     virtual void setBackgroundColor ( QColor );
 
-    /// get the background color
-    QColor getBackgroundColor() const;
-
+    /** @name Viewing/Interaction Property
+     */
+    ///@{
 public slots:
     /// set the backface culling mode (default is true).
     void setBackfaceCulling ( bool );
 
 public:
     /// get the backface current culling mode.
-    bool getBackfaceCulling() const;
+    // bool getBackfaceCulling() const;
 
 public slots:
     /** Update the visualization of lines (for all the InterfaceGeometry of the scene).
@@ -295,27 +284,9 @@ public:
     /// Handle keyboard events in the scene, let to the parent widget if not processed here. This method is a friend of class InteractiveViewerFrame
     void keyPressEvent ( QKeyEvent* e );
 
-    /// get the boolean indicating if the lines are currently set to be displayed as tubes.
-    bool getLinesAsTubes() const;
-
-    /** update the visualization of points (for all object3D in the scene).
-      *
-      * This property acts directly on the actor, thus it can be changed outside the InterfaceGeometry,
-      * thus the InterfaceGeometry should not be aware of its value (no method should be concerned with
-      * this property)
-      *
-      */
-    void setPointSize ( double size );
-
-    /// get the current point size value
-    double getPointSize() const;
-
     /// Set the current highlighting mode.
     virtual void setHighlightMode ( InteractiveViewer::HighlightMode );
 
-    /// Return the current highlighting mode.
-    InteractiveViewer::HighlightMode getHighlightMode() const;
-
     /// return interactiveViewer RendererWidget
     inline RendererWidget * getRendererWidget() {
         return rendererWidget;
@@ -413,15 +384,9 @@ protected:
     /// type of InteractiveViewer (display slice or geometry)
     ViewerType myType;
 
-    /// Are lines currently displayed as tubes (the actors have to add a vtkTubeFilter between the source and the mapper)
-    bool linesAsTubes;
-
     /// for InterfaceBitMap, toggle the interpolation mode (intern method, not a property because it can only be modified by the keyboard interaction)
     void toggleInterpolation();
 
-    /// keep the value of the hightlight mode
-    HighlightMode highlightMode;
-
     /// Update the display of the given Component, according to its selection state and the current HighlightMode.
     void updateSelectionDisplay ( Component * );
 
@@ -466,6 +431,11 @@ protected:
     /// the QToolBar for the InteractiveViewer
     QToolBar *viewerToolBar;
 
+    /// the ComboBox for mesh scalar data
+    QComboBox* scalarDataComboBox;
+
+    MeshDataFilterModel* scalarDataModel;
+
     /// init all the actions (called only once in the getWidget() method)
     void initActions();
 
@@ -482,6 +452,7 @@ protected:
     QAction *pointsAction;
     QAction *colorAction;
     QAction *glyphAction;
+    QWidgetAction *scalarDataColorAction;
 
     /// display mode
     QAction *highlightSelectionAction;
@@ -523,7 +494,6 @@ protected:
     QAction *pickCellAction;
     QAction* pickCellRegionAction;
     QAction* pickPointRegionAction;
-    //TODO QAction *pickRegionAction; /// to pick a region by selecting top left / bottom right corners
 
     ///@}
 
@@ -539,6 +509,9 @@ protected:
     /** Current picking mode, NO_PICKING be default. */
     PickingMode pickingMode;
 
+    /// Indicate that this viewer is picking.
+    bool isPicking;
+
     /// picking effect while mouse button is kept pressed is selecting (depends on the selection state of the first component picked)
     bool pickingEffectIsSelecting;
 
@@ -549,7 +522,6 @@ protected:
 
     ///@}
 
-
     /** @name Help Whats This Utility
       */
     /// @{
@@ -572,10 +544,65 @@ protected:
     void addWhatsThisItem ( const QString & key, const QString & description );
     /// @}
 
-protected slots:
-    /** @name All the slots called by the menu actions
+    /**
+      * @name CamiTK Properties of this viewer
       */
     ///@{
+    /**
+     * The property object that holds the properties of this viewer
+     */
+    PropertyObject* propertyObject;
+
+    /**
+     * The property that stands for the type of highlight mode of the 3D viewer.
+     */
+    Property* highlightModeProperty;
+
+    /**
+     * The property that stands for the background color of the viewer.
+     */
+    Property* backgroundColorProperty;
+
+    /**
+     * Property that tells whether the viewer use a gradient background color or not.
+     */
+    Property* backgroundGradientColorProperty;
+
+    /**
+     *  Property that tells whether the viewer uses lines as tubes or not.
+     */
+    Property* linesAsTubesProperty;
+
+    /**
+     * Property that tells whether the viewer uses the backface culling option or not.
+     */
+    Property* backfaceCullingProperty;
+
+    /**
+     * Property which defines the point size of each point in the 3D viewer.
+     */
+    Property* pointSizeProperty;
+
+    /**
+     * Create and handle the CamiTK properties of this viewer.
+     */
+    void createProperties();
+
+    /**
+     * Event filter of this class instance to watch its properties instances.
+     * Each time a property has dynamically changed, this method is called.
+     *
+     * @note Only used by Geometry viewers
+     */
+    bool eventFilter(QObject *object, QEvent *event);
+
+    ///@}
+
+protected slots:
+    /**
+     * @name All the slots called by the menu actions
+     */
+    ///@{
     void renderingActorsChanged();
 
     void highlightModeChanged ( QAction *selectedAction );
@@ -603,10 +630,14 @@ protected slots:
     void setGlyph(bool);
 
     ///@}
+
+
+
 };
 
 }
 
+Q_DECLARE_METATYPE(camitk::InteractiveViewer::HighlightMode)
 
 #endif
 
