@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -26,6 +26,7 @@
 // -- Core stuff
 #include "Application.h"
 #include "PropertyExplorer.h"
+#include "Component.h"
 
 // -- QT stuff
 #include <QVBoxLayout>
@@ -43,11 +44,17 @@ PropertyExplorer::PropertyExplorer() : Viewer("Property Explorer") {
     revertButton = NULL;
     applyButton = NULL;
     currentComponent = NULL;
+
+    createProperties();
 }
 
 // ---------------- destructor ----------------
 PropertyExplorer::~PropertyExplorer() {
     clear();
+    if(propertyObject)
+        delete propertyObject;
+    if(viewModeProperty)
+        delete viewModeProperty;
 }
 
 //----------------------- getInstance ------------------------
@@ -125,13 +132,11 @@ QWidget * PropertyExplorer::getWidget(QWidget * parent) {
         // get user pref for view mode
         QSettings & settings = Application::getSettings();
         settings.beginGroup("PropertyExplorer");
-
-        // the background color
-        ObjectController::ViewMode mode = (ObjectController::ViewMode) settings.value("viewMode", ObjectController::BUTTON).toInt();
+        ObjectController::ViewMode mode = (ObjectController::ViewMode) propertyObject->property(viewModeProperty->getName().toStdString().c_str()).toInt();
         settings.endGroup();
 
         // first the property editor
-        theController = new ObjectController(propertyFrame,mode);
+        theController = new ObjectController(propertyFrame, mode);
         propertyTabLayout->addWidget(theController);
 
         // then the buttons
@@ -168,22 +173,7 @@ QWidget * PropertyExplorer::getWidget(QWidget * parent) {
 
 // ---------------- getPropertyObject ----------------
 QObject * PropertyExplorer::getPropertyObject() {
-    return this;
-}
-
-
-// ---------------- getViewMode ----------------
-const ObjectController::ViewMode PropertyExplorer::getViewMode() {
-    return theController->getViewMode();
-}
-
-// ---------------- setViewMode ----------------
-void PropertyExplorer::setViewMode(ObjectController::ViewMode mode) {
-    theController->setViewMode(mode);
-    QSettings & settings = Application::getSettings();
-    settings.beginGroup("PropertyExplorer");
-    settings.setValue("viewMode", mode);
-    settings.endGroup();
+    return propertyObject;
 }
 
 // ---------------- clear ----------------
@@ -202,7 +192,7 @@ void PropertyExplorer::clear() {
 void PropertyExplorer::selectWidget(QWidget* widget) {
     // get the last component tab widgets
     QWidget * customWidget;
-    for (unsigned int i=0; i < this->tabWidget->count(); i++) {
+    for (int i=0; i < this->tabWidget->count(); i++) {
         customWidget = this->tabWidget->widget(i);
         if (customWidget && (customWidget == widget)) {
             this->tabWidget->setCurrentWidget(widget);
@@ -213,7 +203,7 @@ void PropertyExplorer::selectWidget(QWidget* widget) {
 
 // ---------------- selectIndex ----------------
 void PropertyExplorer::selectIndex(unsigned int index) {
-    if ((index >= 0) && (index < this->tabWidget->count()))
+    if ((index >= 0) && ((int)index < this->tabWidget->count()))
         this->tabWidget->setCurrentIndex(index);
 }
 
@@ -225,7 +215,48 @@ void PropertyExplorer::updateTabIndexToDisplay(int index) {
     }
 }
 
+// ---------------- eventFilter ----------------
+bool PropertyExplorer::eventFilter(QObject *object, QEvent *event) {
+    // watch propertyObject instance for dynamic property changes
+    if(event->type() == QEvent::DynamicPropertyChange) {
+        // objectcontroller view mode update
+        ObjectController::ViewMode mode = (ObjectController::ViewMode) propertyObject->property(viewModeProperty->getName().toStdString().c_str()).toInt();
+        theController->setViewMode(mode);
+        QSettings & settings = Application::getSettings();
+        settings.beginGroup("PropertyExplorer");
+        settings.setValue("viewMode", mode);
+        settings.endGroup();
+        return true;
 
+    } else {
+        // pass the event on to the parent class
+        return Viewer::eventFilter(object, event);
+    }
+
+}
+
+// ---------------- createProperties ----------------
+void PropertyExplorer::createProperties() {
+    // viewer properties
+    propertyObject = new PropertyObject("Property Explorer");
+
+    // view mode property
+    // get the value store in the application settings
+    QSettings & settings = Application::getSettings();
+    settings.beginGroup("PropertyExplorer");
+    ObjectController::ViewMode mode = (ObjectController::ViewMode) settings.value("viewMode", ObjectController::BUTTON).toInt();
+    settings.endGroup();
+
+    viewModeProperty = new Property("View mode", mode, "The display type of the PropertyExplorer", "");
+    viewModeProperty->setEnumTypeName("camitk::ObjectController::ViewMode");
+    QStringList viewModeNames;
+    viewModeNames << "Tree" << "Groupbox" << "Button";
+    viewModeProperty->setAttribute("enumNames", viewModeNames);
+    propertyObject->addProperty(viewModeProperty);
+
+    // propertyObject is monitored by the PropertyExplorer instance (this) when its properties change
+    propertyObject->installEventFilter(this);
+}
 
 
 }
