@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -33,6 +33,8 @@
 #include <QKeyEvent>
 #include <QFileInfo>
 #include <QCursor>
+#include <QProcessEnvironment>
+#include <QOpenGLContext>
 
 // -- VTK stuff
 #include <vtkObjectFactory.h>
@@ -95,7 +97,7 @@
 namespace camitk {
 
 //--------------- Picking Interactor ---------------------------------------
-vtkCxxRevisionMacro(vtkInteractorStylePick, "$Revision: 1.1 $");
+vtkInstantiatorNewMacro(vtkInteractorStylePick);
 vtkStandardNewMacro(vtkInteractorStylePick);
 //--------------------------------------------------------------------------
 vtkInteractorStylePick::vtkInteractorStylePick() {
@@ -325,7 +327,7 @@ void vtkInteractorStylePick::Pick() {
 
         vtkAssemblyPath *path = NULL;
         rwi->StartPickCallback();
-        vtkAbstractPropPicker *picker =
+        vtkSmartPointer<vtkAbstractPropPicker> picker =
             vtkAbstractPropPicker::SafeDownCast ( rwi->GetPicker() );
         if ( picker != NULL ) {
             vtkAreaPicker *areaPicker = vtkAreaPicker::SafeDownCast ( picker );
@@ -337,6 +339,7 @@ void vtkInteractorStylePick::Pick() {
                                0.0, this->CurrentRenderer );
             }
             path = picker->GetPath();
+            picker = NULL;
         }
         if ( path == NULL ) {
             this->HighlightProp ( NULL );
@@ -361,7 +364,7 @@ void vtkInteractorStylePick::PrintSelf ( ostream& os, vtkIndent indent ) {
 QMap <RendererWidget::ScreenshotFormat , RendererWidget::ScreenshotFormatInfo*> screenshotMap;
 
 //---------------------- Constructor ------------------------
-RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(parent) {
+RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget2(parent) {
     setObjectName( "RendererWidget" );
 
     //-- initialize screenshotMap only at the first invocation of constructor
@@ -378,7 +381,65 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
     policy.setHeightForWidth(false);
     setSizePolicy(policy);
 
-    //-- display options (this is not a state manage by the renderer, but a property of the actors
+    //-- OpenGL context on integrated card
+    // For more information about this problem
+    // see https://bugzilla-timc.imag.fr/show_bug.cgi?id=181
+    
+    // Description of the bugfix:
+    // In order to make it work on integrated cards as well as on GPU (using primusrun
+    // see below for optirun), RendererWidget is now inheriting from QVTKWidget2 (which
+    // in turns inherits from QGLWidget, which is deprecated...)
+    //
+    // Unfortunately this trigger another bug where, although everything is alright
+    // when running on the GPU (using primusrun), it does not work on the integrated card.
+    // 
+    // To make it work on both, the OpenGL format has to be reinitialized.
+    //
+    // This might lead to performance issue (not investigated). If this is the case,
+    // set the environment variable CAMITK_NO_OPENGL_RESET to 1.
+    // For instance:
+    // CAMITK_NO_OPENGL_RESET=1 primusrun bin/camitk-imp 
+    // or 
+    // CAMITK_NO_OPENGL_RESET=1 bin/camitk-imp
+    //
+    // If the CAMITK_NO_OPENGL_RESET environment variable is set to 1, then the OpenGL context will not be
+    // reset.
+    
+    // Note for bumblebee users on Linux:
+    // There is a bug in bumblebee/optirun, see https://bugreports.qt.io/browse/QTBUG-33258
+    // you need to use primusrun (which is also the bumblebee developer team recommendation)
+    
+    /*
+    qDebug() << "------------------------ OpenGL information -------------------------" ;
+    qDebug() << "OpenGL Versions Supported: " << QGLFormat::openGLVersionFlags() ;
+    qDebug() << "Current format:" << format();
+    qDebug() << "Context valid: " << context()->isValid() ;
+    qDebug() << "Direct rendering: " << context()->format().directRendering();
+    qDebug() << "Context OpenGL Version: " << context()->format().majorVersion() << "." << context()->format().minorVersion() ;
+    qDebug() << "Vendor: " << (const char*)glGetString(GL_VENDOR);
+    qDebug() << "Renderer: " << (const char*)glGetString(GL_RENDERER);
+    qDebug() << "Version: " << (const char*)glGetString(GL_VERSION) ;
+    qDebug() << "GLSL version: " << (const char*)glGetString(GL_SHADING_LANGUAGE_VERSION) ;
+    qDebug() << "---------------------------------------------------------------------\n";
+    */
+    
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    bool resetOpenGL = true;
+    if (env.contains("CAMITK_NO_OPENGL_RESET") && env.value("CAMITK_NO_OPENGL_RESET") == "1") {
+        CAMITK_INFO("RendererWidget", "constructor", "CAMITK_NO_OPENGL_RESET on: QGLFormat is not reset\n");
+        resetOpenGL = false;
+    }
+     
+    if (resetOpenGL) {
+        // recreate a format, using some default from the current context
+        QGLFormat newFormat;
+        newFormat.setProfile(context()->format().profile());
+        newFormat.setDepthBufferSize(context()->format().depthBufferSize());
+        newFormat.setStencilBufferSize(context()->format().stencilBufferSize());
+        context()->setFormat(newFormat);
+    }
+    
+    //-- display options (this is not a state managed by the renderer, but a property of the actors)
     backfaceCulling = false;
     displayCopyright = true;
     rendering3DRedBlue = false;
@@ -386,12 +447,11 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
     pointSize = 4.0;
 
     //-- render window
-    vtkSmartPointer<vtkRenderWindow> renderWindow = vtkRenderWindow::New();
+    vtkSmartPointer<vtkRenderWindow> renderWindow = GetRenderWindow();
 
     //-- renderer
-    renderer = vtkRenderer::New();
+    renderer = vtkSmartPointer<vtkRenderer>::New();
     renderWindow->AddRenderer( renderer );
-    SetRenderWindow( renderWindow );
 
     //-- interactor
     interactor = vtkSmartPointer<QVTKInteractor>::New();
@@ -476,7 +536,7 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
     annotatedCube->SetXFaceTextRotation(90);
     annotatedCube->SetZFaceTextRotation(90);
     annotatedCube->SetFaceTextScale(0.65);
-    vtkSmartPointer<vtkTransform> transform = vtkTransform::New();
+    vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
     transform->Identity();
     transform->Scale(0.05, 0.05, 0.05); // 5% of unit length
     annotatedCube->GetAssembly()->SetPosition(0.0, 0.0, 0.0);
@@ -615,10 +675,10 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
 
 //----------------------   Destructor   ------------------------
 RendererWidget::~RendererWidget() {
-	// delete all properties
-	foreach(ScreenshotFormatInfo* sfi, screenshotMap.values())
-		delete sfi;
-	screenshotMap.clear();
+    // delete all properties
+    foreach(ScreenshotFormatInfo* sfi, screenshotMap.values())
+    delete sfi;
+    screenshotMap.clear();
 }
 
 //---------------------- buildScreenshotMap ------------------------
@@ -696,23 +756,14 @@ void RendererWidget::screenshot(QString filename) {
         break;
     case EPS:
         exporter = vtkSmartPointer<vtkGL2PSExporter>::New();
-        vtkGL2PSExporter::SafeDownCast(exporter)->CompressOff();
-        vtkGL2PSExporter::SafeDownCast(exporter)->SetFilePrefix(fileprefix);
-        vtkGL2PSExporter::SafeDownCast(exporter)->DrawBackgroundOn();
         vtkGL2PSExporter::SafeDownCast(exporter)->SetFileFormatToEPS();
         break;
     case PDF:
         exporter = vtkSmartPointer<vtkGL2PSExporter>::New();
-        vtkGL2PSExporter::SafeDownCast(exporter)->CompressOff();
-        vtkGL2PSExporter::SafeDownCast(exporter)->SetFilePrefix(fileprefix);
-        vtkGL2PSExporter::SafeDownCast(exporter)->DrawBackgroundOn();
         vtkGL2PSExporter::SafeDownCast(exporter)->SetFileFormatToPDF();
         break;
     case TEX:
         exporter = vtkSmartPointer<vtkGL2PSExporter>::New();
-        vtkGL2PSExporter::SafeDownCast(exporter)->CompressOff();
-        vtkGL2PSExporter::SafeDownCast(exporter)->SetFilePrefix(fileprefix);
-        vtkGL2PSExporter::SafeDownCast(exporter)->DrawBackgroundOn();
         vtkGL2PSExporter::SafeDownCast(exporter)->SetFileFormatToTeX();
         break;
         /* TODO export to POV and export to X3D using corresponding writer
@@ -723,9 +774,6 @@ void RendererWidget::screenshot(QString filename) {
           */
     case SVG:
         exporter = vtkGL2PSExporter::New();
-        vtkGL2PSExporter::SafeDownCast(exporter)->CompressOff();
-        vtkGL2PSExporter::SafeDownCast(exporter)->SetFilePrefix(fileprefix);
-        vtkGL2PSExporter::SafeDownCast(exporter)->DrawBackgroundOn();
         vtkGL2PSExporter::SafeDownCast(exporter)->SetFileFormatToSVG();
         break;
     case OBJ:
@@ -748,9 +796,25 @@ void RendererWidget::screenshot(QString filename) {
         break;
     }
 
+    // specific options for GL2PS exporter (Vtk 6 has a much better vtkGL2PSExporter)
+    vtkSmartPointer<vtkGL2PSExporter> gl2psExporter = vtkGL2PSExporter::SafeDownCast(exporter);
+    if (gl2psExporter) {
+        vtkGL2PSExporter::SafeDownCast(exporter)->CompressOff();
+        vtkGL2PSExporter::SafeDownCast(exporter)->SetSortToBSP();
+        vtkGL2PSExporter::SafeDownCast(exporter)->Write3DPropsAsRasterImageOff();
+        vtkGL2PSExporter::SafeDownCast(exporter)->SetFilePrefix(fileprefix);
+        vtkGL2PSExporter::SafeDownCast(exporter)->DrawBackgroundOff();
+    }
+
     if (exporter) {
+        bool displayGradientBackup = displayGradient;
+        if (displayGradientBackup)
+            setGradientBackground(false);
         exporter->SetInput(GetRenderWindow());
         exporter->Write();
+        if (displayGradientBackup)
+            setGradientBackground(true);
+        refresh();
     } else {
         if (imageWriter) {
             // create the proper vtk filter for export
@@ -799,6 +863,8 @@ void RendererWidget::setGradientBackground(bool gb) {
         renderer->GradientBackgroundOn();
         renderer->SetBackground(0.823, 0.823, 0.921); // light blue in the bottom
         renderer->SetBackground2(1, 1, 1); // white on top
+    } else {
+        renderer->GradientBackgroundOff();
     }
 
     // have to do that to force the display of (c) on top
@@ -1027,12 +1093,12 @@ void RendererWidget::updateAxes() {
 
     // the size of the annotated cube is about 5% of the size of the bound
     maxLength /= 2.0;
-    vtkSmartPointer<vtkTransform> transform = vtkTransform::New();
+    vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
     transform->Identity();
     transform->Scale(maxLength, maxLength, maxLength);
 
     // free the last user transform used. Not freeing it, caused a memory leak on each viewer->refresh() call
-    annotatedCube->GetAssembly()->GetUserTransform()->Delete();
+    // annotatedCube->GetAssembly()->GetUserTransform()->Delete();
 
     annotatedCube->GetAssembly()->SetUserTransform(transform);
 }
@@ -1246,20 +1312,24 @@ void RendererWidget::keyPressEvent(QKeyEvent* event) {
     event->ignore();
 }
 
+//--------------------- mousePressEvent ----------------------------------
 void RendererWidget::mousePressEvent ( QMouseEvent* event ) {
     if ( ( QApplication::keyboardModifiers() == Qt::ControlModifier ) &&
             ( event->button() == Qt::LeftButton ) ) {
         startPicking();
         pickInteractorStyle->OnLeftButtonDown();
-    } else if ( event->button() == Qt::RightButton ) {
-        emit rightButtonPressed();
+
+    } else {
+        if ( event->button() == Qt::RightButton ) {
+            emit rightButtonPressed();
+        }
+        QVTKWidget2::mousePressEvent ( event );
     }
-    QVTKWidget::mousePressEvent ( event );
 }
 
 //--------------------- mouseReleaseEvent ----------------------------------
 void RendererWidget::mouseReleaseEvent(QMouseEvent* event) {
-    QVTKWidget::mouseReleaseEvent ( event );
+    QVTKWidget2::mouseReleaseEvent ( event );
     endPicking();
 }
 
@@ -1299,7 +1369,7 @@ void RendererWidget::mouseMoveEvent(QMouseEvent* event) {
         // just keep the button pressed
         //pick();
     }
-    QVTKWidget::mouseMoveEvent(event);
+    QVTKWidget2::mouseMoveEvent(event);
 }
 
 
@@ -1409,5 +1479,4 @@ void RendererWidget::setPicker(vtkSmartPointer<vtkAbstractPropPicker> woodyWood)
     }
 }
 
-
 }
