@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+ * (c) 2001-2016 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -30,10 +30,14 @@
 #include "CamiTKAPI.h"
 
 // -- VTK stuff
-#include <QVTKWidget.h>
+#include <QVTKWidget2.h>
 #include <vtkSmartPointer.h>
 #include <vtkInteractorStyle.h>
-
+// additional needed headers for QVTKWidget2
+#include <vtkGenericOpenGLRenderWindow.h>
+#include <vtkRenderWindowInteractor.h>
+#include <QVTKInteractor.h>
+    
 // -- VTK stuff classes
 class vtkRenderer;
 class vtkInteractorStyle;
@@ -52,52 +56,55 @@ class vtkUnsignedCharArray;
 class vtkTextMapper;
 
 namespace camitk {
-// -- Core stuff classes
-class GeometricObject;
+    // -- Core stuff classes
+    class GeometricObject;
 
-/// Interactor used when we are in picking mode
-class vtkInteractorStylePick : public vtkInteractorStyle {
+    /// Interactor used when we are in picking mode
+    class vtkInteractorStylePick : public vtkInteractorStyle {
 
-public :
+    public:
 
-    static vtkInteractorStylePick * New();
-    vtkTypeRevisionMacro ( vtkInteractorStylePick, vtkInteractorStyle );
+        static vtkInteractorStylePick * New();
+        vtkTypeMacro(vtkInteractorStylePick, vtkInteractorStyle);
 
-    void PrintSelf ( ostream& os, vtkIndent indent );
+        void PrintSelf(ostream& os, vtkIndent indent);
 
-    void SetAreaPicking(bool b);
+        void SetAreaPicking(bool b);
 
-    virtual void OnLeftButtonDown();
+        virtual void OnLeftButtonDown();
 
-    virtual void OnLeftButtonUp();
+        virtual void OnLeftButtonUp();
 
-    virtual void OnMouseMove();
+        virtual void OnMouseMove();
 
-protected :
+    protected:
 
-    vtkInteractorStylePick();
-    ~vtkInteractorStylePick();
+        vtkInteractorStylePick();
+        ~vtkInteractorStylePick();
 
-    virtual void Pick();
+        virtual void Pick();
 
-    void RedrawRubberBand();
+        void RedrawRubberBand();
 
-    int StartPosition[2];
-    int EndPosition[2];
+        int StartPosition[2];
+        int EndPosition[2];
 
-    int Moving;
+        int Moving;
 
-    vtkUnsignedCharArray* PixelArray;
+        vtkUnsignedCharArray* PixelArray;
 
-    bool AreaPicking;
+        bool AreaPicking;
 
-// private :
-//
-//     vtkInteractorStylePick ( const vtkInteractorStylePick& ); // Not implemented
-//     void operator= ( const vtkInteractorStylePick& ); // Not implemented
+        // private :
+        //
+        //     vtkInteractorStylePick ( const vtkInteractorStylePick& ); // Not implemented
+        //     void operator= ( const vtkInteractorStylePick& ); // Not implemented
 
-};
+    };
 
+}
+
+namespace camitk{
 /**
  * @ingroup group_sdk_libraries_core_viewer
  *
@@ -109,15 +116,14 @@ protected :
  *
  * The Core companion class is InteractiveViewer (which delegates all vtk stuff to RendererWidget.
  *
- * It is directly based on QVTKWidget, the GUI support class available in Vtk version >= 5.0
+ * It is directly based on QVTKWidget2, the GUI support class available in Vtk version >= 5.0
  * This is a pure Qt/vtk wrapper class (no Core stuff).
  *
  * For developers: please check the coding policy in InteractiveViewer API documentation first.
  *
  *
 **/
-
-class CAMITK_API RendererWidget : public QVTKWidget {
+class CAMITK_API RendererWidget : public QVTKWidget2 {
     Q_OBJECT
     Q_ENUMS(ControlMode CameraOrientation); // so that it can be used in property editor
 
