@@ -48,18 +48,15 @@
 #include <QtGui/QAction>
 #include <QtGui/QDockWidget>
 
-void CanvasView::contentsMousePressEvent(QMouseEvent* event)
-{
+void CanvasView::contentsMousePressEvent(QMouseEvent* event) {
     handleMouseClickEvent(event);
 }
 
-void CanvasView::contentsMouseDoubleClickEvent(QMouseEvent* event)
-{
+void CanvasView::contentsMouseDoubleClickEvent(QMouseEvent* event) {
     handleMouseClickEvent(event);
 }
 
-void CanvasView::handleMouseClickEvent(QMouseEvent* event)
-{
+void CanvasView::handleMouseClickEvent(QMouseEvent* event) {
     QPoint p = inverseWorldMatrix().map(event->pos());
     QtCanvasItemList l = canvas()->collisions(p);
     moving = 0;
@@ -69,21 +66,19 @@ void CanvasView::handleMouseClickEvent(QMouseEvent* event)
     emit itemClicked(moving);
 }
 
-void CanvasView::contentsMouseMoveEvent(QMouseEvent* event)
-{
+void CanvasView::contentsMouseMoveEvent(QMouseEvent* event) {
     if (moving) {
-	QPoint p = inverseWorldMatrix().map(event->pos());
-	moving->moveBy(p.x() - moving_start.x(), p.y() - moving_start.y());
-	moving_start = p;
-	canvas()->update();
+        QPoint p = inverseWorldMatrix().map(event->pos());
+        moving->moveBy(p.x() - moving_start.x(), p.y() - moving_start.y());
+        moving_start = p;
+        canvas()->update();
         emit itemMoved(moving);
     }
 }
 
 
 MainWindow::MainWindow(QWidget *parent)
-    : QMainWindow(parent)
-{
+    : QMainWindow(parent) {
     QMenu *editMenu = menuBar()->addMenu(tr("Edit"));
     QMenu *newObjectMenu = editMenu->addMenu(tr("New Object"));
 
@@ -123,17 +118,17 @@ MainWindow::MainWindow(QWidget *parent)
     sizeManager = new QtSizePropertyManager(this);
 
     connect(doubleManager, SIGNAL(valueChanged(QtProperty *, double)),
-                this, SLOT(valueChanged(QtProperty *, double)));
+            this, SLOT(valueChanged(QtProperty *, double)));
     connect(stringManager, SIGNAL(valueChanged(QtProperty *, const QString &)),
-                this, SLOT(valueChanged(QtProperty *, const QString &)));
+            this, SLOT(valueChanged(QtProperty *, const QString &)));
     connect(colorManager, SIGNAL(valueChanged(QtProperty *, const QColor &)),
-                this, SLOT(valueChanged(QtProperty *, const QColor &)));
+            this, SLOT(valueChanged(QtProperty *, const QColor &)));
     connect(fontManager, SIGNAL(valueChanged(QtProperty *, const QFont &)),
-                this, SLOT(valueChanged(QtProperty *, const QFont &)));
+            this, SLOT(valueChanged(QtProperty *, const QFont &)));
     connect(pointManager, SIGNAL(valueChanged(QtProperty *, const QPoint &)),
-                this, SLOT(valueChanged(QtProperty *, const QPoint &)));
+            this, SLOT(valueChanged(QtProperty *, const QPoint &)));
     connect(sizeManager, SIGNAL(valueChanged(QtProperty *, const QSize &)),
-                this, SLOT(valueChanged(QtProperty *, const QSize &)));
+            this, SLOT(valueChanged(QtProperty *, const QSize &)));
 
     QtDoubleSpinBoxFactory *doubleSpinBoxFactory = new QtDoubleSpinBoxFactory(this);
     QtCheckBoxFactory *checkBoxFactory = new QtCheckBoxFactory(this);
@@ -170,36 +165,31 @@ MainWindow::MainWindow(QWidget *parent)
     itemClicked(0);
 }
 
-void MainWindow::newRectangle()
-{
+void MainWindow::newRectangle() {
     QtCanvasItem *item = addRectangle();
     canvas->update();
     itemClicked(item);
 }
 
-void MainWindow::newEllipse()
-{
+void MainWindow::newEllipse() {
     QtCanvasItem *item = addEllipse();
     canvas->update();
     itemClicked(item);
 }
 
-void MainWindow::newLine()
-{
+void MainWindow::newLine() {
     QtCanvasItem *item = addLine();
     canvas->update();
     itemClicked(item);
 }
 
-void MainWindow::newText()
-{
+void MainWindow::newText() {
     QtCanvasItem *item = addText();
     canvas->update();
     itemClicked(item);
 }
 
-void MainWindow::deleteObject()
-{
+void MainWindow::deleteObject() {
     if (!currentItem)
         return;
 
@@ -208,16 +198,14 @@ void MainWindow::deleteObject()
     canvas->update();
 }
 
-void MainWindow::clearAll()
-{
+void MainWindow::clearAll() {
     QtCanvasItemList list = canvas->allItems();
     qDeleteAll(list);
     itemClicked(0);
     canvas->update();
 }
 
-void MainWindow::fillView()
-{
+void MainWindow::fillView() {
     for (int i = 0; i < 10; i++) {
         addRectangle();
         addEllipse();
@@ -227,10 +215,9 @@ void MainWindow::fillView()
     canvas->update();
 }
 
-QtCanvasItem *MainWindow::addRectangle()
-{
+QtCanvasItem *MainWindow::addRectangle() {
     QtCanvasPolygonalItem *item = new QtCanvasRectangle(rand() % canvas->width(),
-                rand() % canvas->height(), 50, 50, canvas);
+            rand() % canvas->height(), 50, 50, canvas);
     int z = rand() % 256;
     item->setBrush(QColor(rand() % 32 * 8, rand() % 32 * 8, rand() % 32 * 8));
     item->setPen(QPen(QColor(rand() % 32*8, rand() % 32*8, rand() % 32*8), 4));
@@ -239,8 +226,7 @@ QtCanvasItem *MainWindow::addRectangle()
     return item;
 }
 
-QtCanvasItem *MainWindow::addEllipse()
-{
+QtCanvasItem *MainWindow::addEllipse() {
     QtCanvasPolygonalItem *item = new QtCanvasEllipse(50, 50, canvas);
     item->setBrush(QColor(rand() % 32 * 8, rand() % 32 * 8, rand() % 32 * 8));
     item->move(rand() % canvas->width(), rand() % canvas->height());
@@ -249,11 +235,10 @@ QtCanvasItem *MainWindow::addEllipse()
     return item;
 }
 
-QtCanvasItem *MainWindow::addLine()
-{
+QtCanvasItem *MainWindow::addLine() {
     QtCanvasLine *item = new QtCanvasLine(canvas);
     item->setPoints(0, 0, rand() % canvas->width() - canvas->width() / 2,
-                rand() % canvas->height() - canvas->height() / 2);
+                    rand() % canvas->height() - canvas->height() / 2);
     item->move(rand() % canvas->width(), rand() % canvas->height());
     item->setPen(QPen(QColor(rand() % 32*8, rand() % 32*8, rand() % 32*8), 6));
     item->setZ(rand() % 256);
@@ -261,8 +246,7 @@ QtCanvasItem *MainWindow::addLine()
     return item;
 }
 
-QtCanvasItem *MainWindow::addText()
-{
+QtCanvasItem *MainWindow::addText() {
     QtCanvasText *item = new QtCanvasText(canvas);
     item->setText(tr("Text"));
     item->setColor(QColor(rand() % 32*8, rand() % 32*8, rand() % 32*8));
@@ -272,8 +256,7 @@ QtCanvasItem *MainWindow::addText()
     return item;
 }
 
-void MainWindow::itemMoved(QtCanvasItem *item)
-{
+void MainWindow::itemMoved(QtCanvasItem *item) {
     if (item != currentItem)
         return;
 
@@ -282,8 +265,7 @@ void MainWindow::itemMoved(QtCanvasItem *item)
     doubleManager->setValue(idToProperty[QLatin1String("zpos")], item->z());
 }
 
-void MainWindow::updateExpandState()
-{
+void MainWindow::updateExpandState() {
     QList<QtBrowserItem *> list = propertyEditor->topLevelItems();
     QListIterator<QtBrowserItem *> it(list);
     while (it.hasNext()) {
@@ -293,8 +275,7 @@ void MainWindow::updateExpandState()
     }
 }
 
-void MainWindow::itemClicked(QtCanvasItem *item)
-{
+void MainWindow::itemClicked(QtCanvasItem *item) {
     updateExpandState();
 
     QMap<QtProperty *, QString>::ConstIterator itProp = propertyToId.constBegin();
@@ -382,8 +363,7 @@ void MainWindow::itemClicked(QtCanvasItem *item)
     }
 }
 
-void MainWindow::addProperty(QtProperty *property, const QString &id)
-{
+void MainWindow::addProperty(QtProperty *property, const QString &id) {
     propertyToId[property] = id;
     idToProperty[id] = property;
     QtBrowserItem *item = propertyEditor->addProperty(property);
@@ -391,8 +371,7 @@ void MainWindow::addProperty(QtProperty *property, const QString &id)
         propertyEditor->setExpanded(item, idToExpanded[id]);
 }
 
-void MainWindow::valueChanged(QtProperty *property, double value)
-{
+void MainWindow::valueChanged(QtProperty *property, double value) {
     if (!propertyToId.contains(property))
         return;
 
@@ -410,8 +389,7 @@ void MainWindow::valueChanged(QtProperty *property, double value)
     canvas->update();
 }
 
-void MainWindow::valueChanged(QtProperty *property, const QString &value)
-{
+void MainWindow::valueChanged(QtProperty *property, const QString &value) {
     if (!propertyToId.contains(property))
         return;
 
@@ -428,8 +406,7 @@ void MainWindow::valueChanged(QtProperty *property, const QString &value)
     canvas->update();
 }
 
-void MainWindow::valueChanged(QtProperty *property, const QColor &value)
-{
+void MainWindow::valueChanged(QtProperty *property, const QColor &value) {
     if (!propertyToId.contains(property))
         return;
 
@@ -462,8 +439,7 @@ void MainWindow::valueChanged(QtProperty *property, const QColor &value)
     canvas->update();
 }
 
-void MainWindow::valueChanged(QtProperty *property, const QFont &value)
-{
+void MainWindow::valueChanged(QtProperty *property, const QFont &value) {
     if (!propertyToId.contains(property))
         return;
 
@@ -480,8 +456,7 @@ void MainWindow::valueChanged(QtProperty *property, const QFont &value)
     canvas->update();
 }
 
-void MainWindow::valueChanged(QtProperty *property, const QPoint &value)
-{
+void MainWindow::valueChanged(QtProperty *property, const QPoint &value) {
     if (!propertyToId.contains(property))
         return;
 
@@ -498,8 +473,7 @@ void MainWindow::valueChanged(QtProperty *property, const QPoint &value)
     canvas->update();
 }
 
-void MainWindow::valueChanged(QtProperty *property, const QSize &value)
-{
+void MainWindow::valueChanged(QtProperty *property, const QSize &value) {
     if (!propertyToId.contains(property))
         return;
 
