@@ -64,30 +64,43 @@ typedef QList<QtCanvasItem *> QtCanvasItemList;
 
 class QtCanvasItemExtra;
 
-class QtCanvasItem
-{
+class QtCanvasItem {
 public:
     QtCanvasItem(QtCanvas* canvas);
     virtual ~QtCanvasItem();
 
-    double x() const
-	{ return myx; }
-    double y() const
-	{ return myy; }
-    double z() const
-	{ return myz; } // (depth)
+    double x() const {
+        return myx;
+    }
+    double y() const {
+        return myy;
+    }
+    double z() const {
+        return myz;    // (depth)
+    }
 
     virtual void moveBy(double dx, double dy);
     void move(double x, double y);
-    void setX(double a) { move(a,y()); }
-    void setY(double a) { move(x(),a); }
-    void setZ(double a) { myz=a; changeChunks(); }
+    void setX(double a) {
+        move(a,y());
+    }
+    void setY(double a) {
+        move(x(),a);
+    }
+    void setZ(double a) {
+        myz=a;
+        changeChunks();
+    }
 
     bool animated() const;
     virtual void setAnimated(bool y);
     virtual void setVelocity(double vx, double vy);
-    void setXVelocity(double vx) { setVelocity(vx,yVelocity()); }
-    void setYVelocity(double vy) { setVelocity(xVelocity(),vy); }
+    void setXVelocity(double vx) {
+        setVelocity(vx,yVelocity());
+    }
+    void setYVelocity(double vy) {
+        setVelocity(xVelocity(),vy);
+    }
     double xVelocity() const;
     double yVelocity() const;
     virtual void advance(int stage);
@@ -104,36 +117,44 @@ public:
     void hide();
 
     virtual void setVisible(bool yes);
-    bool isVisible() const
-	{ return (bool)vis; }
+    bool isVisible() const {
+        return (bool)vis;
+    }
     virtual void setSelected(bool yes);
-    bool isSelected() const
-	{ return (bool)sel; }
+    bool isSelected() const {
+        return (bool)sel;
+    }
     virtual void setEnabled(bool yes);
-    bool isEnabled() const
-	{ return (bool)ena; }
+    bool isEnabled() const {
+        return (bool)ena;
+    }
     virtual void setActive(bool yes);
-    bool isActive() const
-	{ return (bool)act; }
-    bool visible() const
-	{ return (bool)vis; }
-    bool selected() const
-	{ return (bool)sel; }
-    bool enabled() const
-	{ return (bool)ena; }
-    bool active() const
-	{ return (bool)act; }
+    bool isActive() const {
+        return (bool)act;
+    }
+    bool visible() const {
+        return (bool)vis;
+    }
+    bool selected() const {
+        return (bool)sel;
+    }
+    bool enabled() const {
+        return (bool)ena;
+    }
+    bool active() const {
+        return (bool)act;
+    }
 
     enum RttiValues {
-	Rtti_Item = 0,
-	Rtti_Sprite = 1,
-	Rtti_PolygonalItem = 2,
-	Rtti_Text = 3,
-	Rtti_Polygon = 4,
-	Rtti_Rectangle = 5,
-	Rtti_Ellipse = 6,
-	Rtti_Line = 7,
-	Rtti_Spline = 8
+        Rtti_Item = 0,
+        Rtti_Sprite = 1,
+        Rtti_PolygonalItem = 2,
+        Rtti_Text = 3,
+        Rtti_Polygon = 4,
+        Rtti_Rectangle = 5,
+        Rtti_Ellipse = 6,
+        Rtti_Line = 7,
+        Rtti_Spline = 8
     };
 
     virtual int rtti() const;
@@ -142,11 +163,14 @@ public:
     virtual QRect boundingRect() const=0;
     virtual QRect boundingRectAdvanced() const;
 
-    QtCanvas* canvas() const
-	{ return cnv; }
+    QtCanvas* canvas() const {
+        return cnv;
+    }
 
 protected:
-    void update() { changeChunks(); }
+    void update() {
+        changeChunks();
+    }
 
 private:
     // For friendly subclasses...
@@ -164,10 +188,10 @@ private:
     virtual void removeFromChunks();
     virtual void changeChunks();
     virtual bool collidesWith(const QtCanvasSprite*,
-			       const QtCanvasPolygonalItem*,
-			       const QtCanvasRectangle*,
-			       const QtCanvasEllipse*,
-			       const QtCanvasText*) const = 0;
+                              const QtCanvasPolygonalItem*,
+                              const QtCanvasRectangle*,
+                              const QtCanvasEllipse*,
+                              const QtCanvasText*) const = 0;
     // End of friend stuff
 
     QtCanvas* cnv;
@@ -186,8 +210,7 @@ private:
 
 class QtCanvasData;
 
-class QtCanvas : public QObject
-{
+class QtCanvas : public QObject {
     Q_OBJECT
 public:
     QtCanvas(QObject* parent = 0);
@@ -197,7 +220,7 @@ public:
     virtual ~QtCanvas();
 
     virtual void setTiles(QPixmap tiles, int h, int v,
-			   int tilewidth, int tileheight);
+                          int tilewidth, int tileheight);
     virtual void setBackgroundPixmap(const QPixmap& p);
     QPixmap backgroundPixmap() const;
 
@@ -205,43 +228,58 @@ public:
     QColor backgroundColor() const;
 
     virtual void setTile(int x, int y, int tilenum);
-    int tile(int x, int y) const
-	{ return grid[x+y*htiles]; }
+    int tile(int x, int y) const {
+        return grid[x+y*htiles];
+    }
 
-    int tilesHorizontally() const
-	{ return htiles; }
-    int tilesVertically() const
-	{ return vtiles; }
+    int tilesHorizontally() const {
+        return htiles;
+    }
+    int tilesVertically() const {
+        return vtiles;
+    }
 
-    int tileWidth() const
-	{ return tilew; }
-    int tileHeight() const
-	{ return tileh; }
+    int tileWidth() const {
+        return tilew;
+    }
+    int tileHeight() const {
+        return tileh;
+    }
 
     virtual void resize(int width, int height);
-    int width() const
-	{ return awidth; }
-    int height() const
-	{ return aheight; }
-    QSize size() const
-	{ return QSize(awidth,aheight); }
-    QRect rect() const
-	{ return QRect(0, 0, awidth, aheight); }
-    bool onCanvas(int x, int y) const
-	{ return x>=0 && y>=0 && x<awidth && y<aheight; }
-    bool onCanvas(const QPoint& p) const
-	{ return onCanvas(p.x(),p.y()); }
-    bool validChunk(int x, int y) const
-	{ return x>=0 && y>=0 && x<chwidth && y<chheight; }
-    bool validChunk(const QPoint& p) const
-	{ return validChunk(p.x(),p.y()); }
+    int width() const {
+        return awidth;
+    }
+    int height() const {
+        return aheight;
+    }
+    QSize size() const {
+        return QSize(awidth,aheight);
+    }
+    QRect rect() const {
+        return QRect(0, 0, awidth, aheight);
+    }
+    bool onCanvas(int x, int y) const {
+        return x>=0 && y>=0 && x<awidth && y<aheight;
+    }
+    bool onCanvas(const QPoint& p) const {
+        return onCanvas(p.x(),p.y());
+    }
+    bool validChunk(int x, int y) const {
+        return x>=0 && y>=0 && x<chwidth && y<chheight;
+    }
+    bool validChunk(const QPoint& p) const {
+        return validChunk(p.x(),p.y());
+    }
 
-    int chunkSize() const
-	{ return chunksize; }
+    int chunkSize() const {
+        return chunksize;
+    }
     virtual void retune(int chunksize, int maxclusters=100);
 
-    bool sameChunk(int x1, int y1, int x2, int y2) const
-	{ return x1/chunksize==x2/chunksize && y1/chunksize==y2/chunksize; }
+    bool sameChunk(int x1, int y1, int x2, int y2) const {
+        return x1/chunksize==x2/chunksize && y1/chunksize==y2/chunksize;
+    }
     virtual void setChangedChunk(int i, int j);
     virtual void setChangedChunkContaining(int x, int y);
     virtual void setAllChanged();
@@ -258,7 +296,7 @@ public:
     QtCanvasItemList collisions(const QPoint&) const;
     QtCanvasItemList collisions(const QRect&) const;
     QtCanvasItemList collisions(const QPolygon& pa, const QtCanvasItem* item,
-				bool exact) const;
+                                bool exact) const;
 
     void drawArea(const QRect&, QPainter* p, bool double_buffer=false);
 
@@ -324,8 +362,7 @@ private:
 
 class QtCanvasViewData;
 
-class QtCanvasView : public QScrollArea
-{
+class QtCanvasView : public QScrollArea {
     Q_OBJECT
     Q_PROPERTY(bool highQualityRendering READ highQualityRendering WRITE setHighQualityRendering)
 public:
@@ -334,8 +371,9 @@ public:
     QtCanvasView(QtCanvas* viewing, QWidget* parent=0);
     ~QtCanvasView();
 
-    QtCanvas* canvas() const
-	{ return viewing; }
+    QtCanvas* canvas() const {
+        return viewing;
+    }
     void setCanvas(QtCanvas* v);
 
     const QMatrix &worldMatrix() const;
@@ -347,7 +385,7 @@ public:
     bool highQualityRendering() const;
 public slots:
     void setHighQualityRendering(bool enable);
-    
+
 protected:
     friend class QtCanvasWidget;
     virtual void drawContents(QPainter *p, int cx, int cy, int cw, int ch);
@@ -377,8 +415,7 @@ private:
 };
 
 
-class QtCanvasPixmap : public QPixmap
-{
+class QtCanvasPixmap : public QPixmap {
 public:
 #ifndef QT_NO_IMAGEIO
     QtCanvasPixmap(const QString& datafilename);
@@ -387,11 +424,16 @@ public:
     QtCanvasPixmap(const QPixmap&, const QPoint& hotspot);
     ~QtCanvasPixmap();
 
-    int offsetX() const
-	{ return hotx; }
-    int offsetY() const
-	{ return hoty; }
-    void setOffset(int x, int y) { hotx = x; hoty = y; }
+    int offsetX() const {
+        return hotx;
+    }
+    int offsetY() const {
+        return hoty;
+    }
+    void setOffset(int x, int y) {
+        hotx = x;
+        hoty = y;
+    }
 
 private:
     Q_DISABLE_COPY(QtCanvasPixmap)
@@ -409,8 +451,7 @@ private:
 };
 
 
-class QtCanvasPixmapArray
-{
+class QtCanvasPixmapArray {
 public:
     QtCanvasPixmapArray();
 #ifndef QT_NO_IMAGEIO
@@ -428,11 +469,13 @@ public:
     bool operator!(); // Failure check.
     bool isValid() const;
 
-    QtCanvasPixmap* image(int i) const
-	{ return img ? img[i] : 0; }
+    QtCanvasPixmap* image(int i) const {
+        return img ? img[i] : 0;
+    }
     void setImage(int i, QtCanvasPixmap* p);
-    uint count() const
-	{ return (uint)framecount; }
+    uint count() const {
+        return (uint)framecount;
+    }
 
 private:
     Q_DISABLE_COPY(QtCanvasPixmapArray)
@@ -447,8 +490,7 @@ private:
 };
 
 
-class QtCanvasSprite : public QtCanvasItem
-{
+class QtCanvasSprite : public QtCanvasItem {
 public:
     QtCanvasSprite(QtCanvasPixmapArray* array, QtCanvas* canvas);
 
@@ -461,10 +503,12 @@ public:
     void setFrame(int);
     enum FrameAnimationType { Cycle, Oscillate };
     virtual void setFrameAnimation(FrameAnimationType=Cycle, int step=1, int state=0);
-    int frame() const
-	{ return frm; }
-    int frameCount() const
-	{ return images->count(); }
+    int frame() const {
+        return frm;
+    }
+    int frameCount() const {
+        return images->count();
+    }
 
     int rtti() const;
     static int RTTI;
@@ -488,11 +532,13 @@ public:
     int topEdge(int ny) const;
     int rightEdge(int nx) const;
     int bottomEdge(int ny) const;
-    QtCanvasPixmap* image() const
-	{ return images->image(frm); }
+    QtCanvasPixmap* image() const {
+        return images->image(frm);
+    }
     virtual QtCanvasPixmap* imageAdvanced() const;
-    QtCanvasPixmap* image(int f) const
-	{ return images->image(f); }
+    QtCanvasPixmap* image(int f) const {
+        return images->image(f);
+    }
     virtual void advance(int stage);
 
 public:
@@ -510,21 +556,20 @@ private:
     uint anim_state:2;
     uint anim_type:14;
     bool collidesWith(const QtCanvasSprite*,
-		       const QtCanvasPolygonalItem*,
-		       const QtCanvasRectangle*,
-		       const QtCanvasEllipse*,
-		       const QtCanvasText*) const;
+                      const QtCanvasPolygonalItem*,
+                      const QtCanvasRectangle*,
+                      const QtCanvasEllipse*,
+                      const QtCanvasText*) const;
 
     friend bool qt_testCollision(const QtCanvasSprite* s1,
-				  const QtCanvasSprite* s2);
+                                 const QtCanvasSprite* s2);
 
     QtCanvasPixmapArray* images;
 };
 
 class QPolygonalProcessor;
 
-class QtCanvasPolygonalItem : public QtCanvasItem
-{
+class QtCanvasPolygonalItem : public QtCanvasItem {
 public:
     QtCanvasPolygonalItem(QtCanvas* canvas);
     virtual ~QtCanvasPolygonalItem();
@@ -534,10 +579,12 @@ public:
     virtual void setPen(QPen p);
     virtual void setBrush(QBrush b);
 
-    QPen pen() const
-	{ return pn; }
-    QBrush brush() const
-	{ return br; }
+    QPen pen() const {
+        return pn;
+    }
+    QBrush brush() const {
+        return br;
+    }
 
     virtual QPolygon areaPoints() const=0;
     virtual QPolygon areaPointsAdvanced() const;
@@ -554,19 +601,20 @@ protected:
     void setWinding(bool);
 
     void invalidate();
-    bool isValid() const
-	{ return (bool)val; }
+    bool isValid() const {
+        return (bool)val;
+    }
 
 private:
     void scanPolygon(const QPolygon& pa, int winding,
-		      QPolygonalProcessor& process) const;
+                     QPolygonalProcessor& process) const;
     QPolygon chunks() const;
 
     bool collidesWith(const QtCanvasSprite*,
-		       const QtCanvasPolygonalItem*,
-		       const QtCanvasRectangle*,
-		       const QtCanvasEllipse*,
-		       const QtCanvasText*) const;
+                      const QtCanvasPolygonalItem*,
+                      const QtCanvasRectangle*,
+                      const QtCanvasEllipse*,
+                      const QtCanvasText*) const;
 
     QBrush br;
     QPen pn;
@@ -574,8 +622,7 @@ private:
 };
 
 
-class QtCanvasRectangle : public QtCanvasPolygonalItem
-{
+class QtCanvasRectangle : public QtCanvasPolygonalItem {
 public:
     QtCanvasRectangle(QtCanvas* canvas);
     QtCanvasRectangle(const QRect&, QtCanvas* canvas);
@@ -586,11 +633,13 @@ public:
     int width() const;
     int height() const;
     void setSize(int w, int h);
-    QSize size() const
-	{ return QSize(w,h); }
+    QSize size() const {
+        return QSize(w,h);
+    }
     QPolygon areaPoints() const;
-    QRect rect() const
-	{ return QRect(int(x()),int(y()),w,h); }
+    QRect rect() const {
+        return QRect(int(x()),int(y()),w,h);
+    }
 
     bool collidesWith(const QtCanvasItem*) const;
 
@@ -603,17 +652,16 @@ protected:
 
 private:
     bool collidesWith(  const QtCanvasSprite*,
-			 const QtCanvasPolygonalItem*,
-			 const QtCanvasRectangle*,
-			 const QtCanvasEllipse*,
-			 const QtCanvasText*) const;
+                        const QtCanvasPolygonalItem*,
+                        const QtCanvasRectangle*,
+                        const QtCanvasEllipse*,
+                        const QtCanvasText*) const;
 
     int w, h;
 };
 
 
-class QtCanvasPolygon : public QtCanvasPolygonalItem
-{
+class QtCanvasPolygon : public QtCanvasPolygonalItem {
 public:
     QtCanvasPolygon(QtCanvas* canvas);
     ~QtCanvasPolygon();
@@ -632,8 +680,7 @@ protected:
 };
 
 
-class QtCanvasSpline : public QtCanvasPolygon
-{
+class QtCanvasSpline : public QtCanvasPolygon {
 public:
     QtCanvasSpline(QtCanvas* canvas);
     ~QtCanvasSpline();
@@ -652,17 +699,18 @@ private:
 };
 
 
-class QtCanvasLine : public QtCanvasPolygonalItem
-{
+class QtCanvasLine : public QtCanvasPolygonalItem {
 public:
     QtCanvasLine(QtCanvas* canvas);
     ~QtCanvasLine();
     void setPoints(int x1, int y1, int x2, int y2);
 
-    QPoint startPoint() const
-	{ return QPoint(x1,y1); }
-    QPoint endPoint() const
-	{ return QPoint(x2,y2); }
+    QPoint startPoint() const {
+        return QPoint(x1,y1);
+    }
+    QPoint endPoint() const {
+        return QPoint(x2,y2);
+    }
 
     int rtti() const;
     static int RTTI;
@@ -679,14 +727,13 @@ private:
 };
 
 
-class QtCanvasEllipse : public QtCanvasPolygonalItem
-{
+class QtCanvasEllipse : public QtCanvasPolygonalItem {
 
 public:
     QtCanvasEllipse(QtCanvas* canvas);
     QtCanvasEllipse(int width, int height, QtCanvas* canvas);
     QtCanvasEllipse(int width, int height, int startangle, int angle,
-		    QtCanvas* canvas);
+                    QtCanvas* canvas);
 
     ~QtCanvasEllipse();
 
@@ -694,10 +741,12 @@ public:
     int height() const;
     void setSize(int w, int h);
     void setAngles(int start, int length);
-    int angleStart() const
-	{ return a1; }
-    int angleLength() const
-	{ return a2; }
+    int angleStart() const {
+        return a1;
+    }
+    int angleLength() const {
+        return a2;
+    }
     QPolygon areaPoints() const;
 
     bool collidesWith(const QtCanvasItem*) const;
@@ -710,10 +759,10 @@ protected:
 
 private:
     bool collidesWith(const QtCanvasSprite*,
-		       const QtCanvasPolygonalItem*,
-		       const QtCanvasRectangle*,
-		       const QtCanvasEllipse*,
-		       const QtCanvasText*) const;
+                      const QtCanvasPolygonalItem*,
+                      const QtCanvasRectangle*,
+                      const QtCanvasEllipse*,
+                      const QtCanvasText*) const;
     int w, h;
     int a1, a2;
 };
@@ -721,8 +770,7 @@ private:
 
 class QtCanvasTextExtra;
 
-class QtCanvasText : public QtCanvasItem
-{
+class QtCanvasText : public QtCanvasItem {
 public:
     QtCanvasText(QtCanvas* canvas);
     QtCanvasText(const QString&, QtCanvas* canvas);
@@ -739,8 +787,9 @@ public:
 
     void moveBy(double dx, double dy);
 
-    int textFlags() const
-	{ return flags; }
+    int textFlags() const {
+        return flags;
+    }
     void setTextFlags(int);
 
     QRect boundingRect() const;
