@@ -39,10 +39,10 @@
 
 
 #include "qtpropertybrowser.h"
-#include <QtCore/QSet>
-#include <QtCore/QMap>
-#include <QtGui/QIcon>
-#include <QtGui/QLineEdit>
+#include <QSet>
+#include <QMap>
+#include <QIcon>
+#include <QLineEdit>
 
 #if defined(Q_CC_MSVC)
 #    pragma warning(disable: 4786) /* MS VS 6: truncating debug info after 255 characters */
