@@ -52,10 +52,10 @@
 #ifndef QTPROPERTYBROWSERUTILS_H
 #define QTPROPERTYBROWSERUTILS_H
 
-#include <QtCore/QMap>
-#include <QtGui/QIcon>
-#include <QtGui/QWidget>
-#include <QtCore/QStringList>
+#include <QMap>
+#include <QIcon>
+#include <QWidget>
+#include <QStringList>
 
 #if QT_VERSION >= 0x040400
 QT_BEGIN_NAMESPACE
