@@ -56,13 +56,12 @@ class QLocale;
 
 /**
  * @ingroup group_sdk_libraries_qtpropertybrowser
- * 
- * @brief 
+ *
+ * @brief
  * The description of this class will come soon !
- * 
+ *
  **/
-class QT_QTPROPERTYBROWSER_EXPORT QtGroupPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtGroupPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtGroupPropertyManager(QObject *parent = 0);
@@ -77,8 +76,7 @@ protected:
 
 class QtIntPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtIntPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtIntPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtIntPropertyManager(QObject *parent = 0);
@@ -111,8 +109,7 @@ private:
 
 class QtBoolPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtBoolPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtBoolPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtBoolPropertyManager(QObject *parent = 0);
@@ -137,8 +134,7 @@ private:
 
 class QtDoublePropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtDoublePropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtDoublePropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtDoublePropertyManager(QObject *parent = 0);
@@ -174,8 +170,7 @@ private:
 
 class QtStringPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtStringPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtStringPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtStringPropertyManager(QObject *parent = 0);
@@ -206,8 +201,7 @@ private:
 
 class QtDatePropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtDatePropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtDatePropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtDatePropertyManager(QObject *parent = 0);
@@ -237,8 +231,7 @@ private:
 
 class QtTimePropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtTimePropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtTimePropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtTimePropertyManager(QObject *parent = 0);
@@ -262,8 +255,7 @@ private:
 
 class QtDateTimePropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtDateTimePropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtDateTimePropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtDateTimePropertyManager(QObject *parent = 0);
@@ -287,8 +279,7 @@ private:
 
 class QtKeySequencePropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtKeySequencePropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtKeySequencePropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtKeySequencePropertyManager(QObject *parent = 0);
@@ -312,8 +303,7 @@ private:
 
 class QtCharPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtCharPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtCharPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtCharPropertyManager(QObject *parent = 0);
@@ -338,8 +328,7 @@ private:
 class QtEnumPropertyManager;
 class QtLocalePropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtLocalePropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtLocalePropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtLocalePropertyManager(QObject *parent = 0);
@@ -367,8 +356,7 @@ private:
 
 class QtPointPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtPointPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtPointPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtPointPropertyManager(QObject *parent = 0);
@@ -396,8 +384,7 @@ private:
 
 class QtPointFPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtPointFPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtPointFPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtPointFPropertyManager(QObject *parent = 0);
@@ -428,8 +415,7 @@ private:
 
 class QtSizePropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtSizePropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtSizePropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtSizePropertyManager(QObject *parent = 0);
@@ -463,8 +449,7 @@ private:
 
 class QtSizeFPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtSizeFPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtSizeFPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtSizeFPropertyManager(QObject *parent = 0);
@@ -501,8 +486,7 @@ private:
 
 class QtRectPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtRectPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtRectPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtRectPropertyManager(QObject *parent = 0);
@@ -533,8 +517,7 @@ private:
 
 class QtRectFPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtRectFPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtRectFPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtRectFPropertyManager(QObject *parent = 0);
@@ -570,8 +553,7 @@ private:
 class QtVector3DPropertyManagerPrivate;
 class QVector3D;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtVector3DPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtVector3DPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtVector3DPropertyManager(QObject *parent = 0);
@@ -602,8 +584,7 @@ private:
 
 class QtEnumPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtEnumPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtEnumPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtEnumPropertyManager(QObject *parent = 0);
@@ -634,8 +615,7 @@ private:
 
 class QtFlagPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtFlagPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtFlagPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtFlagPropertyManager(QObject *parent = 0);
@@ -666,8 +646,7 @@ private:
 
 class QtSizePolicyPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtSizePolicyPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtSizePolicyPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtSizePolicyPropertyManager(QObject *parent = 0);
@@ -697,8 +676,7 @@ private:
 
 class QtFontPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtFontPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtFontPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtFontPropertyManager(QObject *parent = 0);
@@ -733,8 +711,7 @@ private:
 
 class QtColorPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtColorPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtColorPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtColorPropertyManager(QObject *parent = 0);
@@ -763,8 +740,7 @@ private:
 
 class QtCursorPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtCursorPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtCursorPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtCursorPropertyManager(QObject *parent = 0);
