@@ -56,13 +56,12 @@ class QtVariantPropertyPrivate;
 
 /**
  * @ingroup group_sdk_libraries_qtpropertybrowser
- * 
- * @brief 
+ *
+ * @brief
  * The description of this class will come soon !
- * 
+ *
  **/
-class QT_QTPROPERTYBROWSER_EXPORT QtVariantProperty : public QtProperty
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtVariantProperty : public QtProperty {
 public:
     ~QtVariantProperty();
     QVariant value() const;
@@ -81,8 +80,7 @@ private:
 
 class QtVariantPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtVariantPropertyManager : public QtAbstractPropertyManager
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtVariantPropertyManager : public QtAbstractPropertyManager {
     Q_OBJECT
 public:
     QtVariantPropertyManager(QObject *parent = 0);
@@ -109,11 +107,11 @@ public:
 public Q_SLOTS:
     virtual void setValue(QtProperty *property, const QVariant &val);
     virtual void setAttribute(QtProperty *property,
-                const QString &attribute, const QVariant &value);
+                              const QString &attribute, const QVariant &value);
 Q_SIGNALS:
     void valueChanged(QtProperty *property, const QVariant &val);
     void attributeChanged(QtProperty *property,
-                const QString &attribute, const QVariant &val);
+                          const QString &attribute, const QVariant &val);
 protected:
     virtual bool hasValue(const QtProperty *property) const;
     QString valueText(const QtProperty *property) const;
@@ -168,8 +166,7 @@ private:
 
 class QtVariantEditorFactoryPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtVariantEditorFactory : public QtAbstractEditorFactory<QtVariantPropertyManager>
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtVariantEditorFactory : public QtAbstractEditorFactory<QtVariantPropertyManager> {
     Q_OBJECT
 public:
     QtVariantEditorFactory(QObject *parent = 0);
@@ -177,7 +174,7 @@ public:
 protected:
     void connectPropertyManager(QtVariantPropertyManager *manager);
     QWidget *createEditor(QtVariantPropertyManager *manager, QtProperty *property,
-                QWidget *parent);
+                          QWidget *parent);
     void disconnectPropertyManager(QtVariantPropertyManager *manager);
 private:
     QtVariantEditorFactoryPrivate *d_ptr;
